@@ -55,7 +55,7 @@ use strict;
             my $xs = XML::Simple->new;
             $bookmarks = $xs->XMLin($xmlString,
                                     ForceArray => ['file', 'dir'],
-                                    KeyAttr => {'file' => '',
+                                    KeyAttr => {
                                                 'dir' => 'id'
                                                });
             $self->{menu}->setBookmarks($bookmarks);
@@ -67,6 +67,7 @@ use strict;
     {
         my ($self, $bookmarks) = @_;
         
+        return if !$bookmarks->{file};
         $self->{bookmarks} = $bookmarks;
         my $xs = XML::Simple->new;
         my $xmlString = $xs->XMLout($bookmarks,
@@ -700,13 +701,6 @@ use GCDialogs;
         return $self->{folders}->getBookmarks;
     }
 
-    sub addFolder
-    {
-        my $self = shift;
-        my $dialog = new GCBookmarkNewFolderDialog($self);
-        $self->{folders}->addFolder($dialog->{entry}->getValue) if $dialog->show;
-    }
-
     sub saveBookmarks
     {
         my $self = shift;
