@@ -455,8 +455,7 @@ use GCUtils;
     {
         my ($self, $movies) = @_;
 
-        $self->{moviesList} = $movies;
-        
+        $self->{moviesList} = [];
         @{$self->{items}->{data}} = ();
         
         foreach (@{$movies})
@@ -469,6 +468,11 @@ use GCUtils;
                           $borrower,
                           $_->{$self->{lendDateField}} ];
             push @{$self->{items}->{data}}, @infos;
+            push @{$self->{moviesList}}, {
+                $self->{titleField} => $_->{$self->{titleField}},
+                $self->{borrowerField} => $borrower,
+                $self->{lendDateField} => $_->{$self->{lendDateField}}
+            };
         }
         
         $self->{items}->select(0);
@@ -521,7 +525,7 @@ use GCUtils;
         my $hbox = new Gtk2::HBox(0,0);
         
         $self->{items} = new Gtk2::SimpleList(
-                $parent->{model}->getDisplayedText('Items') => "text",
+                $parent->{model}->getDisplayedItems => "text",
                 $parent->{lang}->{PanelBorrower} => "text",
                 $parent->{lang}->{BorrowedDate} => "text");
 
@@ -554,32 +558,13 @@ use GCUtils;
     {
         my ($self, $col) = @_;
 
-        my @movies = @{$self->{moviesList}};
+        #my @movies = @{$self->{moviesList}};
 
         for my $i (0..2)
         {
             $self->{items}->get_column($i)->set_sort_indicator(0);
         }
         
-        sub compareTitle
-        {
-            use locale;
-            $a->{$self->{titleField}} cmp $b->{$self->{titleField}};
-        }
-        sub compareBorrower
-        {
-            use locale;
-            $a->{$self->{borrowerField}} cmp $b->{$self->{borrowerField}};
-        }
-        sub compareLendDate
-        {
-            my ($day, $month, $year) = split m/\//, $a->{$self->{lendDateField}};
-            my $dateA = join "_", $year, $month, $day;
-            ($day, $month, $year) = split m/\//, $b->{$self->{lendDateField}};
-            my $dateB = join "_", $year, $month, $day;
-            $dateA cmp $dateB;
-        }
-
         if ($self->{sort} == $col)
         {
             $self->{order} = 1 - $self->{order}
@@ -589,14 +574,41 @@ use GCUtils;
             $self->{order} = 1;
         }
         
-        @movies = sort compareTitle @movies if $col == 0;
-        @movies = sort compareBorrower @movies if $col == 1;
-        @movies = sort compareLendDate @movies if $col == 2;
+        my $compare;
+        if ($col < 2)
+        {
+            use locale;
+            $compare = sub {
+                return $a->{$self->{titleField}}
+                   cmp $b->{$self->{titleField}};
+            };
+        }
+        elsif ($col == 1)
+        {
+            use locale;
+            $compare = sub {
+                return $a->{$self->{borrowerField}}
+                   cmp $b->{$self->{borrowerField}};
+            };
+        }
+        else
+        {
+            $compare = sub {
+                my ($day, $month, $year) = split m/\//, $a->{$self->{lendDateField}};
+                my $dateA = join "_", $year, $month, $day;
+                ($day, $month, $year) = split m/\//, $b->{$self->{lendDateField}};
+                my $dateB = join "_", $year, $month, $day;
+                return $dateA cmp $dateB;
+            };
+        }
+
+        @{$self->{moviesList}} = sort $compare @{$self->{moviesList}};
+
 
         $self->{items}->get_column($col)->set_sort_indicator(1);
-        @movies = reverse @movies if ! $self->{order};
+        @{$self->{moviesList}} = reverse @{$self->{moviesList}} if ! $self->{order};
         $self->{items}->get_column($col)->set_sort_order($self->{order} ? 'ascending' : 'descending');
-        $self->setList(\@movies);
+        $self->setList($self->{moviesList});
         $self->{sort} = $col;
     }
 
