@@ -28,102 +28,67 @@ use strict;
     package GCPseudoFrame;
     
     use File::Basename;
+    use File::Temp qw(tempdir);
     use GCUtils;
     
     sub new
     {
-        my ($proto, $parent, $options, $lang) = @_;
+        my ($proto, $parent, $options, $lang, $keepPictures) = @_;
         my $class = ref($proto) || $proto;
         my $self  = {
                         options => $options,
                         imagePrefix => 'gcstar_',
                         lang => $lang,
                         parent => $parent,
+                        agent => 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.5) Gecko/20041111 Firefox/1.0',
                     };
         bless ($self, $class);
-        
+        $self->{tmpImageDir} = tempdir(CLEANUP => ($keepPictures ? 0 : 1));
         return $self;
     }
 
     sub setCurrentModel
     {
         my ($self, $model) = @_;
-        
+
         $self->{parent}->setModel($model);
     }
 
-    sub refreshFilters
-    {
-    }
-    
     sub transformTitle
     {
         my ($self, $title) = @_;
         return $title;
     }
     
+    sub getImagesDir
+    {
+        my ($self, $suffix, $itemTitle, $imagesDir) = @_;
+        return GCFrame::getImagesDir(@_);
+    }
+
     sub getUniqueImageFileName
     {
         my ($self, $suffix, $itemTitle, $imagesDir) = @_;
-    
-        $imagesDir ||= $self->{options}->images;
-        $imagesDir =~ s+([^/])$+$1/+;
-        my $imagePrefix;
-        if ($self->{options}->useTitleForPics)
-        {
-            $imagePrefix = GCUtils::getSafeFileName($itemTitle);
-            $imagePrefix .= '_';
-        }
-        else
-        {
-            $imagePrefix = $self->{imagePrefix};
-        }
-
-        if ( ! -e $imagesDir)
-        {
-            mkdir($imagesDir);
-        }
-
-        my $filePrefix = $imagesDir.$imagePrefix;
-        my @tmp_filenames;
-        @tmp_filenames = glob $filePrefix.'*.*';
-        my $sysPrefix = $filePrefix;
-        $sysPrefix =~ s/\\/\\\\/g if ($^O =~ /win32/i);
-        my @numbers = sort {$b <=> $a} map {
-            /$sysPrefix([0-9]*)\./ && $1;
-        } @tmp_filenames;
-        my $mostRecent = $numbers[0] || 0;
-
-        my $picture = $filePrefix.$mostRecent.$suffix;
-
-        while (-e $picture)
-        {
-            $mostRecent++;
-            $picture = $filePrefix.$mostRecent.$suffix;
-        }
-        return $picture;
+        return GCFrame::getUniqueImageFileName(@_);
     }
 
     sub transformPicturePath
     {
         my ($self, $path, $file) = @_;
+        return GCFrame::transformPicturePath(@_);
+    }
+    
+    sub preloadModel
+    {
+        my ($self, $model) = @_;
+        # Preload the model into the factory cache
+        $self->{model} = $self->{modelsFactory}->getModel($model);
+    }
 
-        return '' if !$path;
-        $file ||= $self->{parent}->{file};
-        $path = GCUtils::getDisplayedImage($path, '', $file);
-        my $dir = undef;
-        $dir = dirname($file) if $file;
-        return GCUtils::pathToUnix(File::Spec->rel2abs($path,$dir))
-            if !$self->{options}->useRelativePaths;
-        return GCUtils::pathToUnix(File::Spec->abs2rel($path,$dir));
-    }
-    
-    sub endProgress
-    {
-    }
-    
-    sub removeUpdatedMark
+    sub AUTOLOAD
     {
+        our $AUTOLOAD;
+        (my $name = $AUTOLOAD) =~ s/.*?::(.*)/$1/;
     }
 }
 
@@ -147,26 +112,38 @@ use strict;
         my $self  = {};
         bless ($self, $class);
 
-        GCPlugins::loadPlugins;
-        $self->{lang} = $GCLang::langs{$options->lang};
-        $self->{parent} = new GCPseudoFrame($self, $options, $self->{lang});
+        $self->{file} = $output;
+        $self->{useStdOut} = 0;
+        if (!$output)
+        {
+            (undef, $self->{file}) = tmpnam;
+            $self->{useStdOut} = 1;
+        }
 
-        $self->{modelFactory} = new GCModelsCache($self->{parent});
-        $self->{model} = $self->{modelFactory}->getModel($model);
+        GCPlugins::loadAllPlugins;
+        $self->{lang} = $GCLang::langs{$options->lang};
+        $self->{parent} = new GCPseudoFrame($self, $options, $self->{lang}, $self->{useStdOut});
+
+        $self->{modelsFactory} = new GCModelsCache($self->{parent});
+        $self->{model} = $self->{modelsFactory}->getModel($model);
+        $self->{parent}->{model} = $self->{model};
+        $self->{parent}->{modelsFactory} = $self->{modelsFactory};
 
         $self->{plugin} = $pluginsMap{$model}->{$plugin};
+        $self->leave("Fetch plugin $plugin doesn't exist") if $plugin && (!$self->{plugin});
 
         if ($import)
         {
             GCImport::loadImporters;
             foreach (@importersArray)
             {
-                if ($_->getName =~ /$import/)
+                if ($_->getName =~ /\Q$import/)
                 {
                     $self->{importer} = $_;
                     last;
                 }
             }
+            $self->leave("Import plugin $import doesn't exist") if $import && (!$self->{importer});
             $self->{importer}->setModel($self->{model});
             $self->{importOptions} = {};
             foreach (@{$self->{importer}->getOptions})
@@ -185,6 +162,7 @@ use strict;
                     last;
                 }
             }
+            $self->leave("Export plugin $export doesn't exist") if $export && (!$self->{exporter});
             $self->{exporter}->setModel($self->{model});
             $self->{exporter}->setLangName($options->lang);
             $self->{exportOptions} = {
@@ -196,14 +174,6 @@ use strict;
             }
         }
         
-        $self->{file} = $output;
-        $self->{useStdOut} = 0;
-        if (!$output)
-        {
-            (undef, $self->{file}) = tmpnam;
-            $self->{useStdOut} = 1;
-        }
-
         $self->{toBeRemoved} = [];
 
         $self->{data} = new GCItems($self->{parent});
@@ -218,15 +188,47 @@ use strict;
         
         unlink $_ foreach (@{$self->{toBeRemoved}});
     }
-    
+
+    sub leave
+    {
+        my ($self, $message) = @_;
+        print "$message\n";
+        $self->DESTROY;
+        exit 1;
+    }
+
+    sub listPlugins
+    {
+        my $self = shift;
+
+        foreach (sort keys %{$pluginsMap{$self->{model}->getName}})
+        {
+            print "$_\n";
+            print "\t", $pluginsMap{$self->{model}->getName}->{$_}->getAuthor,"\n";
+            print "\n";
+        }
+    }
+
     sub setModel
     {
         my ($self, $model) = @_;
-        $self->{model} = $self->{modelFactory}->getModel($model);
-        $self->{exporter}->setModel($self->{model})
-            if $self->{exporter};
-        $self->{importer}->setModel($self->{model})
-            if $self->{importer};
+        $self->{model} = $self->{modelsFactory}->getModel($model);
+        if ($self->{exporter})
+        {
+            $self->{exporter}->setModel($self->{model});
+            foreach (@{$self->{exporter}->getOptions})
+            {
+                $self->{exportOptions}->{$_->{name}} = $_->{default};
+            }
+        }
+        if ($self->{importer})
+        {
+            $self->{importer}->setModel($self->{model});
+            foreach (@{$self->{importer}->getOptions})
+            {
+                $self->{importOptions}->{$_->{name}} = $_->{default};
+            }
+        }
     }
     
     sub setFields
@@ -248,6 +250,7 @@ use strict;
     {
         my ($self, $title) = @_;
         my @data;
+        $self->leave("No fetch plugin specified") if !$self->{plugin};
         $self->{plugin}->{title} = $title;
         $self->{plugin}->{type} = 'load';
         $self->{plugin}->{urlField} = $self->{model}->{commonFields}->{url};
@@ -266,16 +269,35 @@ use strict;
             }
             push @data, $info;
         }
-        $self->{data}->{itemArray} = \@data;
+        $self->{data}->setItemsList(\@data);
     }
     
     sub save
     {
         my $self = shift;
         my $previousFile = $self->{data}->{options}->file;
-        $self->{data}->{options}->file($self->{file});
+        my $previousRelativePaths = $self->{data}->{options}->useRelativePaths;
+        my $prevImages = $self->{parent}->getImagesDir;
+
+        
+        my $newFile = GCUtils::pathToUnix(File::Spec->rel2abs($self->{file}));
+        $self->{data}->{options}->file($newFile);
+        $self->{parent}->{file} = $newFile;
+
+        # We re-generate it because it could have changed with new file name
+        my $newImages = $self->{parent}->getImagesDir;
+        if ($prevImages ne $newImages)
+        {
+            # The last parameter is for copy. When saving a new file, we move.
+            $self->{data}->setNewImagesDirectory($newImages, $prevImages, 1);
+        }
+
         $self->{data}->{model} = $self->{model};
+        $self->{data}->{backend} = new GCBackend::GCBeXmlParser($self->{parent})
+            if ! $self->{data}->{backend};
+        $self->{data}->{options}->useRelativePaths(0) if $self->{useStdOut};
         $self->{data}->save;
+        $self->{data}->{options}->useRelativePaths($previousRelativePaths);
         $self->{data}->{options}->file($previousFile);
         open IN, $self->{file};
         if ($self->{useStdOut})
@@ -295,13 +317,12 @@ use strict;
     sub import
     {
         my ($self, $file, $prefs) = @_;
-
         $self->{importOptions}->{parent} = $self->{parent};
         $self->{importOptions}->{file} = $file;
         $self->{importOptions}->{fields} = $self->{fields};
         $self->parsePrefs($prefs, $self->{importOptions});
         $self->{importer}->{options} = $self->{importOptions};
-        $self->{data}->{itemArray} = $self->{importer}->getItemsArray($file);
+        $self->{data}->setItemsList($self->{importer}->getItemsArray($file));
         $self->setModel($self->{importer}->getModelName);
         $self->{data}->{model} = $self->{model}
             if $self->{data};
@@ -318,7 +339,7 @@ use strict;
         $self->{exportOptions}->{file} = $self->{file};
         $self->{exportOptions}->{collection} = $self->{file};
         $self->{exportOptions}->{fieldsInfo} = $self->{model}->{fieldsInfo};
-        $self->{exportOptions}->{items} = $self->{data}->{itemArray};
+        $self->{exportOptions}->{items} = $self->{data}->getItemsList;
         $self->{exportOptions}->{defaultImage} = $ENV{GCS_SHARE_DIR}.'/logos/no.png';
         $self->parsePrefs($prefs, $self->{exportOptions});
         $self->{data}->{model} = $self->{model}
@@ -326,7 +347,7 @@ use strict;
 
         $self->{exporter}->process($self->{exportOptions});
 
-        open IN, $self->{exportOptions}->{file};
+        CORE::open IN, $self->{exportOptions}->{file};
         if ($self->{useStdOut})
         {
             print $_ while (<IN>);
@@ -344,10 +365,7 @@ use strict;
         (undef, my $picture) = tmpnam;
         $picture .= $suffix;
 
-        my $browser = LWP::UserAgent->new;
-        $browser->proxy(['http'], $self->{parent}->{options}->proxy);
-        $browser->agent($self->{agent});
-        $browser->get($pictureUrl, ':content_file' => $picture);
+        GCUtils::downloadFile($pictureUrl, $picture, $self->{parent});
         push @{$self->{toBeRemoved}}, $picture;
         return $picture;
     }
