@@ -63,7 +63,7 @@ $hasAboutDialog = 0 if $@;
         my ($proto, $parent, $title, $okLabel, $extraAfter, @extraButtons) = @_;
         my $class = ref($proto) || $proto;
         my @buttons;
-        if ($okLabel =~ /^gtk-/)
+        if ((defined $okLabel) && ($okLabel =~ /^gtk-/))
         {
             @buttons = ('gtk-cancel'=>'cancel', $okLabel=>'ok');
             $okLabel = '';
@@ -165,7 +165,7 @@ $hasAboutDialog = 0 if $@;
             $self->{about}->set_comments($parent->{lang}->{AboutDesc});
             $self->{about}->set_version($version);
             $self->{about}->set_authors('', @authors);
-            $self->{about}->set_documenters(("",'Tian','http://www.gcstar.org/doc'));
+            $self->{about}->set_documenters(("",'Christian Jodar (Tian)','http://wiki.gcstar.org/'));
             $self->{about}->set_artists("",$parent->{lang}->{AboutDesign}, 'http://le-spektre.org/');
             $self->{about}->set_copyright($parent->{lang}->{AboutLicense});
             $self->{about}->set_license($license);
@@ -830,9 +830,12 @@ $hasAboutDialog = 0 if $@;
         $toId++ if $toId < $toTotal;
         $toId = 0 if ($toId < 0);
 
-        splice(@{$self->{$from}->{data}}, $fromId, 1);
+        if (!$self->{permanent}->{$fromString})
+        {
+            splice(@{$self->{$from}->{data}}, $fromId, 1);
+            splice(@{$self->{$from.'Array'}}, $fromId, 1);
+        }
         splice(@{$self->{$to}->{data}}, $toId, 0, $fromString);
-        splice(@{$self->{$from.'Array'}}, $fromId, 1);
         splice(@{$self->{$to.'Array'}}, $toId, 0, $fromString);
         
         if ($to eq 'unused')
@@ -880,7 +883,10 @@ $hasAboutDialog = 0 if $@;
         my %tmpMap;
         $tmpMap{$_} = 1 foreach (@$initial);
         $self->{usedArray} = $new;
-        delete $tmpMap{$_} foreach (@$new);
+        foreach (@$new)
+        {
+            delete $tmpMap{$_} if !$self->{permanent}->{$_};
+        }
         my @tmpArray = sort keys %tmpMap;
         $self->{unusedArray} = \@tmpArray;
         
@@ -910,10 +916,22 @@ $hasAboutDialog = 0 if $@;
     sub fillList
     {
         my $self = shift;
-        my @array = sort @{$self->getInitData};
+        my @array = grep !$self->{permanent}->{$_}, sort @{$self->getInitData};
         $self->setListData(\@array);
     }
-                            
+
+    sub addToPermanent
+    {
+        my ($self, $id) = @_;
+        $self->{permanent}->{$id} = 1;
+    }
+            
+    sub removeFromPermanent
+    {
+        my ($self, $id) = @_;
+        delete $self->{permanent}->{$id};
+    }
+            
     sub new
     {
         my ($proto, $parent, $title) = @_;
@@ -1023,7 +1041,6 @@ $hasAboutDialog = 0 if $@;
     {
         my $self = shift;
         my @array;
-        
         @array = keys %{$self->{fieldNameToId}};
         return \@array;
     }
@@ -1127,13 +1144,14 @@ $hasAboutDialog = 0 if $@;
 
     sub new
     {
-        my ($proto, $parent, $title, $preList, $isIdList) = @_;
+        my ($proto, $parent, $title, $preList, $isIdList, $ignoreField) = @_;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new(
                                 $parent,
                                 $title
                             );
 
+        $self->{ignoreField} = $ignoreField;
         bless ($self, $class);
         $self->{lang} = $parent->{lang};
         $self->{tooltips} = Gtk2::Tooltips->new();
@@ -1176,17 +1194,20 @@ $hasAboutDialog = 0 if $@;
         $self->{fieldNameToId} = {};
 
         my $model = $self->{parent}->{parent}->{model};
-        my $groups = $model->getGroups;
-        while (my ($key, $value) = each %{$model->{fieldsInfo}})
+        if ($model)
         {
-            next if !$value->{displayed};
-            my $displayed = $groups->{$value->{group}}->{displayed}
-                          . $model->getDisplayedText('Separator')
-                          . $value->{displayed};
-            $self->{fieldNameToId}->{$displayed} = $key;
-            $self->{fieldIdToName}->{$key} = $displayed;
+            my $groups = $model->getGroups;
+            while (my ($key, $value) = each %{$model->{fieldsInfo}})
+            {
+                next if !$value->{displayed};
+                my $displayed = $groups->{$value->{group}}->{displayed}
+                              . $model->getDisplayedText('Separator')
+                              . $value->{displayed};
+                $self->{fieldNameToId}->{$displayed} = $key;
+                $self->{fieldIdToName}->{$key} = $displayed;
+            }
+            $self->{model} = $model;
         }
-        $self->{model} = $model;
         $self->{scrollPanelUnused}->set_size_request(200,-1);
         $self->{scrollPanelUsed}->set_size_request(200,-1);        
         $self->fillList if ! $preList;
@@ -1199,6 +1220,21 @@ $hasAboutDialog = 0 if $@;
         $self->saveList(\@{$self->{usedArray}});
         return $self;
     }
+
+    sub addIgnoreField
+    {
+        my ($self, $ignoreField) = @_;
+        $self->{ignoreString} = $self->{parent}->{lang}->{FieldsListIgnore};
+        $self->{fieldNameToId}->{$self->{ignoreString}} = $ignoreField;
+        $self->{fieldIdToName}->{$ignoreField} = $self->{ignoreString};
+        $self->addToPermanent($self->{ignoreString});
+    }
+
+    sub removeIgnoreField
+    {
+        my ($self) = @_;
+        $self->removeFromPermanent($self->{ignoreString});
+    }
 }
 
 
@@ -1312,7 +1348,7 @@ $hasAboutDialog = 0 if $@;
         $file = Cwd::realpath($file)
             if -e $file;
         eval {
-           $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
+            $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
             $self->{dialog}->set_current_folder($file.'/')
                 if (($self->{type} eq 'new') && 
                 (($empty) || (-d $file)));
@@ -1391,6 +1427,7 @@ $hasAboutDialog = 0 if $@;
         if ($value)
         {
             $self->{preview} = new GCItemImage($self->{parent}->{options}, $self->{parent}->{defaultImage},1);
+            $self->{preview}->setImmediate;
             if ($self->{type} eq 'new')
             {
                 $self->{dialog}->signal_connect('update-preview' => \&updatePreview, $self);
@@ -1500,7 +1537,7 @@ $hasAboutDialog = 0 if $@;
     {
         my ($proto, $parent, $title) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent, 'GCstar - '.$title,
+        my $self  = $class->SUPER::new($parent, $title,
                                        'gtk-go-forward' => 'no');
         bless ($self, $class);
         
@@ -1516,4 +1553,57 @@ $hasAboutDialog = 0 if $@;
     }
 }
 
+{
+    package GCCriticalErrorDialog;
+    use base 'Gtk2::MessageDialog';
+    
+    sub new
+    {
+        my ($proto, $parent, $message) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($parent,
+                                       [qw/modal destroy-with-parent/],
+                                       'error',
+                                       'ok',
+                                        $message);
+        bless ($self, $class);
+        $self->set_position('center-on-parent');
+        $self->{parent} = $parent;
+        $self->{message} = $message;
+        
+        my $label = $parent->{lang}->{MenuBugReport};
+        $label =~ s/_//g;
+        my $bugReport = new Gtk2::Button($label);
+        $self->action_area->pack_start($bugReport,0,0,0);
+        $self->action_area->reorder_child($bugReport,0);
+        $bugReport->show_all;
+        $bugReport->signal_connect('clicked' => sub {
+            $self->reportBug;
+        });
+        
+        return $self;
+    }
+    
+    sub show
+    {
+        my $self = shift;
+        $self->run;
+        $self->destroy;
+    }
+    
+    sub reportBug
+    {
+        my $self = shift;
+        my $subject = $self->{parent}->{lang}->{BugReportSubject};
+        my $message = '
+'.$self->{parent}->{lang}->{BugReportVersion}.$self->{parent}->{lang}->{Separator}.$self->{parent}->{version}.'
+'.$self->{parent}->{lang}->{BugReportPlatform}.$self->{parent}->{lang}->{Separator}.$^O.'
+
+'.$self->{parent}->{lang}->{BugReportMessage}.$self->{parent}->{lang}->{Separator}.$self->{message}.'
+
+'.$self->{parent}->{lang}->{BugReportInformation}.$self->{parent}->{lang}->{Separator};
+        $self->{parent}->reportBug(undef, $subject, $message);
+    }
+}
+
 1;
