@@ -25,8 +25,6 @@ package GCDisplay;
 use strict;
 use GCUtils;
 
-my $firstYear = 1895;
-
 {
     package GCFilterSearch;
 
@@ -221,7 +219,6 @@ my $firstYear = 1895;
     sub removeTemporaryFilters
     {
         my $self = shift;
-        
         foreach (keys %{$self->{info}})
         {
             foreach my $i(0 .. scalar @{$self->{info}->{$_}} - 1)
@@ -238,60 +235,71 @@ my $firstYear = 1895;
         $self->{model} = $model;
     }
 
-    sub testAnd
+    sub test
     {
         my ($self, $info) = @_;
         return 1 if $self->{cleared};
+        my $testAnd = $self->{mode} eq 'and';
         foreach my $field(keys %{$self->{info}})
         {
-            my $value = $info->{$field};
-            foreach my $info(@{$self->{info}->{$field}})
+            my $value = '';
+            if ($field eq $GCFieldSelector::anyFieldValue)
             {
-                if ($info->{preprocess})
+                # We concatenate all of the values here to perform the
+                # the test on all of the fields in one shot
+                foreach my $key(keys %$info)
                 {
-                    my $preProcess = 'GCPreProcess::'.$info->{preprocess};
+                    if (ref($info->{$key}) eq 'ARRAY')
+                    {
+                        $value .= GCPreProcess::otherList($info->{$key});
+                    }
+                    else
+                    {
+                        $value .= $info->{$key};
+                    }
+                }
+            }
+            else
+            {
+                $value = $info->{$field};
+            }
+            foreach my $filter(@{$self->{info}->{$field}})
+            {
+                next if !$filter;
+                if ($filter->{preprocess})
+                {
+                    my $preProcess = 'GCPreProcess::'.$filter->{preprocess};
                     eval {
                         no strict qw/refs/;
                         $value = $preProcess->($value);
                     };
                 }
-                return 0 if $info
-                         && ! $info->{comp}->($value, $info->{value});
-            }
-        }
-        return 1;
-    }
-
-    sub testOr
-    {
-        my ($self, $info) = @_;
-        return 1 if $self->{cleared};
-        foreach my $field(keys %{$self->{info}})
-        {
-            my $value = $info->{$field};
-            foreach my $info(@{$self->{info}->{$field}})
-            {
-                if ($info->{preprocess})
+                if ($testAnd)
                 {
-                    my $preProcess = 'GCPreProcess::'.$info->{preprocess};
-                    eval {
-                        no strict qw/refs/;
-                        $value = $preProcess->($value);
-                    };
+                    return 0 if ! $filter->{comp}->($value, $filter->{value});
+                }
+                else
+                {
+                    return 1 if $filter->{comp}->($value, $filter->{value});
                 }
-                return 1 if $info
-                         && $info->{comp}->($value, $info->{value});
             }
         }
-        return 0;
+        return $testAnd;
     }
 
     sub setMode
     {
         my ($self, $mode) = @_;
         $mode ||= 'and';
-        *test = \&testAnd if $mode eq 'and';
-        *test = \&testOr if $mode eq 'or';
+        #*test = \&testAnd if $mode eq 'and';
+        #*test = \&testOr if $mode eq 'or';
+        $self->{mode} = $mode;
+    }
+    
+    sub isEmpty
+    {
+        my $self = shift;
+        return $self->{cleared};
     }
 }
 
@@ -308,7 +316,7 @@ use Gtk2;
     {
         my $self = shift;
         
-        my $info = $self->{parent}->{items}->{filterSearch}->{info};
+        my $info = $self->{parent}->{filterSearch}->{info};
         
         foreach (@{$self->{fields}})
         {
@@ -351,7 +359,6 @@ use Gtk2;
         my $self = shift;
 
         $self->initValues;
-        
         $self->SUPER::show();
         $self->show_all;
         $self->{search} = undef;
@@ -382,7 +389,6 @@ use Gtk2;
     sub clear
     {
         my $self = shift;
-
         foreach (@{$self->{fields}})
         {
             $self->{$_}->clear;
@@ -407,7 +413,7 @@ use Gtk2;
                                        'gtk-clear' => 'reject',
                                       );
         bless ($self, $class);
-
+        $self->set_position('center-on-parent');
         $self->{parent} = $parent;
         $self->{comparisonConvertor} = new GCComparisonSelector($parent);
         $self->{layoutTable} = new Gtk2::Table(1,3,0);
@@ -419,16 +425,109 @@ use Gtk2;
         return $self;
     }
     
+    sub createWidget
+    {
+        my ($self, $info, $comparison) = @_;
+        my $widget;
+        my $withComparisonLabel = 1;
+
+        if ($info->{type} eq 'short text')
+        {
+            if ($comparison eq 'range')
+            {
+                $widget = new GCRange('text', $self->{parent}->{lang});
+                $widget->setWidth(16);
+                $withComparisonLabel = 0;
+            }
+            else
+            {
+                $widget = new GCShortText;
+            }
+            $widget->signal_connect('activate' => sub {$self->response('ok')} );
+        }
+        elsif ($info->{type} eq 'number')
+        {
+            #If we want to have values that are less to the specified one,
+            #we use max as default to be sure everything will be returned
+            #in that case.
+            my $default = $info->{min};
+            $default = $info->{max}
+                if $comparison =~ /^l/;
+            if (exists $info->{min})
+            {
+                if ($comparison eq 'range')
+                {
+                    $widget = new GCRange('number',
+                                          $self->{parent}->{lang},
+                                          $info->{min},
+                                          $info->{max},
+                                          $info->{step});
+                    $widget->setWidth(16);
+                    $withComparisonLabel = 0;
+                }
+                else
+                {
+                    $widget = new GCNumeric($default,
+                                            $info->{min},
+                                            $info->{max},
+                                            $info->{step});
+                }
+            }
+            else
+            {
+                if ($comparison eq 'range')
+                {
+                    $widget = new GCRange('numeric text', $self->{parent}->{lang});
+                    $widget->setWidth(16);
+                    $withComparisonLabel = 0;
+                }
+                else
+                {
+                    $widget = new GCCheckedText('0-9.');
+                }
+            }
+        }
+        elsif ($info->{type} eq 'checked text')
+        {
+            $widget = new GCCheckedText($info->{format});
+        }
+        elsif (($info->{type} eq 'history text')
+            || (($info->{type} =~ /list/)
+             && ($info->{history} ne 'false')))
+        {
+            $widget = new GCHistoryText;
+        }
+        elsif ($info->{type} eq 'options')
+        {
+            $widget = new GCMenuList;
+            $widget->setValues($self->{model}->getValues($info->{values}), $info->{separator});
+        }
+        elsif ($info->{type} eq 'yesno')
+        {
+            $widget = new GCCheckBoxWithIgnore($self->{parent});
+            $withComparisonLabel = 0;
+        }
+        elsif ($info->{type} eq 'date')
+        {
+            $widget = new GCDate($self, $self->{parent}->{lang}, 1);
+        }
+        else
+        {
+            $widget = new GCShortText;
+        }
+        
+        return ($widget, $withComparisonLabel);
+    }
+    
     sub setModel
     {
         my ($self, $model) = @_;
-
+        $self->{model} = $model;
         foreach ($self->{layoutTable}->get_children)
         {
             $self->{layoutTable}->remove($_);
             $_->destroy;
         }
-        #$self->{layoutTable}->set_size_request(-1,-1);
 
         my $fieldsInfo = $model->{fieldsInfo};
         $self->{fieldsInfo} = $fieldsInfo;
@@ -450,7 +549,6 @@ use Gtk2;
             my $withComparisonLabel;
             foreach my $filter(@filters)
             {
-                $withComparisonLabel = 1;
                 my $field = $filter->{field};
                 if ($field ne 'separator')
                 {
@@ -459,90 +557,10 @@ use Gtk2;
                     $labelText = $model->getDisplayedText($filter->{label}) if $filter->{label};            
                     my $label = new GCLabel($labelText);
                     $self->{layoutTable}->attach($label, 0, 1, $row, $row + 1, 'fill', 'fill', 2 * $GCUtils::margin, 0);
-                    if ($fieldsInfo->{$field}->{type} eq 'short text')
-                    {
-                        if ($filter->{comparison} eq 'range')
-                        {
-                            $self->{$field} = new GCRange('text', $self->{parent}->{lang});
-                            $self->{$field}->setWidth(16);
-                            $withComparisonLabel = 0;
-                        }
-                        else
-                        {
-                            $self->{$field} = new GCShortText;
-                        }
-                        $self->{$field}->signal_connect('activate' => sub {$self->response('ok')} );
-                    }
-                    elsif ($fieldsInfo->{$field}->{type} eq 'number')
-                    {
-                        #If we want to have values that are less to the specified one,
-                        #we use max as default to be sure everything will be returned
-                        #in that case.
-                        my $default = $fieldsInfo->{$field}->{min};
-                        $default = $fieldsInfo->{$field}->{max}
-                            if $filter->{comparison} =~ /^l/;
-                        if (exists $fieldsInfo->{$field}->{min})
-                        {
-                            if ($filter->{comparison} eq 'range')
-                            {
-                                $self->{$field} = new GCRange('number',
-                                                              $self->{parent}->{lang},
-                                                              $fieldsInfo->{$field}->{min},
-                                                              $fieldsInfo->{$field}->{max},
-                                                              $fieldsInfo->{$field}->{step});
-                                $self->{$field}->setWidth(16);
-                                $withComparisonLabel = 0;
-                            }
-                            else
-                            {
-                                $self->{$field} = new GCNumeric($default,
-                                                                $fieldsInfo->{$field}->{min},
-                                                                $fieldsInfo->{$field}->{max},
-                                                                $fieldsInfo->{$field}->{step});
-                            }
-                        }
-                        else
-                        {
-                            if ($filter->{comparison} eq 'range')
-                            {
-                                $self->{$field} = new GCRange('numeric text', $self->{parent}->{lang});
-                                $self->{$field}->setWidth(16);
-                                $withComparisonLabel = 0;
-                            }
-                            else
-                            {
-                                $self->{$field} = new GCCheckedText('0-9.');
-                            }
-                        }
-                    }
-                    elsif ($fieldsInfo->{$field}->{type} eq 'checked text')
-                    {
-                        $self->{$field} = new GCCheckedText($fieldsInfo->{$field}->{format});
-                    }
-                    elsif (($fieldsInfo->{$field}->{type} eq 'history text')
-                        || (($fieldsInfo->{$field}->{type} =~ /list/)
-                         && ($fieldsInfo->{$field}->{history} ne 'false')))
-                    {
-                        $self->{$field} = new GCHistoryText;
-                    }
-                    elsif ($fieldsInfo->{$field}->{type} eq 'options')
-                    {
-                        $self->{$field} = new GCMenuList;
-                        $self->{$field}->setValues($model->getValues($fieldsInfo->{$field}->{'values'}), $fieldsInfo->{$field}->{separator});
-                    }
-                    elsif ($fieldsInfo->{$field}->{type} eq 'yesno')
-                    {
-                        $self->{$field} = new GCCheckBoxWithIgnore($self->{parent});
-                        $withComparisonLabel = 0;
-                    }
-                    elsif ($fieldsInfo->{$field}->{type} eq 'date')
-                    {
-                        $self->{$field} = new GCDate($self, $self->{parent}->{lang}, 1);
-                    }
-                    else
-                    {
-                        $self->{$field} = new GCShortText;
-                    }
+
+                    ($self->{$field}, $withComparisonLabel) = 
+                        $self->createWidget($fieldsInfo->{$field},
+                                            $filter->{comparison});
                     if ($withComparisonLabel
                     && ($filter->{comparison} ne 'eq'))
                     {
@@ -553,6 +571,7 @@ use Gtk2;
                         $self->{layoutTable}->attach($labelComparison, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
                     }
                     $self->{layoutTable}->attach($self->{$field}, 2, 3, $row, $row + 1, ['fill', 'expand'], 'expand', 0, 0);
+                    $self->{$field}->grab_focus if $row == 2;
                 }
                 else
                 {
@@ -561,7 +580,7 @@ use Gtk2;
                 $row++;
             }
         }
-        #$self->resize(1,1);
+        $self->{layoutTable}->show_all;
     }
 }
 
@@ -576,7 +595,12 @@ use Gtk2;
     {
         my $self = shift;
         $self->{layoutTable}->resize($self->{nbFields} + 1, 3);
-        my $field = new GCFieldSelector(0, $self->{model});
+        my $field = new GCFieldSelector(0, $self->{model}, 0, 1);
+        $field->{number} = $self->{nbFields};
+        $field->signal_connect('changed' => sub {
+            my $fs = shift;
+            $self->updateField($fs->{number}, $fs->getValue);
+        });
         push @{$self->{fields}}, $field;
         $self->{layoutTable}->attach($field, 0, 1, $self->{nbFields}, $self->{nbFields}+1,
                                      ['expand', 'fill'], 'fill', 0, 0);
@@ -656,6 +680,7 @@ use Gtk2;
         my $self  = $class->SUPER::new($parent);
         bless ($self, $class);
 
+        $self->{parent} = $parent;
         $self->vbox->remove($self->{layoutTable});
 
         my $allTable = new Gtk2::Table(7,3,0);
@@ -722,7 +747,59 @@ use Gtk2;
             $_->destroy;
         }
         $self->addItem;
-        $self->{remove}->set_sensitive(0)
+        $self->{remove}->set_sensitive(0);
+        $self->{layoutTable}->show_all;
+    }
+
+    sub updateField
+    {
+        my ($self, $idx, $field) = @_;
+        my $widget = $self->{values}->[$idx];
+        $self->{layoutTable}->remove($widget);
+        $widget->destroy;
+
+        my $newWidget;
+        my $info = $self->{model}->{fieldsInfo}->{$field};
+        ($newWidget, undef) = $self->createWidget($info);
+#        my $type = $self->{model}->{fieldsInfo}->{$field}->{type};
+#        if ($type eq 'history text')
+#        {
+#            $newWidget = new GCHistoryText;
+#            $newWidget->setValues($self->{parent}->{panel}->getValues($field));
+#        }
+#        elsif  ($type eq 'single list')
+#        {
+#            $newWidget = new GCHistoryText;
+#            $newWidget->setValues($self->{parent}->{panel}->getValues($field)->[0]);            
+#        }
+#        elsif ($type eq 'number')
+#        {
+#            $newWidget = new GCCheckedText('0-9.');
+#        }
+#        elsif ($type eq 'date')
+#        {
+#            $newWidget = new GCDate($self, $self->{parent}->{lang}, 1);
+#            $newWidget->setFormat($self->{parent}->{options}->dateFormat)
+#                if $self->{parent}->{options}->dateFormat;
+#        }
+#        else
+#        {
+#            $newWidget = new GCShortText;
+#        }
+
+        if ($info->{type} eq 'history text')
+        {
+            $newWidget->setValues($self->{parent}->{panel}->getValues($field));
+        }
+        elsif ($info->{type} eq 'single list')
+        {
+            $newWidget->setValues($self->{parent}->{panel}->getValues($field)->[0]);            
+        }
+
+        $self->{values}->[$idx] = $newWidget;
+        $self->{layoutTable}->attach($newWidget, 2, 3, $idx, $idx+1,
+                                     ['expand', 'fill'], 'fill', 0, 0);
+        $newWidget->show_all;
     }
 }
 
