@@ -62,6 +62,7 @@ use GCExportImport;
         $options->{items} = $self->{parent}->{items}->getItemsList($filter);
         $options->{collection} = $self->{parent}->{options}->file;
         $options->{defaultImage} = $self->{parent}->{defaultImage};
+        $options->{sorter} = $self->{sorter}->getValue;
     }
 
     sub setModel
@@ -79,12 +80,15 @@ use GCExportImport;
 
         $self->{fieldsButtonLabel} = $parent->{lang}->{ExportFieldsTitle};
         $self->{fieldsTip} = $parent->{lang}->{ExportFieldsTip};
-
+        $self->{sortLabel} = GCLabel->new($parent->{lang}->{ExportSortBy});
         $self->{filter} = new Gtk2::CheckButton($parent->{lang}->{ExportFilter});
-        $self->{dataTable}->resize(2, 2);
+        $self->{sorter} = new GCFieldSelector(0, undef, 0);
+        $self->{dataTable}->resize(3, 2);
         $self->{dataTable}->attach($self->{filter}, 0, 2, 0, 1, 'fill', 'fill', 0, 0);
-        $self->{dataTable}->attach($self->{labelFile}, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
-        $self->{dataTable}->attach($self->{file}, 1, 2, 1, 2, ['fill', 'expand'], 'fill', 0, 0);
+        $self->{dataTable}->attach($self->{sortLabel}, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
+        $self->{dataTable}->attach($self->{sorter}, 1, 2, 1, 2, 'fill', 'fill', 0, 0);
+        $self->{dataTable}->attach($self->{labelFile}, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
+        $self->{dataTable}->attach($self->{file}, 1, 2, 2, 3, ['fill', 'expand'], 'fill', 0, 0);
 
 #        $self->vbox->pack_start(new Gtk2::HSeparator, 0, 0, 5);
 #        $self->vbox->pack_start($self->{filter},0,0,0);
