@@ -114,6 +114,11 @@ use GCExportImport;
         return 1;
     }    
 
+    sub wantsSort
+    {
+        return 0;
+    }
+
     #End of methods to be overriden
     
     sub getUniqueImageFileName
@@ -125,9 +130,8 @@ use GCExportImport;
     
     sub duplicatePicture
     {
-        my ($self, $item, $field, $dir, $title) = @_;
+        my ($self, $orig, $field, $dir, $title) = @_;
         
-        my $orig = $item->{$field};
         $self->{saved}->{$field} = $orig;
         my $newPic = $orig;
         if ($orig && $self->{options}->{withPictures})
@@ -172,20 +176,42 @@ use GCExportImport;
             $info->{$_} = $self->{saved}->{$_};
         }
     }
-    
+
     sub transformValue
     {
         my ($self, $value, $field) = @_;
-
+        if ($self->{options}->{fieldsInfo}->{$field}->{type} eq 'image')
+        {
+            if ($self->{copyPictures})
+            {
+                $value = $self->duplicatePicture($value, $field,
+                                                 $self->{dirName},
+                                                 $self->{currentItem}->{
+                                                     $self->{model}->{commonFields}->{title}
+                                                 });
+            }
+            return $value;
+        }
         return $self->{options}->{originalList}->transformValue($value, $field);
     }
-    
+
+    sub getStockLabel
+    {
+        my ($self, $stock) = @_;
+        my $item = Gtk2::Stock->lookup($stock);
+        my $label = '';
+        ($label = $item->{label}) =~ s/_//
+            if $item;
+        return $label;
+    }
+
     # If you need really specific processing, you can instead override the process method
     sub process
     {
         my ($self, $options) = @_;
 
         $self->{saved} = {};
+        $self->{currentItem} = undef;
 
         $self->{options} = $options;
 
@@ -215,32 +241,59 @@ use GCExportImport;
                                     .basename($self->{options}->{defaultImage});
        }
 
-        $self->preProcess;
+        if (! $self->preProcess)
+        {
+            return $self->getEndInfo;
+        }
 
         my @tmpArray = @{$options->{items}};
-
+        if ($self->wantsSort)
+        {
+            my $sorter = $self->{options}->{sorter};
+            use locale;
+            @tmpArray = sort {
+                my $val1 = uc $self->{options}->{originalList}->transformValue($a->{$sorter}, $sorter);
+                my $val2 = uc $self->{options}->{originalList}->transformValue($b->{$sorter}, $sorter);
+                return $val1 cmp $val2;
+            } @tmpArray;
+        }
         my $header = $self->getHeader($#tmpArray + 1);
         my $body = '';
 
         my $item;
         my $idx = 0;
+        my $copyPictures = 0;
+        my @copiedPicturesFields;
+        if ($self->{options}->{withPictures})
+        {
+            # If we don't specify fields, the pictures will be copied with transform value
+            # This one is used now
+            $copyPictures = 1
+                if $self->wantsFieldsSelection;
+            # This one will be used by transform value
+            $self->{copyPictures} = !$copyPictures;
+            foreach my $field(@{$self->{options}->{fields}})
+            {
+                push @copiedPicturesFields, $field
+                    if $self->{options}->{fieldsInfo}->{$field}->{type} eq 'image';
+            }
+        }
         foreach $item(@tmpArray)
         {
-            if ($self->{options}->{withPictures})
+            $self->{currentItem} = $item;
+            if ($copyPictures)
             {
-                foreach my $pic(@{$self->{model}->{managedImages}})
+                foreach my $pic(@copiedPicturesFields)
                 {
-                    $item->{$pic} = $self->duplicatePicture($item, $pic, $self->{dirName},
+                    $item->{$pic} = $self->duplicatePicture($item->{$pic}, $pic, $self->{dirName},
                                                             $item->{$self->{model}->{commonFields}->{title}});
                 }
             }
-
             $body .= $self->getItem($item, $idx);
-
             $self->restoreInfo($item);
-
-	        $idx++;
+            $idx++;
         }
+        $self->{currentItem} = undef;
         my $footer = $self->getFooter($#tmpArray + 1);
 
         $self->postProcess(\$header, \$body);
