@@ -108,24 +108,35 @@ use GCExport::GCExportBase;
 
         $self->setModelsDir;
 
+        my $defaultModel = '';
         foreach (glob $self->{modelsDir}.'/*')
         {
             next if ($_ =~ /\/CVS$/) || ($_ =~ /\.png$/);
             (my $mod = basename($_)) =~ s/_/ /g;
             $self->{modelsFiles} .= $mod.',';
+            $defaultModel = $mod if !$defaultModel;
         }
-
+        $self->{modelsFiles} .= 'UseFile,';
         return [
         {
             name => 'template',
             type => 'options',
             label => 'FileTemplate',
             valuesList => $self->{modelsFiles},
-            #changeCallback => sub {$self->checkAutoModel}
+            default => $defaultModel,
+            changedCallback => sub {shift; $self->checkFileField(@_)},
             buttonLabel => 'Preview',
             buttonCallback => sub {shift; $self->preview(@_)}
         },
                       
+        {
+            name => 'modelFile',
+            type => 'file',
+            label => 'TemplateExternalFile',
+            default => '',
+            insensitive => 1,
+        },
+	    
         {
             name => 'title',
             type => 'short text',
@@ -159,6 +170,14 @@ use GCExport::GCExportBase;
         ]
     }
     
+    sub checkFileField
+    {
+        my ($self, $data) = @_;
+        my ($parent, $list) = @{$data};
+        return if ! $parent->{options}->{modelFile};
+        $parent->{options}->{modelFile}->set_sensitive($list->getValue eq 'UseFile');
+    }
+
     sub preview
     {
         my ($self, $data) = @_;
@@ -205,6 +224,11 @@ use GCExport::GCExportBase;
         return 0;
     }    
 
+    sub wantsSort
+    {
+        return 1;
+    }
+
     sub transformData
     {
         my ($self, $item, $field, $asATable) = @_;
@@ -215,11 +239,11 @@ use GCExport::GCExportBase;
             return '' if !$data;
             my $result = '';
             my $i = 1;
-            foreach (@{$data->{line}})
+            foreach (@{$data})
             {
                 my $class = ($i % 2) ? 'even' : 'odd';
                 $result .= " <tr class=\"$class\">\n";
-                foreach my $item(@{$_->{col}})
+                foreach my $item(@{$_})
                 {
                     $result .= "  <td>$item</td>\n";
                 }
@@ -277,15 +301,30 @@ use GCExport::GCExportBase;
     sub preProcess
     {
         my $self =  shift;
-	
+
+        $self->{errors} = 0;
         $self->setModelsDir;
-        $self->{options}->{template} =~ s/ /_/;
-	
+        my $template = $self->{options}->{template};
+        my $file;
         my $model;
-        my $file = $self->{modelsDir}.'/'.$self->{options}->{template};
-        $file =~ s/"//g;
-        #"
-        open FILE, $file;
+        if ($template eq 'UseFile')
+        {
+            $file = $self->{options}->{modelFile};
+            if ( ! -e $file)
+            {
+                $self->{errors} = $self->getLang->{ModelNotFound};
+                return 0;
+            }
+        }
+        else
+        {
+            $template =~ s/ /_/;
+            $file = $self->{modelsDir}.'/'.$self->{options}->{template};
+            $file =~ s/"//g;
+            #"
+        }
+        # The problem should only happen when using command line, so a die is enough.
+        open FILE, $file or die "\nModel $template doesn't exist for this kind of collection";
         binmode(FILE, ':utf8' );
         $model = do { local $/; <FILE> };
         close FILE;
@@ -346,6 +385,7 @@ use GCExport::GCExportBase;
         $self->{item} = $2;
         $self->{footer} = $3;
         $self->{post} = $4;
+        return 1;
 	}
 
     sub getHeader
@@ -357,7 +397,7 @@ use GCExport::GCExportBase;
         $self->{total} = $total;
         $result =~ s/\$\$PAGETITLE\$\$/$self->{options}->{title}/g;
         $result =~ s/\$\$TOTALNUMBER\$\$/$total/g;
-        $result =~ s/\$\$ITEMS\$\$/$self->{model}->getDisplayedText('Items')/eg;
+        $result =~ s/\$\$ITEMS\$\$/$self->{model}->getDisplayedItems/eg;
 
         #Search form
         $result =~ s/\$\$FORM_INPUT\$\$/$self->getLang->{InputTitle}/eg;
@@ -436,8 +476,12 @@ use GCExport::GCExportBase;
 
         $result =~ s/\$\$IDX\$\$/$idx/g;
         $result =~ s/\$\$TOP\$\$/$self->getLang->{Top}/eg;
+        $result =~ s/\$\$BOTTOM\$\$/$self->getLang->{Bottom}/eg;
         $result =~ s/\$\$TOTALNUMBER\$\$/$total/g;
 
+        # Stock labels
+        $result =~ s/\$\$(gtk-[^\$]*)\$\$/$self->getStockLabel($1)/eg;
+
         #Multiple list displayed as a table
         $result =~ s/\$\$([a-zA-Z0-9_]*)_TABLE\$\$/$self->transformData($item, $1, 1)/eg;
 
@@ -467,6 +511,11 @@ use GCExport::GCExportBase;
     {
         my $self = shift;
         
+        if ($self->{errors})
+        {
+            return ($self->{errors}, 'error');
+        }
+        
         my $message = '';
         
         if ($self->{options}->{open})
