@@ -86,7 +86,7 @@ use GCExport::GCExportBase;
 
         if ($self->{model}->getName)
         {
-            $self->{modelsDir} = $ENV{GCS_SHARE_DIR}.'/xml_models'.$self->{model}->getName;        
+            $self->{modelsDir} = $ENV{GCS_SHARE_DIR}.'/xml_models/'.$self->{model}->getName;
             foreach (glob $self->{modelsDir}.'/*')
             {
                 next if $_ =~ /\/CVS$/;
@@ -147,7 +147,7 @@ use GCExport::GCExportBase;
             my $file;
             if ($self->{options}->{models} eq 'UseFile')
             {
-                $file = $self->{options}->{file};
+                $file = $self->{options}->{templatefile};
             }
             else
             {
@@ -156,7 +156,6 @@ use GCExport::GCExportBase;
                 $file =~ s/"//g;
                 #"
             }
-
             open FILE, $file;
             #Read full file
             $model = do { local $/; <FILE> };
@@ -170,6 +169,7 @@ use GCExport::GCExportBase;
         $self->{header} = $1;
         $self->{item} = $2;
         $self->{footer} = $3;
+        return 1;
     }
 
     sub getHeader
