@@ -102,6 +102,11 @@ use GCDialogs;
         $self->show_all;
         
         $self->{optionsFrame}->hide if ! $self->{nbOptions};
+        if (($self->{type} eq 'export') && (! $self->{module}->wantsSort))
+        {
+            $self->{sorter}->hide;
+            $self->{sortLabel}->hide;
+        }
         # TODO : Hide File selection when not wanted
         #$self->{fileVbox}->hide if ! $self->{module}->wantsFileSelection;
         
@@ -139,12 +144,13 @@ use GCDialogs;
                     $options{originalList} = $self->{parent}->{items};
                     $options{parent} = $self->{parent};
                     
-                    my $info = $self->{module}->process(\%options);
+                    my ($info, $type) = $self->{module}->process(\%options);
+                    $type ||= 'info';
                     if ($info)
                     {
                         my $dialog = Gtk2::MessageDialog->new($self,
                                                               [qw/modal destroy-with-parent/],
-                                                              'info',
+                                                              $type,
                                                               'ok',
                                                               $info);
 
@@ -152,6 +158,7 @@ use GCDialogs;
                         $dialog->run();
                         $dialog->destroy ;
                     }
+                    $self->{parent}->setNbItems;
                 }
                 else
                 {
@@ -176,9 +183,7 @@ use GCDialogs;
     sub setModule
     {
         my ($self, $module) = @_;
-
         $self->set_title($self->{title}." [".$module->getName."]");
-        
         if ($module->wantsDirectorySelection)
         {
             $self->{file}->setType('select-folder', 0);
@@ -191,6 +196,15 @@ use GCDialogs;
             if ($self->{type} eq 'import');
 
         $module->setModel($self->{parent}->{model});
+        # sorter will only be created for export modules.
+        # It's initialized with the title field
+        if ($self->{sorter})
+        {
+            $self->{sorter}->setModel($self->{parent}->{model});
+            $self->{sorter}->setValue($self->{parent}->{model}->{commonFields}->{title});
+            $self->{sorter}->setValue($module->{options}->{sorter})
+                if exists $module->{options};
+        }
         foreach ($self->{optionsTable}->get_children)
         {
             $self->{optionsTable}->remove($_);
@@ -204,11 +218,21 @@ use GCDialogs;
         my %options;
         my $option;
         my $row = 0;
+        my @widgetSignals;
         foreach $option (@optionsList)
         {
             my $label = $module->getLang->{$option->{label}};
-            $label = $self->{parent}->{model}->getDisplayedText($option->{label})
-                if !$label;
+            if (!$label)
+            {
+                if ($self->{parent}->{model})
+                {
+                    $label = $self->{parent}->{model}->getDisplayedText($option->{label});
+                }
+                else
+                {
+                    $label = $self->{parent}->{lang}->{$option->{label}};
+                }
+            }
             my $widget;
             my @vExpand = ('fill');
             my $type = $option->{type};
@@ -224,8 +248,7 @@ use GCDialogs;
                       ($type eq 'options') ||
                       ($type eq 'file'))
             {
-                my $labelWidget = Gtk2::Label->new($label);
-                $labelWidget->set_alignment(0,0.5);
+                my $labelWidget = GCLabel->new($label);
                 $self->{optionsTable}->attach($labelWidget, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
 
                 if ($type eq 'short text')
@@ -262,8 +285,11 @@ use GCDialogs;
                         push @valuesList, $item;
                     }
                     $widget->setValues(\@valuesList);
-                    $widget->signal_connect('changed' => $option->{changedCallback})
-                        if $option->{changedCallback};
+                    if ($option->{changedCallback})
+                    {
+                        $widget->signal_connect('changed' => $option->{changedCallback}, [$self,$widget]);
+                        push @widgetSignals, [$widget, 'changed'];
+                    }
                 }
                 if ($option->{buttonLabel})
                 {
@@ -300,7 +326,7 @@ use GCDialogs;
 #                });
 #                $widget->pack_start($button, 0,0,0);
 #            }
-            
+            $widget->set_sensitive(0) if $option->{insensitive};
             $widget->setValue($value);
             $options{$option->{name}} = $widget;
             $row++;
@@ -337,6 +363,11 @@ use GCDialogs;
         $self->{nbOptions} = $row;
         $self->{options} = \%options;
         $self->{optionsFrame}->show_all;
+        foreach my $pair(@widgetSignals)
+        {
+            $pair->[0]->signal_emit($pair->[1])
+        }
+        
     }
     
     sub getOptions
