@@ -446,7 +446,7 @@ use GCExtract;
         my $currentAudio = $self->{panel}->audio;
         if ($info->{audioEncoding})
         {
-            $currentAudio->{line}->[0]->{col}->[1] = $info->{audioEncoding};
+            $currentAudio->[0]->[1] = $info->{audioEncoding};
             $result->{audio}->{value} = $currentAudio;
             $result->{audio}->{displayed} = $info->{audioEncoding};
         }
