@@ -49,7 +49,7 @@ use GCExtract;
     sub resetTracks
     {
         my $self = shift;
-        $self->{tracks} = {};
+        $self->{tracks} = [];
         $self->{totalTime} = 0;
         $self->{currentTrack} = 0;
         $self->{firstTrack} = '';
@@ -61,10 +61,8 @@ use GCExtract;
         $self->{currentTrack}++;
         $self->{totalTime} += $time;
         $number = $self->{currentTrack} if !defined $number;
-        push @{$self->{tracks}->{line}},
-            {
-                col => [$number, $title, $self->secondsToString($time)]
-            };
+        push @{$self->{tracks}},
+            [$number, $title, $self->secondsToString($time)];
     }
 
     sub getTracks
@@ -87,7 +85,7 @@ use GCExtract;
 
     sub getM3UInfo
     {
-        my ($self, $file) = shift;
+        my ($self) = @_;
         my $file = $self->{file};
         my $info = {};
         while (<$file>)
@@ -113,7 +111,7 @@ use GCExtract;
 
     sub getPLSInfo
     {
-        my ($self, $file) = shift;
+        my ($self) = @_;
         my $file = $self->{file};
         my $info = {};
         my @tracks;
@@ -154,7 +152,6 @@ use GCExtract;
         {
             if ($self->{hasMP3Info})
             {
-                print "using MP3::Info\n";
                 MP3::Info::use_mp3_utf8(1);
                 my $song = MP3::Info::get_mp3tag($self->{firstTrack});
                 $info->{title} = $song->{ALBUM};
@@ -164,7 +161,6 @@ use GCExtract;
             }
             elsif ($self->{hasMP3Tag})
             {
-                print "using MP3::Tag\n";
                 my $song = MP3::Tag->new($self->{firstTrack});
                 (undef, undef, $info->{artist}, $info->{title}) = $song->autoinfo;
             }
@@ -173,7 +169,6 @@ use GCExtract;
         {
             if ($self->{hasOggVorbisHeader})
             {
-                print "using Ogg::Vorbis::Header::PurePerl\n";
                 my $song = Ogg::Vorbis::Header::PurePerl->new($self->{firstTrack});
                 $info->{title} = ($song->comment('album'))[0];
                 $info->{artist} .= $_.', ' foreach $song->comment('artist');
@@ -206,7 +201,7 @@ use GCExtract;
         close FILE;
         
         my $result;
-        my $firstTrackName = $info->{tracks}->{line}->[0]->{col}->[1];
+        my $firstTrackName = $info->{tracks}->[0]->[1];
         $result->{tracks} = {displayed => $firstTrackName, value => $info->{tracks}};
         foreach (@{$self->{fields}})
         {
