@@ -49,6 +49,13 @@ use strict;
         return 0;
     }
 
+    sub cleanMarkup
+    {
+        my ($self, $text) = @_;
+        $text =~ s|<br ?/?>|\n|g;
+        return GCUtils::encodeEntities($text);
+    }
+
     sub selectAll
     {
     }
@@ -69,7 +76,6 @@ use strict;
             push @result, ($key, $value);
         }
         return @result;
-        
     }
     
     sub valueToDisplayed
@@ -79,6 +85,26 @@ use strict;
         # Here we don't change the value;
         return shift;
     }
+    
+    sub hasChanged
+    {
+        my $self = shift;
+
+        return $self->{hasChanged};
+    }
+    
+    sub resetChanged
+    {
+        my $self = shift;
+        $self->{hasChanged} = 0;        
+    }
+
+    sub activateStateTracking
+    {
+        # We do nothing by default
+        # Other widget should connect a signal handler or something similar
+        # when the content has been changed
+    }
 }
 
 {
@@ -99,6 +125,7 @@ use strict;
         {
             $self->{history}->{$i} = {'' => 1};
         }
+        $self->{listType} = $listType;
     }
 
     sub addHistory
@@ -107,20 +134,22 @@ use strict;
 
         my $value = shift;
         my $i;
-        if (ref($value) eq 'HASH')
+        if (ref($value) eq 'ARRAY')
         {
-            foreach (@{$value->{line}})
+            foreach (@$value)
             {
                 $i = 0;
-                foreach my $item(@{$_->{col}})
+                foreach my $item(@$_)
                 {
                     $self->{history}->{$i}->{$item} = 1;
-                    $i++;                   
+                    $i++;
                 }
             }
         }
         else
         {
+            # The separator used was ; instead of ,
+            $value =~ s/;/,/g if $value !~ /,/;
             my @values = split m/,/, $value;
             foreach (@values)
             {
@@ -128,8 +157,8 @@ use strict;
                 $i = 0;
                 foreach my $item(@items)
                 {
-                    $self->{history}->{$i}->{$item} = 1;
-                    $i++;
+                   $self->{history}->{$i}->{$item} = 1;
+                   $i++;
                 }
             }
         }
@@ -195,6 +224,15 @@ use strict;
         bless ($self, $class);
         return $self;
     }
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        return if $self->{readOnly};
+        $self->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
     
     sub isEmpty
     {
@@ -238,19 +276,30 @@ use strict;
     {
         my $self = shift;
         $self->set_editable(0);
-        # We change the lock sub so it will never change that
-        *lock = sub { return };
+        $self->{readOnly} = 1;
     }
 
     sub lock
     {
         my ($self, $locked) = @_;
-    
+        return if $self->{readOnly};
         #$self->can_focus(!$locked);
         $self->set_editable(!$locked);
     }
 }
 
+our $hasSpellChecker;
+BEGIN {
+    eval 'use Gtk2::Spell';
+    if ($@)
+    {
+        $hasSpellChecker = 0;
+    }
+    else
+    {
+        $hasSpellChecker = 1;
+    }
+}
 {
     package GCLongText;
     
@@ -270,11 +319,41 @@ use strict;
         $self->set_shadow_type('in');
         $self->set_policy('automatic', 'automatic');
         #$self->set_size_request(-1,80);
+        
         $self->add($self->{text});
+        $self->{spellChecker} = 0;
 
         bless ($self, $class);
         return $self;
     }
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{text}->get_buffer->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
+    
+    sub setSpellChecking
+    {
+        my ($self, $activate) = @_;
+        return if ! $GCGraphicComponents::hasSpellChecker;
+        if ($activate)
+        {
+            return if $self->{spellChecker};
+            eval {
+                $self->{spellChecker} = Gtk2::Spell->new_attach($self->{text});
+                $self->{spellChecker}->set_language($ENV{LANG});
+            };
+            $self->setSpellChecking(0) if $@;
+        }
+        else
+        {
+            $self->{spellChecker}->detach if $self->{spellChecker};
+            $self->{spellChecker} = 0;
+        }
+    }
     
     sub isEmpty
     {
@@ -297,6 +376,7 @@ use strict;
     {
         my ($self, $text) = @_;
         #$text =~s/<br\/>/\n/g;
+        $text = '' if !defined $text;
         $self->{text}->get_buffer->set_text($text);
     }
     
@@ -332,13 +412,19 @@ use strict;
         my $class = ref($proto) || $proto;
     
         my $self = $class->SUPER::new;
-
         $self->{history} = {'' => 1};
-        
         bless ($self, $class);
         return $self;
     }
-    
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->entry->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -349,7 +435,7 @@ use strict;
     sub selectAll
     {
         my $self = shift;
-        $self->entry->select_region(0, length($self->getValue));
+        $self->entry->select_region(0, -1);
         $self->entry->grab_focus;
     }
 
@@ -393,6 +479,7 @@ use strict;
         my $value = (scalar @_) ? shift : $self->getValue;
         my $noUpdate = shift;
         #$value = ucfirst $value;
+        $value =~ s/^\s*//;
         if (!exists $self->{history}->{$value})
         {
             $self->{history}->{$value} = 1;
@@ -422,7 +509,6 @@ use strict;
     sub setValues
     {
         my ($self, $values) = @_;
-
         $self->{history} = {};
         $self->setDropDown(@$values);
 #        my $previousValue = $self->getValue;
@@ -441,8 +527,6 @@ use strict;
         my $self = shift;
         ($self->get_children)[1]->grab_focus;
         ($self->get_children)[1]->signal_emit('activate');
-#        ($self->get_children)[1]->pressed;
-#        ($self->get_children)[1]->released;
     }
 }
 
@@ -467,7 +551,7 @@ use strict;
         $accel = 0.2 if $values > 100;
         $accel = 0.5 if $values > 500;
         $accel = 1.0 if $values > 2000;
-
+        $default = 0 if $default eq '';
         my $adj = Gtk2::Adjustment->new($default, $min, $max, $step, $pageStep, 0) ;
         my $self = $class->SUPER::new($adj, $accel, $decimals);
         $self->{default} = $default;
@@ -480,6 +564,14 @@ use strict;
         return $self;
     }
 
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -504,6 +596,7 @@ use strict;
     sub setValue
     {
         my ($self, $text) = @_;
+        $text = $self->{default} if $text eq '';
         $self->set_value($text);
     }
     
@@ -586,7 +679,14 @@ use strict;
         
         return $self;
     }
-    
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{from}->activateStateTracking;
+        $self->{to}->activateStateTracking;
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -651,10 +751,10 @@ use strict;
         my $self = shift;
         $self->{dialog} = new GCDateSelectionDialog($self->{mainParent})
             if ! $self->{dialog};
-        $self->{dialog}->date($self->{entry}->get_text);
+        $self->{dialog}->date($self->getValue);
         if ($self->{dialog}->show)
         {
-            $self->{entry}->set_text($self->{dialog}->date);
+            $self->setValue($self->{dialog}->date);
         }
         $self->{parent}->showMe;
     }
@@ -669,7 +769,7 @@ use strict;
         $self->{parent} = $parent;
         $self->getMainParent;
         $self->{reverseDate} = $reverseDate;
-        $self->{entry} = Gtk2::Entry->new_with_max_length(10);
+        $self->{entry} = Gtk2::Entry->new; #_with_max_length(10);
         $self->{entry}->set_width_chars(12);
         $self->{button} = new Gtk2::Button($lang->{PanelDateSelect});
         $self->{button}->signal_connect('clicked' => sub {
@@ -677,10 +777,28 @@ use strict;
         });
         $self->pack_start($self->{entry}, 1, 1, 0);
         $self->pack_start($self->{button}, 0, 0, 0);
-
+        
+        $self->{format} = '%d/%m/%Y';
+        #$self->{format} = '%d %B %Y';
         return $self;
     }
-    
+
+    sub setFormat
+    {
+        my ($self, $format) = @_;
+        my $current = $self->getValue;
+        $self->{format} = $format;
+        $self->setValue($current);
+    }
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{entry}->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -693,13 +811,14 @@ use strict;
         my $self = shift;
         
         my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
-        return $mday.'/'.($mon+1).'/'.(1900+$year);
+        return sprintf('%02d/%02d/%4d', $mday, $mon+1, 1900+$year);
     }
     
     sub getValue
     {
         my $self = shift;
         my $value = $self->{entry}->get_text;
+        $value = GCUtils::strToTime($value, $self->{format}) if $self->{format};
         return GCPreProcess::reverseDate($value) if $self->{reverseDate};
         return $value;
     }
@@ -708,7 +827,12 @@ use strict;
     {
         my ($self, $text) = @_;
         $text = GCPreProcess::restoreDate($text) if $self->{reverseDate};
-        $text = $self->getCurrentDate if $text eq 'current';
+        if ($text eq 'current')
+        {
+            $text = $self->getCurrentDate;
+            $self->{hasChanged} = 1;
+        }
+        $text = GCUtils::timeToStr($text, $self->{format}) if $self->{format};
         $self->{entry}->set_text($text);
     }
     
@@ -781,7 +905,7 @@ use strict;
     {
         my ($self, $type, $withFilter) = @_;
         
-        if (($type != $self->{type}) || ($withFilter != $self->{withFilter}))
+        if (($type ne $self->{type}) || ($withFilter != $self->{withFilter}))
         {
             $self->{dialog}->destroy
                 if $self->{dialog};
@@ -832,7 +956,15 @@ use strict;
 
         return $self;
     }
-    
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{entry}->signal_connect('changed' => sub {;
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -953,7 +1085,7 @@ use strict;
     sub setValue
     {
         my ($self, $value) = @_;
-        
+        $self->{hasChanged} = 1;
         return $value;
     }
 
@@ -1008,6 +1140,7 @@ use strict;
     {
         my ($self, $value) = @_;
         
+        $self->{hasChanged} = 1;
         $self->{url} = $value;
         $self->lock(!$self->{url});
     }
@@ -1029,7 +1162,16 @@ use strict;
         bless ($self, $class);
         return $self;
     }
-    
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+
+        $self->signal_connect('toggled' => sub {
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -1096,6 +1238,18 @@ use strict;
         return $self;
     }
     
+    sub activateStateTracking
+    {
+        my $self = shift;
+
+        foreach (@{$self->{check}})
+        {
+            $_->signal_connect('toggled' => sub {
+                $self->{hasChanged} = 1;
+            });
+        }
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -1176,17 +1330,21 @@ use strict;
                     $self->{entries}->[$i] = GCHistoryText->new;
                     $self->{entries}->[$i]->entry->signal_connect('activate' => sub {
                         my $widget = $self->{entries}->[$i];
-                        $self->addValues if $widget->getValue;
-                        #$widget->popup unless $widget->getValue;
+                        if ($widget->getValue)
+                        {
+                            $self->addValues;
+                            # FIXME. It seems this does nothing:
+                            $self->{entries}->[0]->grab_focus;
+                        }
                         $widget->entry->signal_stop_emission_by_name('activate');
                     });
-                    #$self->{entries}->[$i]->disable_activate;
                 }
                 else
                 {
                     $self->{entries}->[$i] = GCShortText->new;
                     $self->{entries}->[$i]->signal_connect('activate' => sub {
                         $self->addValues;
+                        $self->{entries}->[0]->grab_focus;
                     });
                 }
             }
@@ -1247,6 +1405,19 @@ use strict;
             $selected = 0 if $selected < 0 ;
             $self->{list}->select($selected);
         });
+        
+        $self->{list}->signal_connect('key-press-event' => sub {
+            my ($widget, $event) = @_;
+            my $key = Gtk2::Gdk->keyval_name($event->keyval);
+            if ((!$self->{readonly}) && ($key eq 'Delete'))
+            {
+                $self->{removeButton}->activate;
+                return 1;
+            }
+            # Let key be managed by Gtk2
+            return 0;
+        });
+        
 
         $self->pack_start($self->{box},1,$self->{readonly},0);
 
@@ -1254,6 +1425,20 @@ use strict;
         return $self;
     }
 
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{list}->get_model->signal_connect('row-inserted' => sub {
+            $self->{hasChanged} = 1;
+        });
+        $self->{list}->get_model->signal_connect('row-deleted' => sub {
+            $self->{hasChanged} = 1;
+        });
+        $self->{list}->get_model->signal_connect('row-changed' => sub {
+            $self->{hasChanged} = 1;
+        });
+    }
+
     sub expand
     {
         my $self = shift;
@@ -1283,8 +1468,13 @@ use strict;
                 last;
             }
         }
-        push @{$self->{list}->{data}}, \@values
-            if !$isEmpty;
+        if (!$isEmpty)
+        {
+            push @{$self->{list}->{data}}, \@values;
+            $self->{list}->select($#{$self->{list}->{data}});
+            my $path = $self->{list}->get_selection->get_selected_rows;
+            $self->{list}->scroll_to_cell($path) if $path;
+        }
     }
 
     sub isEmpty
@@ -1297,48 +1487,46 @@ use strict;
     sub getValue
     {
         my $self = shift;
-        my $result = {
-                        line => []
-                     };
-
-        foreach (@{$self->{list}->{data}})
-        {
-            my $cols = {
-                          col => []
-                       };
-            foreach my $value(@{$_})
-            {
-                push @{$cols->{col}}, $value;
-            }
-            push @{$result->{line}}, $cols;
-        }
-        
         my $formated = shift;
+
         if ($formated)
         {
-            $result = GCPreProcess::multipleList($result, $self->{number});
+            return GCPreProcess::multipleList($self->{list}->{data}, $self->{number});
+        }
+        else
+        {
+            # As data in list is a tied array, we need to copy all the values
+            my @value;
+            foreach (@{$self->{list}->{data}})
+            {
+                push @value, [];
+                foreach my $col(@$_)
+                {
+                    push @{$value[-1]}, $col;
+                }
+            }
+            return \@value;
         }
-        
-        
-        return $result;
     }
     
     sub setValue
     {
         my ($self, $value) = @_;
 
-        @{$self->{list}->{data}} = ();
-        if (ref($value) eq 'HASH')
+        if (ref($value) eq 'ARRAY')
         {
-            push @{$self->{list}->{data}}, $_->{col}
-                foreach (@{$value->{line}})
+            @{$self->{list}->{data}} = @{$value};
         }
         else
         {
+            # The separator used was ; instead of ,
+            $value =~ s/;/,/g if $value !~ /,/;
+            @{$self->{list}->{data}} = ();
             my @values = split m/,/, $value;
-            foreach (@values)
+            foreach my $entry (@values)
             {
-                my @items = split m/;/;
+                my @items = split m/;/, $entry;
+                s/^\s*// foreach(@items);
                 push @{$self->{list}->{data}}, \@items;
             }
         }
@@ -1371,20 +1559,22 @@ use strict;
         return if $self->{readonly};
         my $i;
         my $item;
-        if (ref($value) eq 'HASH')
+        if (ref($value) eq 'ARRAY')
         {
-            foreach (@{$value->{line}})
+            foreach (@$value)
             {
                 $i = 0;
-                foreach $item(@{$_->{col}})
+                foreach $item(@$_)
                 {
                     $self->{entries}->[$i]->addHistory($item, $noUpdate);
-                    $i++;                   
+                    $i++;
                 }
             }
         }
         else
         {
+            # The separator used was ; instead of ,
+            $value =~ s/;/,/g if $value !~ /,/;
             my @values = split m/,/, $value;
             foreach (@values)
             {
@@ -1465,9 +1655,21 @@ use strict;
             $self->{width} = 120;
             $self->{height} = 160;
         }
+        $self->{immediate} = 0;
         return $self;
     }
-    
+
+    sub setImmediate
+    {
+        my ($self) = @_;
+        $self->{immediate} = 1;
+    }
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{trackState} = 1;
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -1479,10 +1681,28 @@ use strict;
     {
         my ($self, $displayedImage) = @_;
         $self->{displayedImage} = $displayedImage;
-        
-        $displayedImage = GCUtils::getDisplayedImage($displayedImage,
-                                                     $self->{defaultImage},
-                                                     $self->{options}->file);
+        $self->{hasChanged} = 1 if $self->{trackState};
+        if ($self->{immediate})
+        {
+            $self->setPicture;
+        }
+        else
+        {
+            Glib::Source->remove($self->{timer})
+                if $self->{timer};
+            $self->{timer} = Glib::Timeout->add(100, sub {
+                $self->setPicture;
+            });
+        }
+    }
+    
+    sub setPicture
+    {
+        my $self = shift;
+        $self->{timer} = 0;
+        my $displayedImage = GCUtils::getDisplayedImage($self->{displayedImage},
+                                                        $self->{defaultImage},
+                                                        $self->{options}->file);
         my $pixbuf;
         eval
         {
@@ -1531,11 +1751,14 @@ use strict;
     package GCImageButton;
 
     @GCImageButton::ISA = ('Gtk2::Button', 'GCGraphicComponent');
-    
+
+    use File::Basename;    
+
     sub clearImage
     {
         my $self = shift;
 
+        $self->{hasChanged} = 1 if $self->{trackState};
         my $imagePrefix = $self->{mainParent}->{imagePrefix};
         if ($self->{imageFile} =~ /(\/|\\)$imagePrefix[0-9]*\./)
         {
@@ -1548,7 +1771,6 @@ use strict;
     {
         my ($self, $fileName) = @_;
         return 0 if $self->{locked};
-
         if (!$fileName)
         {
             if (! $self->{imageDialog})
@@ -1556,14 +1778,24 @@ use strict;
                 $self->{imageDialog} = GCFileChooserDialog->new($self->{parent}->{lang}->{PanelImageTitle}, $self->{mainParent}, 'open');
                 $self->{imageDialog}->setWithImagePreview(1);    
             }
-        
-            $self->{imageDialog}->set_filename($self->getValue);
+
+            my $currentFile = $self->getValue;
+            if ($currentFile)
+            {
+                $self->{imageDialog}->set_filename($currentFile);
+            }
+            else
+            {
+                $self->{imageDialog}->set_filename($self->{previousDirectory});
+            }
             my $response = $self->{imageDialog}->run;
             $self->{imageDialog}->hide;
             $self->{parent}->showMe;
             if ($response eq 'ok')
             {
                 $fileName = $self->{imageDialog}->get_filename;
+                $self->{previousDirectory} = dirname($fileName);
+                $self->{hasChanged} = 1 if $self->{trackState};
             }
             else
             {
@@ -1578,6 +1810,7 @@ use strict;
             {
                 $self->{mainParent}->{items}->markToBeRemoved($self->{imageFile});
             }
+            $self->{hasChanged} = 1 if $self->{trackState};
         }
         my $image = $self->{mainParent}->transformPicturePath($fileName);
         $self->setValueWithParent($image);
@@ -1593,6 +1826,7 @@ use strict;
     sub setValue
     {
         my ($self, $value) = @_;
+        $self->{hasChanged} = 1 if $self->{trackState};
         $self->{imageFile} = $value;
         $self->{img}->setValue($value);
     }
@@ -1603,10 +1837,13 @@ use strict;
         $self->{imageFile} = $value;
         if ($self->{isCover})
         {
-            my $previous = $self->{parent}->getAsHash;
             $self->{img}->setValue($value);
-            my $new = $self->{parent}->getAsHash;
-            $self->{mainParent}->{itemsList}->changeCurrent($previous, $new);
+            $self->{mainParent}->{items}->updateCurrent;
+            $self->{hasChanged} = 0 if $self->{parent} eq $self->{mainParent}->{panel};
+            #my $previous = $self->{parent}->getAsHash;
+            #$self->{img}->setValue($value);
+            #my $new = $self->{parent}->getAsHash;
+            #$self->{mainParent}->{itemsView}->changeCurrent($previous, $new);
         }
         else
         {
@@ -1617,7 +1854,6 @@ use strict;
     sub getValue
     {
         my $self = shift;
-        use GCUtils;
         return $self->{img}->getValue;
     }
     
@@ -1709,13 +1945,22 @@ use strict;
                 $fileName =~ s|^file://?(.*)\W*$|$1|;
                 $fileName =~ s|^/*|| if ($^O =~ /win32/i);
                 $fileName =~ s/.$//ms;
+                $fileName =~ s/%20/ /g;
             }
             $self->changeImage($fileName);
         });
 
+        $self->{previousDirectory} = '';
+
         return $self;
     }
     
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->{trackState} = 1;
+    }
+
     sub lock
     {
         my ($self, $locked) = @_;
@@ -1762,6 +2007,7 @@ use strict;
     {
         my $self = shift;
         
+        return 1 if ! defined $self->get_active_iter;
         return ($self->{model}->get($self->get_active_iter))[1] eq '';
         my $idx = $self->get_history;
         $idx-- if $idx >= $self->{separatorPosition};
@@ -1814,7 +2060,8 @@ use strict;
         }
         $i++ if $i >= $self->{separatorPosition};
         $i-- if ($self->{default} == -1) && ($i >= $self->{count});
-        $self->set_active($i);
+        $self->set_active($i)
+            if ($i < scalar(@{$self->{values}}));
     }
 
     sub clear
@@ -1886,7 +2133,10 @@ use strict;
         $self->add_attribute($renderer, text => 1);
         $self->set_row_separator_func(sub {
             my ($model, $iter) = @_;
-            return ($model->get($iter, 0))[0] eq $separatorValue;
+            my @values = $model->get($iter, 0);
+            my $val = '';
+            $val = $values[0] if defined $values[0];
+            return $val eq $GCMenuList::separatorValue;
         });
 
         $self->setValues($values, $separatorPosition) if $values;
@@ -1894,6 +2144,14 @@ use strict;
         $self->set_focus_on_click(1);
         return $self;
     }
+
+    sub activateStateTracking
+    {
+        my $self = shift;
+        $self->signal_connect('changed' => sub {
+            $self->{hasChanged} = 1;
+        });
+    }
 }
 
 {
@@ -1974,7 +2232,6 @@ use strict;
     {
         my ($self, $text) = @_;
         
-        $text =~ s/&/&amp;/g;
         $self->{label}->set_markup($text);
     }
 
@@ -2074,7 +2331,7 @@ use strict;
     {
         my ($self, $text) = @_;
         
-        $text =~ s/&/&amp;/g;
+        #$text =~ s/&/&amp;/g;
         if ($self->{resize})
         {
             $self->resize;
@@ -2158,9 +2415,9 @@ use strict;
 
         $self->{labels} = [];
         my @lines;
-        if (ref($value) eq 'HASH')
+        if (ref($value) eq 'ARRAY')
         {
-            @lines = @{$value->{line}};
+            @lines = @$value;
         }
         else
         {
@@ -2177,9 +2434,9 @@ use strict;
         foreach (@lines)
         {
             my @cols;
-            if (ref($value) eq 'HASH')
+            if (ref($value) eq 'ARRAY')
             {
-                @cols = @{$_->{col}};
+                @cols = @$_;
             }
             else
             {
@@ -2226,16 +2483,17 @@ use strict;
 {
     package GCColorText;
 
-    @GCColorText::ISA = ('Gtk2::ScrolledWindow', 'GCGraphicComponent');
+    @GCColorText::ISA = ('Gtk2::ScrolledWindow', 'GCGraphicComponent', 'GCPseudoHistoryComponent');
 
     sub new
     {
-        my ($proto, $color, $height) = @_;
+        my ($proto, $color, $height, $listType) = @_;
         my $class = ref($proto) || $proto;
     
         my $self = $class->SUPER::new;
         bless ($self, $class);
 
+        $listType = 0 if !$listType;
         $self->{text} = new Gtk2::TextView;
         $self->{text}->set_editable(0);
         $self->{text}->set_wrap_mode('word');
@@ -2247,6 +2505,7 @@ use strict;
         $self->set_shadow_type('none');
         $self->set_policy('automatic', 'automatic');
         $self->add($self->{text});
+        $self->initHistory($listType);
 
         my $layout = $self->create_pango_layout('G');
         my (undef, $rect) = $layout->get_pixel_extents;
@@ -2267,7 +2526,6 @@ use strict;
     {
         my ($self, $text) = @_;
         
-        $text =~ s/&/&amp;/g;
         if ($self->{resize})
         {
             $self->resize;
@@ -2304,7 +2562,6 @@ use strict;
     sub AUTOLOAD
     {
         my $self = shift;
-        GCUtils::printStack;
         my $name = our $AUTOLOAD;
         return if $name =~ /::DESTROY$/;
         $name =~ s/.*?::(.*)/$1/;
@@ -2312,6 +2569,47 @@ use strict;
     }
 }
 
+{
+    package GCColorExpander;
+    
+    @GCColorExpander::ISA = ('GCExpander');
+
+    sub new
+    {
+        my ($proto, $label, $bgColor, $fgStyle) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($label);
+
+        bless ($self, $class);
+        $self->{label} = new GCColorLabel($bgColor);
+        $self->set_label_widget($self->{label});
+        $self->{fgStyle} = $fgStyle;
+
+        return $self;
+    }
+    
+    sub setValue
+    {
+        my ($self, $label, $description) = @_;
+
+        $label = '<span '.$self->{fgStyle}.">$label</span>";
+
+        $self->{label}->set_markup($label);
+        if ($description)
+        {
+            $self->{description}->set_label($description);
+            $self->{description}->show;
+        }
+        else
+        {
+            $self->{description}->set_label('');
+            $self->{description}->hide;
+        }
+
+
+    }
+}
+
 {
     package GCDialogHeader;
     
@@ -2437,19 +2735,102 @@ use strict;
     }
 }
 
+{
+    package GCExpander;
+    
+    @GCExpander::ISA = ('Gtk2::Expander', 'GCGraphicComponent');
+    
+    sub new
+    {
+        my ($proto, $label) = @_;
+        my $class = ref($proto) || $proto;
+    
+        my $self = $class->SUPER::new($label);
+
+        bless ($self, $class);
+        $self->{hbox} = new Gtk2::HBox(0,0);
+        $self->{label} = new Gtk2::Label;
+        $self->{label}->set_alignment(0,0.5);
+        $self->{description} = new Gtk2::Label;
+        $self->{description}->set_alignment(0,0);
+        eval {$self->{description}->set_line_wrap_mode('word');};
+        $self->{hbox}->pack_start($self->{label}, 0, 0, 0);
+        $self->{hbox}->pack_start($self->{description}, 1, 1, 0);
+        $self->set_label_widget($self->{hbox});
+        $self->{signalHandler} = undef;
+        return $self;
+    }
+
+    sub setMode
+    {
+        my ($self, $mode) = @_;
+        if ($mode eq 'asis')
+        {
+            $self->{description}->set_ellipsize('none');
+            $self->{description}->set_line_wrap(0);
+            if ($self->{signalHandler})
+            {
+                $self->signal_handler_disconnect($self->{signalHandler});
+                $self->{signalHandler} = undef;
+                $self->{description}->set_size_request(-1, -1);
+            }
+        }
+        else
+        {
+            $self->{signalHandler} = $self->signal_connect('size-allocate' => sub {
+                $self->{description}->set_size_request($self->allocation->width 
+                                                     - $self->{label}->allocation->width
+                                                     - ( 4 * $GCUtils::margin)
+                                                     , -1);
+                return 0;
+            });
+            if ($mode eq 'wrap')
+            {
+                $self->{description}->set_ellipsize('none');
+                $self->{description}->set_line_wrap(1);
+            }
+            else
+            {
+                $self->{description}->set_ellipsize('end');
+                $self->{description}->set_line_wrap(0);
+            }
+        }
+    }
+
+    sub setValue
+    {
+        my ($self, $label, $description) = @_;
+
+        $self->{label}->set_label($label);
+        if ($description)
+        {
+            $self->{description}->set_label($description);
+            $self->{description}->show;
+        }
+        else
+        {
+            $self->{description}->set_label('');
+            $self->{description}->hide;
+        }
+    }
+}
+
 {
     package GCFieldSelector;
     @GCFieldSelector::ISA = ('GCMenuList');
 
+    our $anyFieldValue = 'GCAnyField';
+
     sub new
     {
         # $advancedFilter: Should we remove some fields that could not be used for grouping
-        my ($proto, $withImages, $model, $advancedFilter) = @_;
+        my ($proto, $withImages, $model, $advancedFilter, $withAnyField) = @_;
         my $class = ref($proto) || $proto;
         my $self = $class->SUPER::new;
         bless($self, $class);
         $self->{withImages} = $withImages;
         $self->{advancedFilter} = $advancedFilter;
+        $self->{withAnyField} = $withAnyField;
         $self->setModel($model) if $model;
         return $self;
      }
@@ -2459,6 +2840,8 @@ use strict;
         my ($self, $model) = @_;
         
         my @values = ({value => '', displayed => ''});
+        push @values, ({value => $anyFieldValue, displayed => $model->getDisplayedText('AdvancedSearchAnyField')})
+            if ($self->{withAnyField});
         foreach (@{$model->{fieldsNames}})
         {
             next if ($model->{fieldsInfo}->{$_}->{type} eq 'image') && (!$self->{withImages});
