@@ -68,12 +68,26 @@ use GCExportImport;
         $self->SUPER::setModule($module);
         $self->{currentList}->set_sensitive(scalar @{$module->getModels} == 0);
         $self->{newList}->set_active(1);
-        foreach (@{$module->getModels})
+        if ($self->{parent}->{model})
         {
-            if ($self->{parent}->{model}->getName eq $_)
+            foreach (@{$module->getModels})
             {
-                $self->{currentList}->set_sensitive(1);
-                last;
+                if ($self->{parent}->{model}->getName eq $_)
+                {
+                    $self->{currentList}->set_sensitive(1);
+                    last;
+                }
+            }
+        }
+        if ($self->{fieldsDialog})
+        {
+            if ($module->wantsIgnoreField)
+            {
+                $self->{fieldsDialog}->addIgnoreField($self->{parent}->{ignoreString});
+            }
+            else
+            {
+                $self->{fieldsDialog}->removeIgnoreField;
             }
         }
     }
@@ -81,7 +95,8 @@ use GCExportImport;
     sub setModel
     {
         my $self = shift;
-        $self->{fieldsDialog} = new GCFieldsSelectionDialog($self, $self->{parent}->{lang}->{ImportFieldsTitle});
+        $self->{fieldsDialog} = new GCFieldsSelectionDialog($self,
+                                                            $self->{parent}->{lang}->{ImportFieldsTitle});
     }
 
     sub new
