@@ -180,7 +180,7 @@ use GCImport::GCImportBase;
             $result[$i]->{director} = $self->readString;
             $self->readString;  #Producer
             $result[$i]->{country} = $self->readString;     
-            $result[$i]->{genre} = $self->readString;
+            $result[$i]->{genre} = [[$self->readString]];
             $result[$i]->{actors} = $self->readString;
             $result[$i]->{webPage} = $self->readString;            
             $result[$i]->{synopsis} = $self->readString;
@@ -197,7 +197,7 @@ use GCImport::GCImportBase;
                 $result[$i]->{audio} =~ s/, +/,/g;
                 $result[$i]->{audio} =~ s/; +/;/g;
             }
-            $result[$i]->{subt} = $self->readString;
+            $result[$i]->{subt} = [[$self->readString]];
             $self->readString;  #File size
             $result[$i]->{image} = $self->readString;
 
