@@ -172,8 +172,8 @@ use GCImport::GCImportBase;
             }
             elsif (/^\s*- (.*)$/)
             {
-                $book{$current} ||= {line => []};
-                push @{$book{$current}->{line}}, {'col' => [$self->transformValue($1)]};
+                $book{$current} ||= [];
+                push @{$book{$current}}, [$self->transformValue($1)];
             }
         }
         close BOOK;
