@@ -23,6 +23,7 @@ package GCImport::GCImportCSV;
 ###################################################
 
 use strict;
+use utf8;
 
 use GCImport::GCImportBase;
 
@@ -30,6 +31,7 @@ use GCImport::GCImportBase;
     package GCImport::GCImporterCSV;
 
     use base qw(GCImport::GCImportBaseClass);
+    use Encode;
 
     sub new
     {
@@ -46,6 +48,11 @@ use GCImport::GCImportBase;
         return 1;
     }
 
+    sub wantsIgnoreField
+    {
+        return 1;
+    }
+
     sub wantsFileSelection
     {
         return 1;
@@ -66,7 +73,14 @@ use GCImport::GCImportBase;
     sub getOptions
     {
         my $self = shift;
-        
+
+        my $charsets = '';
+        my @charsetList = Encode->encodings(':all');
+        foreach (@charsetList)
+        {
+            $charsets .= $_.',';
+        }
+
         return [
             {
                 name => 'sep',
@@ -75,12 +89,21 @@ use GCImport::GCImportBase;
                 default => ';'
             },
 
+            {
+                name => 'charset',
+                type => 'options',
+                label => 'Charset',
+                valuesList => $charsets,
+                default => 'utf8',
+            },
+
             {
                 name => 'withHeader',
                 type => 'yesno',
                 label => 'Header',
                 default => '1'
             },
+
         ];
     }
       
@@ -96,7 +119,8 @@ use GCImport::GCImportBase;
         my @result;
 
         open ITEMS, $file;
-        binmode(ITEMS, ':utf8');
+        binmode(ITEMS, ':utf8')
+            if $self->{options}->{charset} eq 'utf8';;
 
         my $i = 0;
         my $sep = $self->{options}->{sep};
@@ -118,6 +142,8 @@ use GCImport::GCImportBase;
             my $j = 0;
             foreach (@{$self->{options}->{fields}})
             {
+                $values[$j] = decode($self->{options}->{charset}, $values[$j])
+                    if $self->{options}->{charset} ne 'utf8';
                 $result[$i]->{$_} = $values[$j];
                 $j++;
             }
@@ -140,4 +166,4 @@ use GCImport::GCImportBase;
     }
 }
 
-1;
\ No newline at end of file
+1;
