@@ -156,7 +156,7 @@ use GCImport::GCImportBase;
                     if ($origFile =~ /^gcfilms_/)
                     {
                         # We don't change the filename as gcstar has a different pattern for automatic files
-                        my $destPath = $self->{options}->{parent}->{options}->images;
+                        my $destPath = $self->{options}->{parent}->getImagesDir;
                         copy($origPath, $destPath) if $origPath ne $destPath;
                         $result[$i]->{image} = $destPath.$origFile;
                     }
