@@ -29,7 +29,7 @@ use GCImport::GCImportBase;
     package GCImport::GCImporterGCstar;
     use base qw(GCImport::GCImportBaseClass);
 
-    use File::Copy;
+    use GCBackend::GCBackendXmlParser;
     
     sub new
     {
@@ -53,8 +53,7 @@ use GCImport::GCImportBase;
     sub getModelName
     {
         my $self = shift;
-        
-        return $self->{extractedModel};
+        return $self->{model}->getName;
     }
 
     sub getOptions
@@ -78,36 +77,25 @@ use GCImport::GCImportBase;
     {
         return "";
     }
-    
+
     sub getItemsArray
     {
         my ($self, $file) = @_;
-        
-        my $loader = new GCItems($self->{options}->{parent});
-        
-        $loader->load($file, undef, undef, 1);
-        $loader->{model} = $self->{options}->{parent}->{model};
-        $self->{modelAlreadySet} = 1;
-        $self->{extractedModel} = $loader->{model}->getName;
 
+        my $parent = $self->{options}->{parent};
+        $self->{modelsFactory} = $parent->{modelsFactory};
+        $self->{modelAlreadySet} = 0;
+
+        my $backend = new GCBackend::GCBeXmlParser($self);            
+        $backend->setParameters($file);
+        my $loaded = $backend->load(0);
+        my $itemsArray = $loaded->{data};
         if ($self->{options}->{copyPics})
         {
-            #Copying pictures
-            foreach (@{$loader->{itemArray}})
-            {
-                my $title = $_->{$loader->{model}->{commonFields}->{title}};
-                foreach my $field(@{$loader->{model}->{fieldsImage}})
-                {
-                    (my $suffix = $_->{$field}) =~ s/.*?(\.[^.]*)$/$1/;
-                    my $imageFile = $self->{options}->{parent}->getUniqueImageFileName($suffix, $title);
-                    copy($_->{$field}, $imageFile)
-                        if $_->{$field};
-                    $_->{$field} = $imageFile;
-                }
-            }
+            $self->copyPictures($itemsArray, $file);
         }
-        
-        return $loader->{itemArray};
+        return $itemsArray;
+
     }
 }
 
