@@ -105,17 +105,22 @@ use GCImport::GCImportBase;
 
         my $titleField = $self->{options}->{model}->{commonFields}->{title};
         open ITEMS, $file;
+        binmode(ITEMS, ':utf8');
 
         my $i = 0;
 
-        $self->{options}->{parent}->getDialog('Results')->setModel($self->{options}->{model}, $self->{model}->{fieldsInfo});
+        my $resultsDialog = $self->{options}->{parent}->getDialog('Results');
+        $resultsDialog->setModel($self->{options}->{model}, $self->{model}->{fieldsInfo});
+        $resultsDialog->setMultipleSelection(0);
         while (<ITEMS>)
         {
             chomp;
-            
+            next if ! $_;
+
             # $_ contains the title to search
             $plugin->{title} = $_;
             $plugin->{type} = 'load';
+            $plugin->{urlField} = $self->{options}->{model}->{commonFields}->{url};
 
             #Initialize what will be pushed in the array
             my $info = {$titleField => $_};
@@ -123,10 +128,10 @@ use GCImport::GCImportBase;
             $self->{options}->{parent}->setWaitCursor($self->{options}->{lang}->{StatusSearch}.' ('.$_.')');
             $plugin->load;
 
-    		my $itemNumber = $plugin->getItemsNumber;
+            my $itemNumber = $plugin->getItemsNumber;
 
-		    if ($itemNumber != 0)
-		    {
+            if ($itemNumber != 0)
+            {
                 $plugin->{type} = 'info';
                 if (($itemNumber == 1) || ($self->{options}->{first}))
                 {
@@ -136,20 +141,22 @@ use GCImport::GCImportBase;
                 {
                     my $withNext = 0;
                     my @items = $plugin->getItems;
-                    $self->{options}->{parent}->getDialog('Results')->setWithNext(0);
-                    $self->{options}->{parent}->getDialog('Results')->setSearchPlugin($plugin);
-                    $self->{options}->{parent}->getDialog('Results')->setList($_, @items);
-                    $self->{options}->{parent}->getDialog('Results')->show;
-                    if ($self->{options}->{parent}->getDialog('Results')->{validated})
+                    $resultsDialog->setWithNext(0);
+                    $resultsDialog->setSearchPlugin($plugin);
+                    $resultsDialog->setList($_, @items);
+                    $resultsDialog->show;
+                    if ($resultsDialog->{validated})
                     {
-                        $plugin->{wantedIdx} = $self->{options}->{parent}->getDialog('Results')->{itemIndex};
+                        $plugin->{wantedIdx} = $resultsDialog->getItemsIndexes->[0];
                     }
                 }
                 $info = $plugin->getItemInfo;
                 my $title = $info->{$titleField};
+                $self->{options}->{parent}->{defaultPictureSuffix} = $plugin->getDefaultPictureSuffix;
                 foreach my $field(@{$self->{options}->{model}->{managedImages}})
                 {
                     $info->{$field} = '' if $info->{image} eq 'empty';
+                    next if !$info->{$field};
                     ($info->{$field}) = $self->{options}->{parent}->downloadPicture($info->{$field}, $title);
                 }
                 $info->{comment} = $self->getLang->{CommentAuto}
@@ -160,7 +167,15 @@ use GCImport::GCImportBase;
                                   . $self->getLang->{CommentTitle}
                                  . $_
                                  . "\n";
-		    }
+
+                # Add the default value
+                my $defaultInfo = $self->{options}->{model}->getInitInfo;
+                foreach my $field(keys %$defaultInfo)
+                {
+                    next if exists $info->{$field};
+                    $info->{$field} = $defaultInfo->{$field};
+                }
+            }
             
             push @result, $info;
             $self->{options}->{parent}->restoreCursor;            
@@ -179,4 +194,4 @@ use GCImport::GCImportBase;
     }
 }
 
-1;
\ No newline at end of file
+1;
