@@ -42,6 +42,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'إستعمل Javascript',
        	'FileTemplate' => 'قالب:',
         'Preview' => 'معاينة',
@@ -66,6 +69,7 @@
         'Borrowed' => 'تمت إستعارته من قبل: ',
         'NotBorrowed' => 'متاح',
         'Top' => 'للأعلى',
+        'Bottom' => 'Bottom',
      );
 }
 
