@@ -96,6 +96,7 @@
         'SplashInit' => 'تهيئة',
         'SplashLoad' => 'تحميل المجموعات',
         'SplashDisplay' => 'عرض المجموعات',
+        'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'جاهز',
 
 #Import from GCfilms
@@ -182,8 +183,9 @@
         'AboutDesc' => 'لإدارة المجموعات',
         'AboutVersion' => 'إصدار',
         'AboutTeam' => 'فريق',
-        'AboutWho' => 'مدير المشروع، مبرمج: Tian
-مبرمج: Adolfo González',
+        'AboutWho' => 'مدير المشروع، مبرمج: Christian Jodar (Tian)
+مبرمج: Adolfo González
+مبرمج: Nyall Dawson (Zombiepig)',
         'AboutLicense' => 'المشروع تم تطويره و توزيعه وفق رخصة البرامج مفتوحة المصدر GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -247,6 +249,7 @@ hali83@cec.sy',
         'ModelOptionsFieldsPlay' => 'من أجل زر القراءة',
         'ModelCollectionSettings' => 'إعدادات المجموعة',
         'ModelCollectionSettingsLending' => 'لا يمكن إعارة العناصر',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'ضمن أن يكون ضمن صندوق البحث',
         'ModelFilterComparison' => 'مقارنة',
         'ModelFilterContain' => 'يحتوي',
@@ -260,12 +263,14 @@ hali83@cec.sy',
         'ModelTooltipHistory' => 'القيم المدخلة سابقاً سيتم تخزينها ضمن قائمة مرتبطة بالحقل',
         'ModelTooltipFormat' => 'تستعمل هذه الصيغة لتخصيص طريقة فتح الملف بإستعمال زر القراءة',
         'ModelTooltipLending' => 'سيتم إضافة بعض الحقول من أجل إدارة الإستعارة',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'سيتم معاملة جميع المقارنات على أنها أعداد',
         'ModelTooltipQuick' => 'سيتم إضافة قائمة فرعية ضمن قائمة التصفية',
         
         'ResultsTitle' => 'حدد عنصر',
         'ResultsNextTip' => 'البحث ضمن الموقع',
         'ResultsPreview' => 'معاينة',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'التفضيلات',
         'OptionsBrowser' => 'متصفّح الإنترنت',
@@ -280,6 +285,7 @@ hali83@cec.sy',
         'OptionsAutoSave' => 'حفظ المجموعة بشكل تلقائي',
         'OptionsAutoLoad' => 'فتح المجموعة السابقة عند بدء تشغيل البرنامج',
         'OptionsSplash' => 'عرض الشاشة الترحيبية',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'حدد مجلد',
         'OptionsProgramTitle' => 'حدد البرنامج الذي سيتم إستعماله',
 		'OptionsPlugins' => 'الموقع الذي سيتم جلب البيانات منه',
@@ -289,6 +295,7 @@ hali83@cec.sy',
 		'OptionsPluginsList' => 'تخصيص قائمة المواقع',
         'OptionsAskImport' => 'حدد الحقول التي سيتم إستيرادها',
 		'OptionsProxy' => 'إستعمل البروكسي',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'لغة',
         'OptionsMain' => 'عام',
         'OptionsPaths' => 'مسارات',
@@ -299,6 +306,10 @@ hali83@cec.sy',
         'OptionsToolbars' => {0 => 'بلا', 1 => 'صغير', 2 => 'كبير'},
         'OptionsToolbarPosition' => 'توضّع',
         'OptionsToolbarPositions' => {0 => 'في الأعلى', 1 => 'في الأسفل', 2 => 'في اليسار', 3 => 'في اليمين'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'قائمة العناصر',
         'OptionsViews' => {0 => 'نص', 1 => 'صورة', 2 => 'تفاصيل'},
         'OptionsColumns' => 'أعمدة',
@@ -311,6 +322,7 @@ hali83@cec.sy',
         'OptionsSearchStop' => 'السماح بإحباط عملية البحث',
 
         'OptionsAlwaysOriginal' => 'استعمل العنوان الرئيسي كعنوان أصلي إن لم يتم تخصيصه',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'حجم المحفوظات',
         'OptionsClearHistory' => 'مسح المحفوظات',
 		'OptionsStyle' => 'مظهرية العرض',
@@ -341,6 +353,7 @@ hali83@cec.sy',
         'ImagesOptionsButton' => 'إعدادات',
         'ImagesOptionsTitle' => 'إعدادات قائمة الصوّر',
         'ImagesOptionsSelectColor' => 'حدد لون',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'خلفية',
         'ImagesOptionsBgPicture' => 'إستعمل صورة الخلفية',
         'ImagesOptionsFg'=> 'تحديد',
@@ -353,10 +366,10 @@ hali83@cec.sy',
         'DetailedOptionsTitle' => 'إعدادات قائمة تفاصيل',
         'DetailedOptionsImageSize' => 'قياس الصوّر',
         'DetailedOptionsGroupItems' => 'تجميع العناصر عن طريق',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'حدد التي الحقول التي سيتم عرضها',
-		'DetailedOptionsMasterOption' => 'المجموعة الرئيسية هي:',
-		'DetailedOptionsMasterGenerated' => 'الإنشاء التلقائي',
-		'DetailedOptionsMasterOrdered' => 'محددة عن طريق',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'معلومات',
         'ExtractTitle' => 'معلومات الملف',
@@ -365,12 +378,14 @@ hali83@cec.sy',
         'FieldsListOpen' => 'فتح قائمة الحقول من ملف',
         'FieldsListSave' => 'حفظ قائمة الحقول لملف',
         'FieldsListError' => 'لا يمكن إستعمال قائمة الحقول مع هذا النوع من المجموعات',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'تصدير قائمة العناصر',
         'ExportFilter' => 'تصدير العناصر المعروضة فقط',
         'ExportFieldsTitle' => 'حقول سيتم تصديرها',
         'ExportFieldsTip' => 'حدد الحقول التي تود تصديرها',
         'ExportWithPictures' => 'نسخ الصّور لمجلّد فرعي',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'إستيراد قائمة عناصر أخرى',
         'ImportExportData' => 'بيانات',
@@ -417,6 +432,7 @@ hali83@cec.sy',
         'PanelNobody' => 'لا أحد',
         'PanelUnknown' => 'غير معروف',
         'PanelAdded' => 'إضافة التاريخ',
+        'PanelRating' => 'تقييم',
         'PanelLocation' => 'المكان',
 
         'PanelLending' => 'إعارة',
@@ -429,6 +445,10 @@ hali83@cec.sy',
         'PanelLendedYes' => 'مُعار',
         'PanelLendedNo' => 'متاح',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'اما',
         'CheckYes' => 'نعم',
         'CheckNo' => 'لا',
@@ -538,7 +558,13 @@ hali83@cec.sy',
         'AdvancedSearchTypeAnd' => 'مطابقة كل المعايير',
         'AdvancedSearchTypeOr' => 'مطايقة معيار واحد على الأقل',
         'AdvancedSearchCriteria' => 'المعيار',
+        'AdvancedSearchAnyField' => 'Any field',
  
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
