@@ -47,12 +47,14 @@
         Image => 'Изображение',
         Original => 'Оригинално заглавие',
         Actors => 'Участват',
+        Actor => 'Actor',
+        Role => 'Role',
         Comment => 'Коментари',
         Synopsis => 'Резюме',
         Seen => 'Гледан',
         Number => '# на медии',
-        Rating => 'Рейтинг',
         Format => 'Тип медия',
+        Identifier => 'Identifier',
         Url => 'Уеб',
         Audio => 'Аудио',
         Video => 'Видео формат',
