@@ -47,8 +47,8 @@
         Box => 'Box picture',
         Case => 'Case',
         Manual => 'Instructions manual',
-        Rating => 'Rating',
         Completion => 'Completion (%)',
+        Executable => 'Executable',
         Description => 'Description',
         Codes => 'Codes',
         Code => 'Code',
