@@ -86,6 +86,7 @@
         'SplashInit' => 'Инициализация',
         'SplashLoad' => 'Зареждане на колекцията',
         'SplashDisplay' => 'Displaying Collection',
+        'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'Готово',
 
 #Import from GCfilms
@@ -172,8 +173,9 @@
         'AboutDesc' => 'Gtk2 каталог на филми',
         'AboutVersion' => 'Версия',
         'AboutTeam' => 'Екип',
-        'AboutWho' => 'Tian: Мениджър на проекта, Програмист
-Adolfo González : Програмист',
+        'AboutWho' => 'Christian Jodar (Tian): Мениджър на проекта, Програмист
+Adolfo González: Програмист
+Nyall Dawson (Zombiepig): Програмист',
         'AboutLicense' => 'Разпространява се под условията на GNU GPL
 Автор на логото le Spektre
 http://le-spektre.org',
@@ -233,6 +235,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'For Play button',
         'ModelCollectionSettings' => 'Collection settings',
         'ModelCollectionSettingsLending' => 'Items could be borrowed',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
@@ -245,12 +248,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
         'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
         'ModelTooltipLending' => 'This will add some fields to manage lendings',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
 
         'ResultsTitle' => 'Избор на филм',
         'ResultsNextTip' => 'Търсене в следващ сайт',
         'ResultsPreview' => 'Preview',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Предпочитания',
         'OptionsBrowser' => 'Уеб-четец',
@@ -265,6 +270,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Автоматично съхраняване на колекция',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Показване на splash екран',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Избор на директория',
         'OptionsProgramTitle' => 'Избор на програма, която да бъде използвана',
 		'OptionsPlugins' => 'Сайтове, от които да се получава информация',
@@ -274,6 +280,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Установяване на списък',
         'OptionsAskImport' => 'Избор на полета, които да бъдат импортирани',
 		'OptionsProxy' => 'Използване на proxy',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Език',
         'OptionsMain' => 'Основен',
         'OptionsPaths' => 'Пътеки',
@@ -281,9 +288,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Свойства',
         'OptionsDisplay' => 'Дисплей',
         'OptionsToolbar' => 'Лента с инструменти',
-        'OptionsToolbars' => {0 => 'Без', 1 => 'Малък', 2 => 'Голям'},
+        'OptionsToolbars' => {0 => 'Без', 1 => 'Малък', 2 => 'Голям', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Позиция',
         'OptionsToolbarPositions' => {0 => 'Горе', 1 => 'Долу', 2 => 'Ляво', 3 => 'Дясно'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Дисплей',
         'OptionsViews' => {0 => 'Техт', 1 => 'Изображение', 2 => 'Детайлно'},
         'OptionsColumns' => 'Колони',
@@ -294,6 +305,7 @@ http://le-spektre.org',
         'OptionsArticles' => 'Статии (Разделени със запетая)',
         'OptionsSearchStop' => 'Позволяване прекъсване на търсенето',
         'OptionsAlwaysOriginal' => 'Използване на основното заглавие ако оригиналното не е представено',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Размер на историята',
         'OptionsClearHistory' => 'Изчистване на историята',
 		'OptionsStyle' => 'Кожа',
@@ -322,6 +334,7 @@ http://le-spektre.org',
         'ImagesOptionsButton' => 'Настройки',
         'ImagesOptionsTitle' => 'Настройки за списък с изображения',
         'ImagesOptionsSelectColor' => 'Избор на цвят',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Фон',
         'ImagesOptionsBgPicture' => 'Използване на изображение за фон',
         'ImagesOptionsFg'=> 'Избор',
@@ -334,10 +347,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Настройки за детайлен списък',
         'DetailedOptionsImageSize' => 'Размер на изображение',
         'DetailedOptionsGroupItems' => 'Group items by',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'ИЗбор на приятели за показване',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'Информация',
         'ExtractTitle' => 'Информация за видео файл',
@@ -346,12 +359,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Load a fields list from a file',
         'FieldsListSave' => 'Save fields list to a file',
         'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Експортиране на списък с филми',
         'ExportFilter' => 'Експортиране само на показани филми',
         'ExportFieldsTitle' => 'Полета, които да бъдат експортирани',
         'ExportFieldsTip' => 'Избор на полета, които да бъдат експортирани',
         'ExportWithPictures' => 'Копиране на изображенията в под-директория',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'Импортиране на друг списък с филми',
         'ImportExportData' => 'Data',
@@ -397,6 +412,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Никой',
         'PanelUnknown' => 'Неизвестен',
         'PanelAdded' => 'Add date',
+        'PanelRating' => 'Рейтинг',
         'PanelLocation' => 'Местоположение',
 
         'PanelLending' => 'Заемане',
@@ -408,6 +424,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Даден',
         'PanelLendedNo' => 'Наличен',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Без значение',
         'CheckYes' => 'Да',
         'CheckNo' => 'Не',
@@ -517,6 +537,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Items matching all criteria',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'Any field',
+
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
