@@ -30,9 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Header' => 'Afegir títols de columnes',
+        'Header' => 'Inclou els noms dels camps a sobre',
         'Separator' => 'Delimitador',
-        'Replacement' => 'Substituir delimitador amb',
+        'Replacement' => 'Substitueix el delimitador amb',
      );
 }
 
