@@ -30,8 +30,8 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'WithDrop' => 'Incloure una instrucció DROP',
-        'WithCreate' => 'Incloure una instrucció CREATE',
+        'WithDrop' => 'Inclou una instrucció DROP',
+        'WithCreate' => 'Inclou una instrucció CREATE',
         'TableName' => 'Nom de la taula',
         'InfoFile' => 'Fitxer SQL: ',
      );
