@@ -30,11 +30,11 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'ModelFile' => 'Fitxer model',
-        'ModelText' => 'Text de model',
-        'Models' => 'Model a emprar',
-        'UseFile' => 'Especificar amb un fitxer',
-        'UseModel' => 'Especificar a la zona de text',
+        'ModelFile' => 'Fitxer plantilla',
+        'ModelText' => 'Text de plantilla',
+        'Models' => 'Plantilla a utilitzar',
+        'UseFile' => 'Utilitza el fitxer',
+        'UseModel' => 'Utilitza la zona de text',
      );
 }
 
