@@ -30,9 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Where' => 'On hauria de cercar',
+        'Where' => 'On l\'hauria de cercar',
         'Default' => 'Directori predeterminat d\'Alexandria',
-        'Specified' => 'Directori especificat abaix',
+        'Specified' => 'Directori especificat a sota',
      );
 }
 
