@@ -30,10 +30,10 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Name' => 'Llista de títols',
-        'Plugin' => 'Lloc a emprar',
-        'UseFirst' => 'Seleccionar el primer si hi ha molts resultats',
-        'CommentAuto' => 'Pel·lícula importada automàticament.',
+        'Name' => 'Llista de noms',
+        'Plugin' => 'Lloc a utilitzar',
+        'UseFirst' => 'Selecciona el primer si hi ha molts resultats',
+        'CommentAuto' => 'Element importat automàticament.',
         'CommentSite' => 'Lloc web: ',
         'CommentTitle' => 'Títol: ',
      );
