@@ -30,7 +30,7 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'NotSupported' => 'El fitxer no és una colecció de vídeo Tellico',
+        'NotSupported' => 'El fitxer no és una colecció Tellico compatible',
      );
 }
 
