@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Použít Javascript',
        	'FileTemplate' => 'Šablona:',
         'Preview' => 'Náhled',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Má půjčeno: ',
         'NotBorrowed' => 'Nepůjčen',
         'Top' => 'Nahoře',
+        'Bottom' => 'Bottom',
      );
 }
 
