@@ -31,8 +31,13 @@
 
     our %lang = (
     
-        CollectionDescription => 'Sbírka Knih',
-        Items => 'Knihy',
+        CollectionDescription => 'Sbírka knih',
+        Items => sub {
+          my $number = shift;
+          return 'Kniha' if $number eq '1';
+          return 'Knihy' if $number =~ /(?<!1)[2-4]$/;
+          return 'Knih';
+        },
         NewItem => 'Nová kniha',
     
         Isbn => 'ISBN',
@@ -43,17 +48,17 @@
         Publication => 'Datum vydání',
         Language => 'Jazyk',
         Genre => 'Žánr',
+        Serie => 'Sbírka',
         Bookdescription => 'Popis',
         Pages => 'Počet stran',
         Read => 'Přečteno',
-        Rating => 'Hodnocení',
         Acquisition => 'Datum pořízení',
         Edition => 'Náklad',
         Format => 'Rozměr',
         Comments => 'Poznámky',
         Url => 'Web',
-        Translator => 'Translator',
-        Artist => 'Artist',
+        Translator => 'Překladatel',
+        Artist => 'Ilustrace',
 
         General => 'Hlavní',
         Details => 'Detaily',
