@@ -31,8 +31,13 @@
 
     our %lang = (
     
-        CollectionDescription => 'hudební sbírka',
-        Items => 'Alba',
+        CollectionDescription => 'Sbírka hudby',
+        Items => sub {
+          my $number = shift;
+          return 'Album' if $number eq '1';
+          return 'Alba' if $number =~ /(?<!1)[2-4]$/;
+          return 'Alb';
+        },
         NewItem => 'Nové album',
     
         Unique => 'ISRC/EAN',
@@ -45,7 +50,7 @@
         Genre => 'Žánr',
 
 #For tracks list
-        Tracks => 'Tracks list',
+        Tracks => 'Seznam skladeb',
         Number => 'Číslo',
         Track => 'Název',
         Time => 'Čas',
