@@ -85,6 +85,7 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'SplashInit' => 'Inicializace',
         'SplashLoad' => 'Nahrávám sbírku',
         'SplashDisplay' => 'Zobrazuji sbírku',
+        'SplashSort' => 'Řadím sbírku',
         'SplashDone' => 'Hotovo',
 
 #Import from GCfilms
@@ -118,7 +119,7 @@ K rozlišení, který server vlastní dané informace, můžete použít
         
         'MenuBookmarks' => 'Mé _Sbíky',
             'MenuBookmarksAdd' => '_Přidat aktuální sbírku',
-            'MenuBookmarksEdit' => '_Editovat bookmarked sbírky',	# Edit bookmarked collections
+            'MenuBookmarksEdit' => '_Editovat založené sbírky',	# Edit bookmarked collections
 
         'MenuHelp' => '_Nápověda',
             'MenuHelpContent' => '_Nápověda',
@@ -171,12 +172,13 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'AboutDesc' => 'Katalog sbírek',
         'AboutVersion' => 'Verze',
         'AboutTeam' => 'Tým',
-        'AboutWho' => 'Tian: Project manager, Programmer
-Adolfo González : Programmer',
+        'AboutWho' => 'Christian Jodar (Tian): Project manager, Programmer
+Adolfo González: Programmer
+Nyall Dawson (Zombiepig): Programmer',
         'AboutLicense' => 'Distribuováno za podmínek GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
-        'AboutTranslation' => 'Český překlad připravil TomCat1',
+        'AboutTranslation' => 'Český překlad připravil Tomáš Klimek (Tomas.Klimek@gmail.com)',
         'AboutDesign' => 'Logo a webdesign od le Spektre',
 
         'ToolbarRandom' => 'Dnes večer',
@@ -188,9 +190,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Nastavení sbírek',
         'ModelNewType' => 'Nový typ sbírky',
         'ModelName' => 'Název nového typu sbírky:',
-		'ModelFields' => 'Fields',
-		'ModelOptions'	=> 'Options',
-		'ModelFilters'	=> 'Filters',
+		'ModelFields' => 'Pole',
+		'ModelOptions'	=> 'Nastavení',
+		'ModelFilters'	=> 'Filtry',
         'ModelNewField' => 'Nové pole',
         'ModelFieldInformation' => 'Informace',
         'ModelFieldName' => 'Štítek:',
@@ -211,7 +213,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Obrázek',
         'ModelFieldTypeSingleList' => 'Jednoduchý seznam',
         'ModelFieldTypeFile' => 'Soubor',
-        'ModelFieldTypeFormatted' => 'Dependant on other fields',
+        'ModelFieldTypeFormatted' => 'Závislý na jiných typech',
         'ModelFieldParameters' => 'Parametry',
         'ModelFieldHasHistory' => 'Používat historii',
         'ModelFieldFlat' => 'Zobrazit v jedné řadě',
@@ -232,6 +234,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'Tlačítko přehrát',
         'ModelCollectionSettings' => 'Nastavení sbírky',
         'ModelCollectionSettingsLending' => 'Položky mohou být půjčeny',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Pole bude ve vyhledávání',
         'ModelFilterComparison' => 'Porovnání',
         'ModelFilterContain' => 'Obsahuje',
@@ -244,12 +247,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Pro uchování dříve zadaných hodnot do seznamu přiřazenému poli',
         'ModelTooltipFormat' => 'Typ souboru se použije pro rozlišení akce při otevírání souboru tlačítkem Přehrát',
         'ModelTooltipLending' => 'Tato možnost přidá několik polí pro správu půjčování',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Hodnoty budou považovány za čísla při porovnání',
         'ModelTooltipQuick' => 'Do menu filtr přidá submenu',			#This will add a submenu in the Filters one
 
         'ResultsTitle' => 'Vyberte si ze seznamu',
         'ResultsNextTip' => 'Hledat na dalším serveru',
         'ResultsPreview' => 'Náhled',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Možnosti',
         'OptionsBrowser' => 'Webový prohlížeč',
@@ -264,6 +269,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Automaticky ukládat sbírku',
         'OptionsAutoLoad' => 'Při startu nahrát předchozí sbírku',
         'OptionsSplash' => 'Zobrazit úvodní obrázek',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Vyberte adresář pro ukládání obrázků',
         'OptionsProgramTitle' => 'Vyberte webový prohlížeč',
 		'OptionsPlugins' => 'Server, odkud stahovat data',
@@ -273,6 +279,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Nastavit seznam',
         'OptionsAskImport' => 'Vyberte pole, která se importují',
 		'OptionsProxy' => 'Použít proxy',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Jazyk',
         'OptionsMain' => 'Hlavní',
         'OptionsPaths' => 'Cesty',
@@ -280,9 +287,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Vlastnosti',
         'OptionsDisplay' => 'Zobrazení',
         'OptionsToolbar' => 'Nástrojová lišta',
-        'OptionsToolbars' => {0 => 'Žádná', 1 => 'Malá', 2 => 'Velká'},
+        'OptionsToolbars' => {0 => 'Žádná', 1 => 'Malá', 2 => 'Velká', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Umístění',
         'OptionsToolbarPositions' => {0 => 'Nahoře', 1 => 'Dole', 2 => 'Vlevo', 3 => 'Vpravo'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Zobrazení',
         'OptionsViews' => {0 => 'Text', 1 => 'Obrázek', 2 => 'Detailní'},
         'OptionsColumns' => 'Sloupce',
@@ -293,14 +304,15 @@ http://le-spektre.org',
         'OptionsArticles' => 'Členy (odděleny čárkou)',
         'OptionsSearchStop' => 'Umožnit zrušení hledání',
         'OptionsAlwaysOriginal' => 'Použít hlavní titul jako originální titul, pokud není vyplněn',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Velikost historie',
         'OptionsClearHistory' => 'Vyčistit historii',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Příště se nedotazovat',
         'OptionsPathProgramsGroup' => 'Programy',
-        'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
-        'OptionsProgramsSet' => 'Set programs',
+        'OptionsProgramsSystem' => 'Použít programy stanovené v systému',
+        'OptionsProgramsUser' => 'Použít jiné programy',
+        'OptionsProgramsSet' => 'Nastavit programy',
         'OptionsPathImagesGroup' => 'Obrázky',
         'OptionsInternetDataGroup' => 'Import dat',
         'OptionsInternetSettingsGroup' => 'Nastavení',
@@ -313,14 +325,15 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Předpona použitá pro obrázky:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Titul nebo název asociované položky',
-        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
-        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% nebo . bude nahrazen adresářem se sbírkou (používat pouze pro začátek cesty)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% bude nahrazen názvem sbírky bez přípony (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% může být použit pouze pro začátek cesty s obrázky',
         'OptionsConfigureMailers' => 'Nastavení e-mailových programů',
 
         'ImagesOptionsButton' => 'Nastavení',
         'ImagesOptionsTitle' => 'Nastavení pro seznam obrázků',
         'ImagesOptionsSelectColor' => 'Vybrat barvu',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Pozadí',
         'ImagesOptionsBgPicture' => 'Použít obrázek na pozadí',
         'ImagesOptionsFg'=> 'Výběr',
@@ -333,10 +346,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Nastavení detailního seznamu',
         'DetailedOptionsImageSize' => 'Velikost obrázků',
         'DetailedOptionsGroupItems' => 'Řadit podle',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Výběr zobrazených polí',
-		'DetailedOptionsMasterOption' => 'Hlavní skupina je',
-		'DetailedOptionsMasterGenerated' => 'Generována automaticky',
-		'DetailedOptionsMasterOrdered' => 'Určena podle',
+        'DetailedOptionsGroupedFirst' => 'Osiřelé položky nechat pohromadě',
+        'DetailedOptionsAddCount' => 'Zobrazit počet prvků v kategoriích',
 
         'ExtractButton' => 'Informace',
         'ExtractTitle' => 'Informace o video souboru',
@@ -345,12 +358,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Nahrát seznam polí ze souboru',
         'FieldsListSave' => 'Uložit seznam polí do souboru',
         'FieldsListError' => 'Tento seznam polí nemůže být použit s tímto typem sbírky',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Export seznamu',
         'ExportFilter' => 'Export pouze zobrazených položek',
         'ExportFieldsTitle' => 'Pole k exportu',
         'ExportFieldsTip' => 'Vyber pole k exportu',
         'ExportWithPictures' => 'Zkopírovat obrázky do podadresáře',
+        'ExportSortBy' => 'Řadit podle',
 
         'ImportListTitle' => 'Import dalšího seznamu',
         'ImportExportData' => 'Data',
@@ -367,7 +382,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Vytvořit novou kolekci',
         'ImportCurrentList' => 'Přidat do stávající kolekce',
         'ImportDropError' => 'Při otevírání souboru se vyskytl problém. Znovu se načte předchozí seznam.',
-        'ImportGenerateId' => 'Generate identifier for each item',
+        'ImportGenerateId' => 'Vytvořit identifikátor pro každou položku',
 
         'FileOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',
 
@@ -383,7 +398,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Vyberte obrázek',
         'PanelImageNoImage' => 'Bez obrázku',
         'PanelSelectFileTitle' => 'Vyberte soubor',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'Obnovit výchozí nastavení',
 
         'PanelFrom' =>'Od',
         'PanelTo' =>'Do',
@@ -393,9 +408,10 @@ http://le-spektre.org',
         'PanelRemoveTip' => 'Odstraní stávající položku',
 
         'PanelDateSelect' => 'Vyberte datum',
-        'PanelNobody' => 'Nikomu',
-        'PanelUnknown' => 'Neznámo',
+        'PanelNobody' => 'Žádný',
+        'PanelUnknown' => 'Neznámý',
         'PanelAdded' => 'Přidáno',
+        'PanelRating' => 'Hodnocení',
         'PanelLocation' => 'Umístění',
 
         'PanelLending' => 'Zápůjčky',
@@ -407,6 +423,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Půjčeno',
         'PanelLendedNo' => 'Dostupné',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Nezáleží',
         'CheckYes' => 'Ano',
         'CheckNo' => 'Ne',
@@ -516,6 +536,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Položky odpovídají všem podmínkám',
         'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce',
         'AdvancedSearchCriteria' => 'Podmínky',
+        'AdvancedSearchAnyField' => 'Any field',
+
+        'BugReportSubject' => 'Zpráva o chybě generovaná z GCstar',
+        'BugReportVersion' => 'Verze',
+        'BugReportPlatform' => 'Operační systém',
+        'BugReportMessage' => 'Chybová zpráva',
+        'BugReportInformation' => 'Další informace',
     );
 }
 1;
