@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Ungültige Templatedatei',
+        'UseFile' => 'Nutze angegebene Datei',
+        'TemplateExternalFile' => 'Templatedatei',
         'WithJS' => 'Javascript verwenden',
        	'FileTemplate' => 'Template:',
         'Preview' => 'Vorschau',
@@ -53,7 +56,8 @@
         'CollapseTitle' => 'Nur Titel anzeigen',
         'Borrowed' => 'Ausgeliehen von: ',
         'NotBorrowed' => 'Verfügbar',
-        'Top' => 'Top',
+        'Top' => 'Oben',
+        'Bottom' => 'Unten',
      );
 }
 
