@@ -43,10 +43,10 @@
         Publication => 'Erscheinungsdatum',
         Language => 'Sprache',
         Genre => 'Genre',
+        Serie => 'Sammlung',
         Bookdescription => 'Beschreibung',
         Pages => 'Seiten',
         Read => 'Gelesen',
-        Rating => 'Bewertung',
         Acquisition => 'Anschaffungsdatum',
         Edition => 'Edition',
         Format => 'Format',
