@@ -47,12 +47,14 @@
         Image => 'Bild',
         Original => 'Originaltitel',
         Actors => 'Besetzung',
+        Actor => 'Schauspieler/in',
+        Role => 'Rolle',
         Comment => 'Kommentar',
         Synopsis => 'Beschreibung',
         Seen => 'Gesehen',
         Number => '# der Medien',
-        Rating => 'Bewertung',
         Format => 'Format',
+        Identifier => 'Identifier',
         Url => 'Internetseite',
         Audio => 'Audio',
         Video => 'Videoformat',
@@ -65,8 +67,8 @@
         SeenNo => 'Film noch nicht gesehen',
 
         AgeUnrated => 'Unbewertet',
-        AgeAll => 'Jedes Alter',
-        AgeParent => 'Aufsicht der Eltern',
+        AgeAll => 'Ohne Altersbeschränkung',
+        AgeParent => '6',
 
         Main => 'Wichtigste Felder',
         General => 'Allgemein',
