@@ -85,6 +85,7 @@ Webseite, von der die Informationen stammen.',
 	'SplashInit' => 'Initialisiere',
 	'SplashLoad' => 'Lade Sammlung',
     'SplashDisplay' => 'Sammlung anzeigen',
+    'SplashSort' => 'Sammlung sortieren',
 	'SplashDone' => 'Fertig',
 
 #Import from GCfilms
@@ -171,8 +172,9 @@ Webseite, von der die Informationen stammen.',
         'AboutDesc' => 'Gtk2 Sammlungs Manager',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
-        'AboutWho' => 'Tian : Projektmanager, Programmierer
-Adolfo González : Programmierer',
+        'AboutWho' => 'Christian Jodar (Tian) : Projektmanager, Programmierer
+Adolfo González : Programmierer
+Nyall Dawson (Zombiepig) : Programmierer',
         'AboutLicense' => 'Veröffentlicht unter den Bedingungen der GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -232,6 +234,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'Für Abspielen Knopf',
         'ModelCollectionSettings' => 'Sammlungseinstellungen',
         'ModelCollectionSettingsLending' => 'Elemente können verborgt werden',
+        'ModelCollectionSettingsTagging' => 'Elemente können getaggt werden',
         'ModelFilterActivated' => 'Soll in Suchfeld sein',
         'ModelFilterComparison' => 'Vergleich',
         'ModelFilterContain' => 'Beinhaltet',
@@ -243,18 +246,20 @@ http://le-spektre.org',
         'ModelTooltipGroup' => 'Kann zum gruppieren verwendet werden. Elemente ohne Gruppenangabe werden in einer vorgegebenen Gruppe zusammengefasst',
         'ModelTooltipHistory' => 'Alle hier eingegebenen Werte werden in einer Liste gespeichert und können darüber auch wieder ausgewählt werden',
         'ModelTooltipFormat' => 'Das Format wird benutzt, um eine geeignete Anwendung mit dem "Öffnen"-Knopf zu verbinden',
-        'ModelTooltipLending' => 'Fügt Felder zum handhaben der Ausleihe hinzu',
+        'ModelTooltipLending' => 'Fügt Felder zur Verwaltung der Ausleihe hinzu',
+        'ModelTooltipTagging' => 'Fügt Felder zur Verwaltung von Tags hinzu',
         'ModelTooltipNumeric' => 'In Vergleichsoperationen wird der Wert als Zahl interpretiert',
         'ModelTooltipQuick' => 'Fügt ein Untermenü zu "Filter" hinzu',
 
         'ResultsTitle' => 'Wählen Sie einen Eintrag',
         'ResultsNextTip' => 'Auf der nächsten Seite suchen',
         'ResultsPreview' => 'Vorschau',
+        'ResultsInfo' => 'Es können mehrere Elemente durch Auswahl bei gedrückter STRG oder UMSCHALT Taste zu der Sammlung hinzugefügt werden.',
         
         'OptionsTitle' => 'Einstellungen',
         'OptionsBrowser' => 'Web-Browser',
-        'OptionsPlayer' => 'Video-Player',
-        'OptionsAudio' => 'Audio-Player',
+        'OptionsPlayer' => 'Videoabspielprogramm',
+        'OptionsAudio' => 'Musikabspielprogramm',
         'OptionsImages' => 'Verzeichnis für Bilder',
         'OptionsUseRelativePaths' => 'Relative Pfade für Bilder verwenden',
         'OptionsLayout' => 'Layout',
@@ -264,6 +269,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Sammlung automatisch speichern',
         'OptionsAutoLoad' => 'Vorhergehende Sammlung beim Programmstart laden',
         'OptionsSplash' => 'Splash-Screen anzeigen',
+        'OptionsSpellCheck' => 'Rechtschreibprüfung für lange Textfelder verwenden',
         'OptionsImagesTitle' => 'Wählen Sie ein Verzeichnis',
         'OptionsProgramTitle' => 'Wählen Sie die gewünschte Anwendung',
 		'OptionsPlugins' => 'Seite zum Bezug von Informationen',
@@ -273,6 +279,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Sammlung bearbeiten',
         'OptionsAskImport' => 'Zu importierende Felder wählen',
 		'OptionsProxy' => 'Proxy verwenden',
+		'OptionsCookieJar' => 'Nutze diese jar-Datei für Cookies',
         'OptionsLang' => 'Sprache',
         'OptionsMain' => 'Allgemein',
         'OptionsPaths' => 'Pfade',
@@ -280,9 +287,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Eigenschaften',
         'OptionsDisplay' => 'Anzeige',
         'OptionsToolbar' => 'Werkzeugleiste',
-        'OptionsToolbars' => {0 => 'Keine', 1 => 'Klein', 2 => 'Gross'},
+        'OptionsToolbars' => {0 => 'Keine', 1 => 'Klein', 2 => 'Groß', 3 => 'Systemeinstellung'},
         'OptionsToolbarPosition' => 'Position',
         'OptionsToolbarPositions' => {0 => 'Oben', 1 => 'Unten', 2 => 'Links', 3 => 'Rechts'},
+        'OptionsExpandersMode' => 'ausklappbare Zeile zu lang',
+        'OptionsExpandersModes' => {'asis' => 'Tue nichts', 'cut' => 'Abschneiden', 'wrap' => 'Zeilenumbruch'},
+        'OptionsDateFormat' => 'Datumsformat',
+        'OptionsDateFormatTooltip' => 'Das Format entspricht dem bei der Funktion strftime(3) genutzten. Voreinstellung ist %d/%m/%Y',
         'OptionsView' => 'Listenansicht',
         'OptionsViews' => {0 => 'Text', 1 => 'Bilder', 2 => 'Detailliert'},
         'OptionsColumns' => 'Spalten',
@@ -293,14 +304,15 @@ http://le-spektre.org',
         'OptionsArticles' => 'Artikel (getrennt durch Kommata)',
         'OptionsSearchStop' => 'Suche kann abgebrochen werden',
         'OptionsAlwaysOriginal' => 'Titel statt Originaltitel verwenden, wenn dieser nicht vorhanden ist',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Größe des Verlaufs',
         'OptionsClearHistory' => 'Verlauf löschen',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Nicht mehr fragen',
         'OptionsPathProgramsGroup' => 'Anwendungsprogramme',
-        'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
-        'OptionsProgramsSet' => 'Set programs',
+        'OptionsProgramsSystem' => 'Nutze systemweite Einstellungen',
+        'OptionsProgramsUser' => 'Nutze hier angegebene Programme',
+        'OptionsProgramsSet' => 'Setze Programme',
         'OptionsPathImagesGroup' => 'Bilder',
         'OptionsInternetDataGroup' => 'Datenimport',
         'OptionsInternetSettingsGroup' => 'Einstellungen',
@@ -313,14 +325,15 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Prefix für Bilddateien:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Titel oder Name für das verbundene Element',
-        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
-        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% oder . wird durch das Verzeichnis der Sammlung ersetzt (nur am Anfang der Pfadangabe nutzen!)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% wird durch den Dateinamen der Sammlung ohne Erweiterung (.gcs) ersetzt',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% kann nur am Anfang der Pfadangabe für die Bilder genutzt werden',
         'OptionsConfigureMailers' => 'Email Programmeinstellung',
 
         'ImagesOptionsButton' => 'Einstellungen',
         'ImagesOptionsTitle' => 'Einstellungen für die Bilderliste',
         'ImagesOptionsSelectColor' => 'Farbe wählen',
+        'ImagesOptionsUseOverlays' => '3D-Rahmen um Bild',
         'ImagesOptionsBg' => 'Hintergrund',
         'ImagesOptionsBgPicture' => 'Hintergrundbild verwenden',
         'ImagesOptionsFg'=> 'Auswahl',
@@ -333,10 +346,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Einstellungen für die detaillierte Sammlung',
         'DetailedOptionsImageSize' => 'Bildgröße',
         'DetailedOptionsGroupItems' => 'Gruppiere Elemente nach',
+        'DetailedOptionsSecondarySort' => 'Sortiere gruppierte Felder nach',
 		'DetailedOptionsFields' => 'Anzuzeigende Felder wählen',
-		'DetailedOptionsMasterOption' => 'Hauptelement der Gruppe',
-		'DetailedOptionsMasterGenerated' => 'Automatisch generiert',
-		'DetailedOptionsMasterOrdered' => 'Bestimmt durch',
+        'DetailedOptionsGroupedFirst' => 'leere Elemente zusammenhalten',
+        'DetailedOptionsAddCount' => 'Anzahl der enthaltenen Elemente anzeigen',
 
         'ExtractButton' => 'Information',
         'ExtractTitle' => 'Dateiinformationen',
@@ -345,12 +358,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Lade Liste von Feldern aus Datei',
         'FieldsListSave' => 'Speichere Liste von Feldern in Datei',
         'FieldsListError' => 'Diese Liste von Feldern kann nicht für diese Sammlung benutzt werden',
+        'FieldsListIgnore' => '--- Ignoriere',
 
         'ExportTitle' => 'Sammlung exportieren',
         'ExportFilter' => 'Nur angezeigte Elemente exportieren',
         'ExportFieldsTitle' => 'Zu exportierende Felder',
         'ExportFieldsTip' => 'Wählen Sie die zu exportierenden Felder',
         'ExportWithPictures' => 'Bilder in ein Unterverzeichnis kopieren',
+        'ExportSortBy' => 'Sortierung nach',
 
         'ImportListTitle' => 'Eine weitere Sammlung importieren',
         'ImportExportData' => 'Data',
@@ -383,10 +398,10 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Wählen Sie ein Bild',
         'PanelImageNoImage' => 'kein Bild',
         'PanelSelectFileTitle' => 'Datei auswählen',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'Voreinstellung herstellen',
 
-        'PanelFrom' =>'From',
-        'PanelTo' =>'To',
+        'PanelFrom' =>'Von',
+        'PanelTo' =>'Bis',
 
         'PanelWeb' => 'Zeige Informationen',
         'PanelWebTip' => 'Zeige Informationen über dieses Element im Internet',
@@ -396,6 +411,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Niemand',
         'PanelUnknown' => 'Unbekannt',
         'PanelAdded' => 'Hinzufügedatum',
+        'PanelRating' => 'Bewertung',
         'PanelLocation' => 'Ort',
 
         'PanelLending' => 'Verleih',
@@ -407,6 +423,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Verliehen',
         'PanelLendedNo' => 'Verfügbar',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favoriten',
+        'TagsAssigned' => 'Zugeordnete Tags', 
+
         'CheckUndef' => 'Egal',
         'CheckYes' => 'Ja',
         'CheckNo' => 'Nein',
@@ -469,7 +489,7 @@ http://le-spektre.org',
         'MultiSiteTitle' => 'Seite für Internetrecherche',
         'MultiSiteUnused' => 'Nicht verwendete Plugins',
         'MultiSiteUsed' => 'Zu verwendende Plugins',
-        'MultiSiteLang' => 'sprachige eutschsprachige Plugins verwenden',
+        'MultiSiteLang' => 'deutschsprachige Plugins verwenden',
         'MultiSiteEmptyError' => 'Die Liste der zu verwendenden Plugins ist leer!',
         'MultiSiteClear' => 'Liste löschen',
 
@@ -516,6 +536,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Elemente, die alle Kriterien erfüllen',
         'AdvancedSearchTypeOr' => 'Elemente, die mindestens ein Kriterium erfüllen',
         'AdvancedSearchCriteria' => 'Suchkriterium',
+        'AdvancedSearchAnyField' => 'In allen Elementen',
+
+        'BugReportSubject' => 'Fehlermeldung erstellt von GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Betriebssystem',
+        'BugReportMessage' => 'Fehlermeldung',
+        'BugReportInformation' => 'Zusätzliche Informationen',
     );
 }
 1;
