@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Books collection',
-        Items => 'Books',
+        Items => {0 => 'Book',
+                  1 => 'Book',
+                  X => 'Books'},
         NewItem => 'New book',
     
         Isbn => 'ISBN',
@@ -43,10 +45,10 @@
         Publication => 'Publication date',
         Language => 'Language',
         Genre => 'Genre',
+        Serie => 'Series',
         Bookdescription => 'Description',
         Pages => 'Pages',
         Read => 'Read',
-        Rating => 'Rating',
         Acquisition => 'Acquisition date',
         Edition => 'Edition',
         Format => 'Format',
