@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Movies collection',
-        Items => 'Movies',
+        Items => {0 => 'Movie',
+                  1 => 'Movie',
+                  X => 'Movies'},
         NewItem => 'New movie',
     
     
@@ -47,17 +49,19 @@
         Image => 'Picture',
         Original => 'Original title',
         Actors => 'Cast',
+        Actor => 'Actor',
+        Role => 'Role',
         Comment => 'Comments',
         Synopsis => 'Synopsis',
         Seen => 'Viewed',
         Number => '# of Media',
-        Rating => 'Rating',
         Format => 'Media',
+        Identifier => 'Identifier',
         Url => 'Web page',
         Audio => 'Audio',
         Video => 'Video format',
         Trailer => 'Video file',
-        Serie => 'Serie',
+        Serie => 'Series',
         Rank => 'Rank',
         Subtitles => 'Subtitles',
 
