@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Video games collection',
-        Items => 'Games',
+        Items => {0 => 'Game',
+                  1 => 'Game',
+                  X => 'Games'},
         NewItem => 'New game',
     
         Id => 'Id',
@@ -47,8 +49,8 @@
         Box => 'Box picture',
         Case => 'Case',
         Manual => 'Instructions manual',
-        Rating => 'Rating',
         Completion => 'Completion (%)',
+        Executable => 'Executable',
         Description => 'Description',
         Codes => 'Codes',
         Code => 'Code',
