@@ -86,6 +86,7 @@ may use the <b>button below item details</b>.',
         'SplashInit' => 'Initialization',
         'SplashLoad' => 'Loading Collection',
         'SplashDisplay' => 'Displaying Collection',
+        'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'Ready',
 
 #Import from GCfilms
@@ -169,15 +170,16 @@ may use the <b>button below item details</b>.',
         'RandomOkTip'=> 'Accept this item',
         
         'AboutTitle' => 'About GCstar',
-        'AboutDesc' => 'Collection manager',
+        'AboutDesc' => 'Personal collections manager',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
-        'AboutWho' => 'Tian: Project manager, Programmer
-Adolfo González : Programmer',
+        'AboutWho' => 'Christian Jodar (Tian): Project manager, Programmer
+Adolfo González: Programmer
+Nyall Dawson (Zombiepig): Programmer',
         'AboutLicense' => 'Distributed under the terms of the GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
-        'AboutTranslation' => 'English translation by Tian and Jason Day',
+        'AboutTranslation' => 'English translation by Christian Jodar and Jason Day',
         'AboutDesign' => 'Logo and webdesign by le Spektre',
 
         'ToolbarRandom' => 'Tonight',
@@ -232,7 +234,8 @@ http://le-spektre.org',
         'ModelOptionsFieldsCover' => 'As cover',
         'ModelOptionsFieldsPlay' => 'For Play button',
         'ModelCollectionSettings' => 'Collection settings',
-        'ModelCollectionSettingsLending' => 'Items could be borrowed',
+        'ModelCollectionSettingsLending' => 'Items can be borrowed',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
@@ -245,12 +248,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
         'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
         'ModelTooltipLending' => 'This will add some fields to manage lendings',
-        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
+        'ModelTooltipNumeric' => 'Should the values be considered as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
         'ResultsTitle' => 'Select an item',
         'ResultsNextTip' => 'Search in next site',
         'ResultsPreview' => 'Preview',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Preferences',
         'OptionsBrowser' => 'Web browser',
@@ -265,6 +270,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Automatically save collection',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Show splash screen',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Select a directory',
         'OptionsProgramTitle' => 'Select the program to be used',
 		'OptionsPlugins' => 'Site to retrieve data from',
@@ -274,6 +280,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Set list',
         'OptionsAskImport' => 'Select fields to be imported',
 		'OptionsProxy' => 'Use a proxy',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Language',
         'OptionsMain' => 'Main',
         'OptionsPaths' => 'Paths',
@@ -281,9 +288,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Features',
         'OptionsDisplay' => 'Display',
         'OptionsToolbar' => 'Toolbar',
-        'OptionsToolbars' => {0 => 'None', 1 => 'Small', 2 => 'Large'},
+        'OptionsToolbars' => {0 => 'None', 1 => 'Small', 2 => 'Large', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Position',
         'OptionsToolbarPositions' => {0 => 'Top', 1 => 'Bottom', 2 => 'Left', 3 => 'Right'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Items list',
         'OptionsViews' => {0 => 'Text', 1 => 'Image', 2 => 'Detailed'},
         'OptionsColumns' => 'Columns',
@@ -294,6 +305,7 @@ http://le-spektre.org',
         'OptionsArticles' => 'Articles (Comma separated)',
         'OptionsSearchStop' => 'Allow search to be aborted',
         'OptionsAlwaysOriginal' => 'Use main title as the original title if none present',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Size of history',
         'OptionsClearHistory' => 'Clear history',
 		'OptionsStyle' => 'Skin',
@@ -317,12 +329,12 @@ http://le-spektre.org',
         'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
         'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
         'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Configure mailing programs',
 
         'ImagesOptionsButton' => 'Settings',
         'ImagesOptionsTitle' => 'Settings for images list',
         'ImagesOptionsSelectColor' => 'Select a color',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Background',
         'ImagesOptionsBgPicture' => 'Use a background picture',
         'ImagesOptionsFg'=> 'Selection',
@@ -335,10 +347,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Settings for detailed list',
         'DetailedOptionsImageSize' => 'Images size',
         'DetailedOptionsGroupItems' => 'Group items by',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Select fields to display',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'Information',
         'ExtractTitle' => 'File information',
@@ -347,12 +359,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Load a fields list from a file',
         'FieldsListSave' => 'Save fields list to a file',
         'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Export item list',
         'ExportFilter' => 'Export only displayed items',
         'ExportFieldsTitle' => 'Fields to be exported',
         'ExportFieldsTip' => 'Select fields you want to export',
         'ExportWithPictures' => 'Copy pictures in a sub-directory',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'Import another items list',
         'ImportExportData' => 'Data',
@@ -399,6 +413,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Nobody',
         'PanelUnknown' => 'Unknown',
         'PanelAdded' => 'Add date',
+        'PanelRating' => 'Rating',
         'PanelLocation' => 'Location',
 
         'PanelLending' => 'Lending',
@@ -410,6 +425,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Lended',
         'PanelLendedNo' => 'Available',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Either',
         'CheckYes' => 'Yes',
         'CheckNo' => 'No',
@@ -519,7 +538,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Items matching all criteria',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'Any field',
  
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
