@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Fichero de plantilla inválido',
+        'UseFile' => 'Usar el fichero especificado abajo',
+        'TemplateExternalFile' => 'Fichero de plantilla',
         'WithJS' => 'Utilizar Javascript',
        	'FileTemplate' => 'Plantilla :',
         'Preview' => 'Vista previa',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Prestatario : ',
         'NotBorrowed' => 'Disponible',
         'Top' => 'Arriba',
+        'Bottom' => 'Bottom',
      );
 }
 
