@@ -47,12 +47,14 @@
         Image => 'Imagen',
         Original => 'Título original',
         Actors => 'Actores',
+        Actor => 'Actor',
+        Role => 'Papel',
         Comment => 'Comentarios',
         Synopsis => 'Sinopsis',
         Seen => 'Ya vista',
         Number => 'Número',
-        Rating => 'Nota',
         Format => 'Soporte',
+        Identifier => 'Identificador',
         Url => 'URL',
         Audio => 'Audio',
         Video => 'Formato de video',
