@@ -86,6 +86,7 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'SplashInit' => 'Inicialización',
         'SplashLoad' => 'Cargando películas',
         'SplashDisplay' => 'Mostrando Colección',
+        'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'Listo',
 
 #Import from GCfilms
@@ -172,12 +173,13 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'AboutDesc' => 'Gestión de Colecciones',
         'AboutVersion' => 'Versión',
         'AboutTeam' => 'Equipo',
-        'AboutWho' => 'Tian : Gestión del proyecto, Programación
-Adolfo González : Programación',
+        'AboutWho' => 'Christian Jodar (Tian) : Gestión del proyecto, Programación
+Adolfo González Blázquez : Programación
+Nyall Dawson (Zombiepig) : Programación',
         'AboutLicense' => 'Distribuido según los términos de la GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
-        'AboutTranslation' => 'Traducción : Adolfo González',
+        'AboutTranslation' => 'Traducción : Adolfo González Blázquez',
         'AboutDesign' => 'Logo y diseño web por le Spektre',
         
         'ToolbarRandom' => 'Esta noche',
@@ -233,6 +235,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'Como botón de Reproducir',
         'ModelCollectionSettings' => 'Preferencias de la colección',
         'ModelCollectionSettingsLending' => 'Los elementos se pueden prestar',
+        'ModelCollectionSettingsTagging' => 'Los elementos se pueden etiquetar',
         'ModelFilterActivated' => 'Debe aparecer en la caja de búsqueda',
         'ModelFilterComparison' => 'Comparación',
         'ModelFilterContain' => 'Contiene',
@@ -245,12 +248,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => '¿Deberían almacenarse los valores introducidos anteriormente en una lista asociada al campo?',
         'ModelTooltipFormat' => 'El formato se usa para determinar la acción para abrir  el fichero al pulsar el botón de Reproducir',
         'ModelTooltipLending' => 'Se añadirán algunos campos para administrar los préstamos',
+        'ModelTooltipTagging' => 'Se añadirán algunos campos para administrar las etiquetas',
         'ModelTooltipNumeric' => '¿Se deberían considerar los valores como números para las comparaciones?',
         'ModelTooltipQuick' => 'Esto añadirá un submenu dentro del menu de Filtros',
 
         'ResultsTitle' => 'Elija una película',
         'ResultsNextTip' => 'Buscar en el siguiente sitio',
         'ResultsPreview' => 'Previsualizar',
+        'ResultsInfo' => 'Puedes añadir varios elementos a la colección presionando Control ó Mayúsculas y seleccionándolos',
 
         'OptionsTitle' => 'Preferencias',
         'OptionsBrowser' => 'Navegador de Internet',
@@ -265,6 +270,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Protección automática de la lista de películas',
         'OptionsAutoLoad' => 'Cargar la colección anterior en el inicio',
         'OptionsSplash' => 'Mostrar la pantalla de arranque',
+        'OptionsSpellCheck' => 'Usar corrector de ortografía en los campos de texto largos',
         'OptionsImagesTitle' => 'Elija un directorio',
         'OptionsProgramTitle' => 'Elija el programa que debe utilizarse',
         'OptionsPlugins' => 'Sitio para descargar las fichas',
@@ -274,6 +280,7 @@ http://le-spektre.org',
         'OptionsPluginsList' => 'Definir la lista',
         'OptionsAskImport' => 'Elegir los campos que deben importarse',
         'OptionsProxy' => 'Utilizar un proxy',
+		'OptionsCookieJar' => 'Usar este fichero de cookie jar',
         'OptionsMain' => 'Principal',
         'OptionsLang' => 'Idioma',
         'OptionsPaths' => 'Directorios',
@@ -281,9 +288,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Opciones',	
         'OptionsDisplay' => 'Visualización',
         'OptionsToolbar' => 'Barra de herramientas',	
-        'OptionsToolbars' => {0 => 'Ninguna', 1 => 'Pequeña', 2 => 'Grande'},
+        'OptionsToolbars' => {0 => 'Ninguna', 1 => 'Pequeña', 2 => 'Grande', 3 => 'Predeterminado del sistema'},
         'OptionsToolbarPosition' => 'Posición',
         'OptionsToolbarPositions' => {0 => 'Arriba', 1 => 'Abajo', 2 => 'Izquierda', 3 => 'Derecha'},
+        'OptionsExpandersMode' => 'Extensores demasiado largos',
+        'OptionsExpandersModes' => {'asis' => 'No hacer nada', 'cut' => 'Cortar', 'wrap' => 'Dividir las lineas'},
+        'OptionsDateFormat' => 'Formato de fecha',
+        'OptionsDateFormatTooltip' => 'El formato usado es el mismo de strftime(3). El predeterminado es %d/%m/%Y',
         'OptionsView' => 'Visualización de las películas',
         'OptionsViews' => {0 => 'Texto', 1 => 'Imagen', 2 => 'Detallada'},
         'OptionsColumns' => 'Columnas',	
@@ -294,14 +305,15 @@ http://le-spektre.org',
         'OptionsArticles' => 'Artículos (separados por una coma)',	
         'OptionsSearchStop' => 'El usuario puede parar las búsquedas',
         'OptionsAlwaysOriginal' => 'Usar título principal como el original si no se encuentra ninguno',
+        'OptionsRestoreAccelerators' => 'Restaurar aceleradores',
         'OptionsHistory' => 'Tamaño del historial',
         'OptionsClearHistory' => 'Limpiar el historial',
         'OptionsStyle' => 'Piel',
         'OptionsDontAsk' => 'No preguntar nunca más',
         'OptionsPathProgramsGroup' => 'Aplicaciones',
-        'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
-        'OptionsProgramsSet' => 'Set programs',
+        'OptionsProgramsSystem' => 'Usar programas predefinidos del sistema',
+        'OptionsProgramsUser' => 'Usar programas definidos por el usuario',
+        'OptionsProgramsSet' => 'Establecer programas',
         'OptionsPathImagesGroup' => 'Imágenes',
         'OptionsInternetDataGroup' => 'Importar datos',
         'OptionsInternetSettingsGroup' => 'Preferencias',
@@ -311,17 +323,18 @@ http://le-spektre.org',
         'OptionsImagesStyleGroup' => 'Estilo',
         'OptionsDetailedPreferencesGroup' => 'Preferencias',
         'OptionsFeaturesConveniencesGroup' => 'conveniencias',
-        'OptionsPicturesFormat' => 'Prefijo para uasr en las imágenes:',
+        'OptionsPicturesFormat' => 'Prefijo para usar en las imágenes:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Título o nombre del elemento asociado',
-        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
-        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% o . se reemplazará con el directorio de la colección (usar sólo al principio de la ruta)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% se reemplazará por el nombre de la colecciñón si el sufijo (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% sólo se puede usar al principio de la ruta para imágenes',
         'OptionsConfigureMailers' => 'Configurar programas de envío correo',
 		       
-	'ImagesOptionsButton' => 'Preferencias',
+        'ImagesOptionsButton' => 'Preferencias',
         'ImagesOptionsTitle' => 'Preferencias para el listado de imágenes',
         'ImagesOptionsSelectColor' => 'Elija un color',
+        'ImagesOptionsUseOverlays' => 'Utilizar superposición de imágenes',
         'ImagesOptionsBg' => 'Fondo',
         'ImagesOptionsBgPicture' => 'Usar una imagen de fondo',
         'ImagesOptionsFg'=> 'Selección',
@@ -334,10 +347,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Preferencias del listado detallado',
         'DetailedOptionsImageSize' => 'Tamaño de la imagen',
         'DetailedOptionsGroupItems' => 'Agrupar elementos por',
+        'DetailedOptionsSecondarySort' => 'Ordenar los campos por el hijo',
         'DetailedOptionsFields' => 'Seleccione los campos a mostrar',
-	'DetailedOptionsMasterOption' => 'Elemento principal del grupo',
-	'DetailedOptionsMasterGenerated' => 'Autogenerado',
-	'DetailedOptionsMasterOrdered' => 'Determinado por',
+        'DetailedOptionsGroupedFirst' => 'Mantener juntos los elementos huérfanos',
+        'DetailedOptionsAddCount' => 'Añadir el número de elementos en las categorías',
 
         'ExtractButton' => 'Información',
         'ExtractTitle' => 'Información del Fichero de Video',
@@ -346,12 +359,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Leer los campos de la lista desde un fichero',
         'FieldsListSave' => 'Guardar los campos de la lista a un fichero',
         'FieldsListError' => 'Estos campor no se pueden usar con este tipo de colección',
+        'FieldsListIgnore' => '--- Ignorar',
 
         'ExportTitle' => 'Exportar el listado de películas',	
         'ExportFilter' => 'Exportar sólo las películas mostradas',
         'ExportFieldsTitle' => 'Campos a exportar',
         'ExportFieldsTip' => 'Elija los campos a exportar',
         'ExportWithPictures' => 'Copiar las imágenes a un subdirectorio',
+        'ExportSortBy' => 'Ordenar por',
 
         'ImportListTitle' => 'Importar otro listado de películas',
         'ImportExportData' => 'Datos',
@@ -384,7 +399,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Seleccionar una imagen',	
         'PanelImageNoImage' => 'Sin imagen',
         'PanelSelectFileTitle' => 'Seleccione un fichero',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'Restaurar predeterminado',
 
         'PanelFrom' =>'De',
         'PanelTo' =>'Para',
@@ -397,6 +412,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Nadie',	
         'PanelUnknown' => 'Desconocido',	
         'PanelAdded' => 'Añadida el (fecha)',
+        'PanelRating' => 'Nota',
         'PanelLocation' => 'Sitio',
 
         'PanelLending' => 'Préstamo',
@@ -408,6 +424,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Prestada',
         'PanelLendedNo' => 'Disponible',
 
+        'PanelTags' => 'Etiquetas',
+        'PanelFavourite' => 'Favorita',
+        'TagsAssigned' => 'Etiquetas asignadas', 
+
         'CheckUndef' => 'Cualquiera',
         'CheckYes' => 'Si',
         'CheckNo' => 'No',
@@ -517,6 +537,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Elementos que cumplan todos los criterios',
         'AdvancedSearchTypeOr' => 'Elementos que cunplan al menos un criterio',
         'AdvancedSearchCriteria' => 'Critero',
+        'AdvancedSearchAnyField' => 'Cualquier campo',
+
+        'BugReportSubject' => 'Informe de error generado por GCstar',
+        'BugReportVersion' => 'Versión',
+        'BugReportPlatform' => 'Sistema operativo',
+        'BugReportMessage' => 'Mensaje de error',
+        'BugReportInformation' => 'Información adicional',
     );
 }
 1;
