@@ -30,14 +30,17 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Ficher de modèle invalide',
+        'UseFile' => 'Utiliser le fichier ci-dessous',
+        'TemplateExternalFile' => 'Fichier avec le modèle',
         'WithJS' => 'Utiliser du Javascript',
-       	'FileTemplate' => 'Modèle :',
+       	'FileTemplate' => 'Modèle',
         'Preview' => 'Aperçu',
         'NoPreview' => 'Aucun aperçu disponible',
         'Title' => 'Titre de la page',
         'InfoFile' => 'La liste se trouve dans le fichier : ',
         'InfoDir' => 'Les images se trouvent dans : ',
-        'HeightImg' => 'Hauteur en pixels des images : ',
+        'HeightImg' => 'Hauteur en pixels des images',
         'OpenFileInBrowser' => 'Ouvrir le fichier généré dans le navigateur web',
         'Note' => 'Liste générée avec <a href="http://www.gcstar.org/">GCstar</a>',
         'InputTitle' => 'Entrez le texte à rechercher',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Emprunté par : ',
         'NotBorrowed' => 'Disponible',
         'Top' => 'Haut',
+        'Bottom' => 'Bas',
      );
 }
 
