@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Collection de livres',
-        Items => 'Livres',
+        Items => {0 => 'Livre',
+                  1 => 'Livre',
+                  X => 'Livres'},
         NewItem => 'Nouveau livre',
     
         Isbn => 'ISBN',
@@ -43,17 +45,17 @@
         Publication => 'Date de publication',
         Language => 'Langue',
         Genre => 'Genres',
+        Serie => 'Série',
         Bookdescription => 'Description',
         Pages => 'Pages',
         Read => 'Lu',
-        Rating => 'Note',
         Acquisition => 'Date d\'acquisition',
         Edition => 'Edition',
         Format => 'Format',
         Comments => 'Commentaires',
         Url => 'Page web',
-        Translator => 'Translator',
-        Artist => 'Artist',
+        Translator => 'Traducteur',
+        Artist => 'Artiste',
 
         General => 'Fiche',
         Details => 'Détails',
