@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Collection de films',
-        Items => 'Films',
+        Items => {0 => 'Film',
+                  1 => 'Film',
+                  X => 'Films'},
         NewItem => 'Nouveau film',
     
     
@@ -47,12 +49,14 @@
         Image => 'Image',
         Original => 'Titre original',
         Actors => 'Acteurs',
+        Actor => 'Acteur',
+        Role => 'Rôle',
         Comment => 'Commentaires',
         Synopsis => 'Synopsis',
         Seen => 'Film déjà vu',
         Number => 'Nombre',
-        Rating => 'Note',
         Format => 'Format',
+        Identifier => 'Identifiant',
         Url => 'Page web',
         Audio => 'Audio',
         Video => 'Format vidéo',
