@@ -32,7 +32,9 @@
     our %lang = (
     
         CollectionDescription => 'Collection musicale',
-        Items => 'Albums',
+        Items => {0 => 'Album',
+                  1 => 'Album',
+                  X => 'Albums'},
         NewItem => 'Nouvel album',
     
         Unique => 'ISRC/EAN',
