@@ -87,6 +87,7 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'SplashInit' => 'Initialisation',
         'SplashLoad' => 'Chargement de la collection',
         'SplashDisplay' => 'Affichage de la collection',
+        'SplashSort' => 'Tri de la collection',
         'SplashDone' => 'Prêt',
 
 #Import from GCfilms
@@ -171,15 +172,16 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'RandomOkTip'=> 'Accepter cet élément',
         
         'AboutTitle' => 'A propos de GCstar',
-        'AboutDesc' => 'Gestionnaire de collections',
+        'AboutDesc' => 'Gestionnaire de collections personnelles',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Equipe',
-        'AboutWho' => 'Tian : Gestionnaire du projet, Programmeur
-Adolfo González : Programmeur',
+        'AboutWho' => 'Christian Jodar (Tian) : Gestionnaire du projet, Programmeur
+Adolfo González : Programmeur
+Nyall Dawson (Zombiepig) : Programmeur',
         'AboutLicense' => 'Distribué selon les termes de la GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
-        'AboutTranslation' => 'Traduction française par Tian',
+        'AboutTranslation' => 'Traduction française par Christian Jodar',
         'AboutDesign' => 'Logo et webdesign par le Spektre',
 
         'ToolbarRandom' => 'Ce soir',
@@ -235,6 +237,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'Pour le bouton Lecture',
         'ModelCollectionSettings' => 'Réglages de la collection',
         'ModelCollectionSettingsLending' => 'Les éléments peuvent être empruntés',
+        'ModelCollectionSettingsTagging' => 'Les éléments peuvent être marqués',
         'ModelFilterActivated' => 'Présent dans la fenêtre de recherche',
         'ModelFilterComparison' => 'Comparaison',
         'ModelFilterContain' => 'Contient',
@@ -247,12 +250,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Est-ce qu\'un historique des valeurs entrées doit être conservé dans une liste.',
         'ModelTooltipFormat' => 'Ce format sert à déterminer l\'action à effectuer lors de l\'appui sur le bouton de lecture.',
         'ModelTooltipLending' => 'Cela va ajouter des champs pour gérer les emprunts.',
+        'ModelTooltipTagging' => 'Cela va ajouter des champs pour gérer les marques et mots-clés',
         'ModelTooltipNumeric' => 'Indique que les valeurs doivent être considérées comme des nombres pour les comparaisons.',
         'ModelTooltipQuick' => 'Ajoutera un sous-menu dans le menu Filtres',
 
         'ResultsTitle' => 'Choisissez un résultat',
         'ResultsNextTip' => 'Rechercher sur le site suivant',
         'ResultsPreview' => 'Aperçu',
+        'ResultsInfo' => 'Vous pouvez ajouter plusieurs éléments à la collection en maintenant la touche Shift ou Ctrl et en les sélectionnant',
 
         'OptionsTitle' => 'Préférences',
         'OptionsBrowser' => 'Navigateur web',
@@ -267,6 +272,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Sauvegarde automatique de la collection',
         'OptionsAutoLoad' => 'Ouvrir la collection précédente au démarrage',
         'OptionsSplash' => 'Afficher l\'écran de démarrage',
+        'OptionsSpellCheck' => 'Utiliser le vérificateur orthographique pour les champs texte longs',
         'OptionsImagesTitle' => 'Choisissez un répertoire',
         'OptionsProgramTitle' => 'Choisissez le programme à utiliser',
 		'OptionsPlugins' => 'Site où récupérer les fiches',
@@ -276,6 +282,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Définir la liste',		
         'OptionsAskImport' => 'Choisir les champs à importer',
 		'OptionsProxy' => 'Utiliser un proxy',
+		'OptionsCookieJar' => 'Utiliser ce fichier de cookies',
         'OptionsMain' => 'Principal',
         'OptionsLang' => 'Langue',
         'OptionsPaths' => 'Chemins',
@@ -283,9 +290,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Options',
         'OptionsDisplay' => 'Affichage',
         'OptionsToolbar' => 'Barre d\'outils',
-        'OptionsToolbars' => {0 => 'Aucune', 1 => 'Petite', 2 => 'Grande'},
+        'OptionsToolbars' => {0 => 'Aucune', 1 => 'Petite', 2 => 'Grande', 3 => 'Réglage système'},
         'OptionsToolbarPosition' => 'Position',
         'OptionsToolbarPositions' => {0 => 'Haut', 1 => 'Bas', 2 => 'Gauche', 3 => 'Droite'},
+        'OptionsExpandersMode' => 'Texte replié trop long',
+        'OptionsExpandersModes' => {'asis' => 'Ne rien faire', 'cut' => 'Couper', 'wrap' => 'Aller à la ligne'},
+        'OptionsDateFormat' => 'Format des dates',
+        'OptionsDateFormatTooltip' => 'Le format est celui utilisé par strftime(3). La valeur par défaut est %d/%m/%Y',
         'OptionsView' => 'Type de liste',
         'OptionsViews' => {0 => 'Texte', 1 => 'Image', 2 => 'Détaillée'},
         'OptionsColumns' => 'Colonnes',
@@ -296,6 +307,7 @@ http://le-spektre.org',
         'OptionsArticles' => 'Articles (Séparés par des virgules)',
         'OptionsSearchStop' => 'Une recherche peut être arrêtée',
         'OptionsAlwaysOriginal' => 'Utiliser le titre principal comme titre original si non présent',
+        'OptionsRestoreAccelerators' => 'Rétablir raccourcis',
 		'OptionsHistory' => 'Taille de l\'historique',
 		'OptionsClearHistory' => 'Purger l\'historique',
 		'OptionsStyle' => 'Thème',
@@ -324,6 +336,7 @@ http://le-spektre.org',
         'ImagesOptionsButton' => 'Réglages',
         'ImagesOptionsTitle' => 'Réglages pour la liste d\'images',
         'ImagesOptionsSelectColor' => 'Choisissez une couleur',
+        'ImagesOptionsUseOverlays' => 'Effet brillant',
         'ImagesOptionsBg' => 'Fond',
         'ImagesOptionsBgPicture' => 'Utiliser une image de fond',
         'ImagesOptionsFg'=> 'Selection',
@@ -336,10 +349,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Réglages pour la liste détaillée',
         'DetailedOptionsImageSize' => 'Taille des images',
         'DetailedOptionsGroupItems' => 'Grouper les éléments par',
+        'DetailedOptionsSecondarySort' => 'Trier les enfants par',
 		'DetailedOptionsFields' => 'Choisir les champs à afficher',
-		'DetailedOptionsMasterOption' => 'Le 1er élément d\'un groupe est',
-		'DetailedOptionsMasterGenerated' => 'Généré automatiquement',
-		'DetailedOptionsMasterOrdered' => 'Déterminé par',
+        'DetailedOptionsGroupedFirst' => 'Garder ensemble les éléments orphelins',
+        'DetailedOptionsAddCount' => 'Ajouter le nombre d\'éléments sur les catégories',
 
         'ExtractButton' => 'Informations',
         'ExtractTitle' => 'Informations du fichier vidéo',
@@ -348,12 +361,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Charger une liste de champs depuis un fichier',
         'FieldsListSave' => 'Sauvegarder la liste des champs dans un fichier',
         'FieldsListError' => 'Cette liste de champs ne peut pas être utilisée avec ce type de collection',
+        'FieldsListIgnore' => '--- Ignorer',
 
         'ExportTitle' => 'Exporter la collection',
         'ExportFilter' => 'Exporter seulement les éléments affichés',
         'ExportFieldsTitle' => 'Champs à exporter',
         'ExportFieldsTip' => 'Choisir les champs devant être exportés',
         'ExportWithPictures' => 'Copier les images dans un sous-répertoire',
+        'ExportSortBy' => 'Trier selon',
 
         'ImportListTitle' => 'Importer une autre collection',
         'ImportExportData' => 'Données',
@@ -399,6 +414,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Personne',
         'PanelUnknown' => 'Inconnu',
         'PanelAdded' => 'Date d\'ajout',
+        'PanelRating' => 'Note',
         'PanelLocation' => 'Emplacement',
 
         'PanelLending' => 'Emprunts',
@@ -410,6 +426,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Prêté',
         'PanelLendedNo' => 'Disponible',
 
+        'PanelTags' => 'Etiquettes',
+        'PanelFavourite' => 'Favori',
+        'TagsAssigned' => 'Mots-clés associés',
+
         'CheckUndef' => 'Sans importance',
         'CheckYes' => 'Oui',
         'CheckNo' => 'Non',
@@ -519,6 +539,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Eléments correspondants à tous les critères',
         'AdvancedSearchTypeOr' => 'Eléments correspondants à au moins un critère',
         'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'N\'importe quel champ',
+
+        'BugReportSubject' => 'Rapport d\'erreur généré depuis GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Système d\'exploitation',
+        'BugReportMessage' => 'Message d\'erreur',
+        'BugReportInformation' => 'Informations complémentaires',
     );
 }
 1;
