@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -30,10 +37,10 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'WithDrop' => 'Includi DROP instruction',
-        'WithCreate' => 'Includi CREATE instruction',
+        'WithDrop' => 'Includi istruzione DROP',
+        'WithCreate' => 'Includi istruzione CREATE',
         'TableName' => 'Nome tabella',
-        'InfoFile' => 'SQL file: ',
+        'InfoFile' => 'File SQL: ',
      );
 }
 
