@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -30,9 +37,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'ModelFile' => 'Template file',
-        'ModelText' => 'Template testo',
-        'Models' => 'Template da usare',
+        'ModelFile' => 'Modello file',
+        'ModelText' => 'Modello testo',
+        'Models' => 'Modello da usare',
         'UseFile' => 'Usa file',
         'UseModel' => 'Usa area di testo',
      );
