@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -30,6 +37,7 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'Charset' => 'Charset',
         'Header' => 'Ignora la prima linea',
         'Separator' => 'Delimitatore',
      );
