@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -30,12 +37,12 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Name' => 'Titles list',
-        'Plugin' => 'Site to be used',
-        'UseFirst' => 'Select first one if many results',
-        'CommentAuto' => 'Item automatically imported.',
-        'CommentSite' => 'Website: ',
-        'CommentTitle' => 'Title: ',
+        'Name' => 'Elenco dei titoli',
+        'Plugin' => 'Lato da utilizzare',
+        'UseFirst' => 'In caso di piu\' risultati utilizza il primo',
+        'CommentAuto' => 'Articolo importato automaticamente.',
+        'CommentSite' => 'Sito web: ',
+        'CommentTitle' => 'Titolo: ',
      );
 }
 
