@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -31,35 +38,35 @@
 
     our %lang = (
     
-        CollectionDescription => 'Books collection',
-        Items => 'Books',
-        NewItem => 'New book',
+        CollectionDescription => 'Biblioteca (Tian)',
+        Items => 'Libri',
+        NewItem => 'Libro nuovo',
     
         Isbn => 'ISBN',
-        Title => 'Title',
-        Cover => 'Cover',
-        Authors => 'Authors',
-        Publisher => 'Publisher',
-        Publication => 'Publication date',
-        Language => 'Language',
-        Genre => 'Genre',
-        Bookdescription => 'Description',
-        Pages => 'Pages',
-        Read => 'Read',
-        Rating => 'Rating',
-        Acquisition => 'Acquisition date',
-        Edition => 'Edition',
-        Format => 'Format',
-        Comments => 'Comments',
-        Url => 'Web page',
-        Translator => 'Translator',
-        Artist => 'Artist',
+        Title => 'Titolo',
+        Cover => 'Copertina',
+        Authors => 'Autore(i)',
+        Publisher => 'Editore',
+        Publication => 'Data di pubblicazione',
+        Language => 'Lingua',
+        Genre => 'Genere',
+        Serie => 'Serie',
+        Bookdescription => 'Descrizione',
+        Pages => 'Pagine',
+        Read => 'Letto',
+        Acquisition => 'Acquisito il',
+        Edition => 'Edizione',
+        Format => 'Formato',
+        Comments => 'Commenti',
+        Url => 'Pagina web',
+        Translator => 'Traduttore',
+        Artist => 'Scrittore',
 
-        General => 'General',
+        General => 'Generale',
         Details => 'Dettagli',
 
-        ReadNo => 'Not read',
-        ReadYes => 'Read',
+        ReadNo => 'Non letto',
+        ReadYes => 'Letto',
      );
 }
 
