@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+#
     
     use strict;
     use base 'Exporter';
@@ -31,7 +38,7 @@
 
     our %lang = (
     
-        CollectionDescription => 'Movies collection',
+        CollectionDescription => 'Filmoteca (Tian)',
         Items => 'Film',
         NewItem => 'Nuovo film',
     
@@ -41,32 +48,34 @@
         Date => 'Data',
         Time => 'Durata',
         Director => 'Regista',
-        Country => 'Nazionalità',
-        MinimumAge => 'Età minima',
+        Country => 'Nazione',
+        MinimumAge => 'Eta\' minima',
         Genre => 'Genere',
         Image => 'Immagine',
         Original => 'Titolo originale',
         Actors => 'Cast',
+        Actor => 'Actor',
+        Role => 'Role',
         Comment => 'Commento',
         Synopsis => 'Trama',
-        Seen => 'Già visto',
+        Seen => 'Gia\' visto',
         Number => 'Numero',
-        Rating => 'Valutazione',
         Format => 'Tipo',
+        Identifier => 'Identifier',
         Url => 'URL',
         Audio => 'Audio',
-        Video => 'Video format',
-        Trailer => 'Video file',
+        Video => 'Video',
+        Trailer => 'Trailer',
         Serie => 'Serie',
         Rank => 'Rank',
         Subtitles => 'Sottotitoli',
 
-        SeenYes => 'Item already viewed',
-        SeenNo => 'Item not viewed',
+        SeenYes => 'Gia\' visto',
+        SeenNo => 'Non visto',
 
-        AgeUnrated => 'Sconosciuto',
-        AgeAll => 'Nessuno',
-        AgeParent => 'Parent Guidance',
+        AgeUnrated => 'Sconosciuta',
+        AgeAll => 'Nessuna',
+        AgeParent => 'V.m.',
 
         Main => 'Oggetti principali',
         General => 'Informazioni film',
@@ -74,14 +83,14 @@
 
         Information => 'Informazioni',
         Languages => 'Lingua',
-        Encoding => 'Encoding',
+        Encoding => 'Codifica',
 
-        FilterAudienceAge => 'Età pubblico',
+        FilterAudienceAge => 'Eta\' pubblico',
         FilterSeenNo => '_Non visto',
-        FilterSeenYes => '_Already Viewed',
+        FilterSeenYes => '_Gia\' visto',
         FilterRatingSelect => 'Valutazione maggiore di...',
 
-        ExtractSize => 'Size',
+        ExtractSize => 'Durata',
      );
 }
 
