@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -31,33 +38,33 @@
 
     our %lang = (
     
-        CollectionDescription => 'Music collection',
-        Items => 'Albums',
-        NewItem => 'New album',
+        CollectionDescription => 'Musicoteca (Tian)',
+        Items => 'Album',
+        NewItem => 'Nuovo album',
     
         Unique => 'ISRC/EAN',
-        Title => 'Title',
-        Cover => 'Cover',
-        Artist => 'Artist',
-        Format => 'Format',
-        Running => 'Running time',
-        Release => 'Release date',
-        Genre => 'Genre',
+        Title => 'Titolo',
+        Cover => 'Copertina',
+        Artist => 'Artista',
+        Format => 'Formato',
+        Running => 'Durata',
+        Release => 'Data pubblicazione',
+        Genre => 'Genere',
 
 #For tracks list
-        Tracks => 'Tracks list',
-        Number => 'Number',
-        Track => 'Title',
-        Time => 'Time',
+        Tracks => 'Lista tracce',
+        Number => 'Numero',
+        Track => 'Titolo',
+        Time => 'Tempo',
 
-        Composer => 'Composer',
-        Producer => 'Producer',
+        Composer => 'Compositore',
+        Producer => 'Produttore',
         Playlist => 'Playlist',
-        Comments => 'Comments',
-        Label => 'Label',
-        Url => 'Web page',
+        Comments => 'Commenti',
+        Label => 'Etichetta',
+        Url => 'WPagina web',
 
-        General => 'General',
+        General => 'Generale',
         Details => 'Dettagli',
      );
 }
