@@ -30,23 +30,26 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Niepoprawny plik szablonu',
+        'UseFile' => 'Skorzystaj z poniższego pliku',
+        'TemplateExternalFile' => 'Plik szablonu',
         'WithJS' => 'Używaj Javascript',
        	'FileTemplate' => 'Plik tymczasowy:',
         'Preview' => 'Podgląd',
         'NoPreview' => 'Podgląd niedostępny',
         'Title' => 'Tytuł strony',
-        'InfoFile' => 'Lista Filmów jest w pliku: ',
+        'InfoFile' => 'Lista pozycji jest w pliku: ',
         'InfoDir' => 'Obrazy są w : ',
         'HeightImg' => 'Wysokość (w pikselach) obrazu do eksportu: ',
         'OpenFileInBrowser' => 'Otwórz wygenerowany plik w przeglądarce',
-        'Note' => 'Lista wygenerowana przez program <a href="http://www.gcstar.org/">GCfilms</a>',
+        'Note' => 'Lista wygenerowana przez program <a href="http://www.gcstar.org/">GCstar</a>',
         'InputTitle' => 'Wpisz szukany ciąg znaków',
         'SearchType1' => 'Tylko tytuł',
         'SearchType2' => 'Pełna informacja',
         'SearchButton' => 'Szukaj',    
         'SearchTitle' => 'Wyświetlaj tylko filmy pasujące do kryterium szukania',
         'AllButton' => 'Wszystkie',
-        'AllTitle' => 'Pokaż wszystkie filmy',
+        'AllTitle' => 'Pokaż wszystkie',
         'Expand' => 'Rozwiń wszystkie',
         'ExpandTitle' => 'Wyświetl informacje o wszystkich filmach',
         'Collapse' => 'Ukryj wszystkie',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Pożyczone przez: ',
         'NotBorrowed' => 'Dostępne',
         'Top' => 'Góra',
+        'Bottom' => 'Bottom',
      );
 }
 
