@@ -30,9 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Where' => 'Where should it search',
-        'Default' => 'Default Alexandria\'s directory',
-        'Specified' => 'Directory specified below',
+        'Where' => 'Gdzie szukać',
+        'Default' => 'Domyślny katalog Alexandrii',
+        'Specified' => 'Katalog podany poniżej',
      );
 }
 
