@@ -33,7 +33,7 @@
         'Name' => 'Lista tytułów',
         'Plugin' => 'Strona używana',
         'UseFirst' => 'Wybierz pierwszy, jeżeli dużo wyników',
-        'CommentAuto' => 'Automatyczny import Filmu.',
+        'CommentAuto' => 'Import automatyczny',
         'CommentSite' => 'Strona: ',
         'CommentTitle' => 'Tytuł: ',
      );
