@@ -31,35 +31,40 @@
 
     our %lang = (
     
-        CollectionDescription => 'Books collection',
-        Items => 'Books',
-        NewItem => 'New book',
+        CollectionDescription => 'Księgozbiór',
+        Items => sub {
+          my $number = shift;
+          return 'Książka' if $number eq '1';
+          return 'Książki' if $number =~ /(?<!1)[2-4]$/;
+          return 'Książek';
+        },
+        NewItem => 'Nowa książka',
     
         Isbn => 'ISBN',
-        Title => 'Title',
-        Cover => 'Cover',
-        Authors => 'Authors',
-        Publisher => 'Publisher',
-        Publication => 'Publication date',
-        Language => 'Language',
-        Genre => 'Genre',
-        Bookdescription => 'Description',
-        Pages => 'Pages',
-        Read => 'Read',
-        Rating => 'Rating',
-        Acquisition => 'Acquisition date',
-        Edition => 'Edition',
-        Format => 'Format',
-        Comments => 'Comments',
-        Url => 'Web page',
-        Translator => 'Translator',
-        Artist => 'Artist',
+        Title => 'Tytuł',
+        Cover => 'Okładka',
+        Authors => 'Autor',
+        Publisher => 'Wydawca',
+        Publication => 'Data wydania',
+        Language => 'Język',
+        Genre => 'Gatunek',
+        Serie => 'Kolekcja',
+        Bookdescription => 'Opis',
+        Pages => 'Stron',
+        Read => 'Przeczytana',
+        Acquisition => 'Data pozyskania',
+        Edition => 'Wydanie',
+        Format => 'Oprawa',
+        Comments => 'Komentarze',
+        Url => 'Strona internetowa',
+        Translator => 'Tłumaczenie',
+        Artist => 'Ilustrator',
 
-        General => 'General',
-        Details => 'Details',
+        General => 'Ogólne',
+        Details => 'Szczegóły',
 
-        ReadNo => 'Not read',
-        ReadYes => 'Read',
+        ReadNo => 'Nieczytana',
+        ReadYes => 'Czytana',
      );
 }
 
