@@ -31,34 +31,40 @@
 
     our %lang = (
     
-        CollectionDescription => 'Music collection',
-        Items => 'Albums',
-        NewItem => 'New album',
+        CollectionDescription => 'Fonoteka',
+        Items => sub {
+          my $number = shift;
+          return 'Album' if $number eq '1';
+          return 'Albumy' if $number =~ /(?<!1)[2-4]$/;
+          return 'Albumów';
+        },
+
+        NewItem => 'Nowy album',
     
         Unique => 'ISRC/EAN',
-        Title => 'Title',
-        Cover => 'Cover',
-        Artist => 'Artist',
+        Title => 'Tytuł',
+        Cover => 'Okładka',
+        Artist => 'Wykonawca',
         Format => 'Format',
-        Running => 'Running time',
-        Release => 'Release date',
-        Genre => 'Genre',
+        Running => 'Łączny czas',
+        Release => 'Data wydania',
+        Genre => 'Gatunek',
 
 #For tracks list
-        Tracks => 'Tracks list',
-        Number => 'Number',
-        Track => 'Title',
-        Time => 'Time',
+        Tracks => 'Lista utworów',
+        Number => 'Ścieżka',
+        Track => 'Tytuł',
+        Time => 'Czas trwania',
 
-        Composer => 'Composer',
-        Producer => 'Producer',
-        Playlist => 'Playlist',
-        Comments => 'Comments',
+        Composer => 'Kompozytor',
+        Producer => 'Producent',
+        Playlist => 'Lista odtwarzania',
+        Comments => 'Opinie',
         Label => 'Label',
-        Url => 'Web page',
+        Url => 'Strona internetowa',
 
-        General => 'General',
-        Details => 'Details',
+        General => 'Ogólne',
+        Details => 'Szczegóły',
      );
 }
 
