@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Foloseşte Javascript',
        	'FileTemplate' => 'Şablon :',
         'Preview' => 'Previzualizare',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Împrumutat de către: ',
         'NotBorrowed' => 'Disponibil',
         'Top' => 'Sus',
+        'Bottom' => 'Bottom',
      );
 }
 
