@@ -30,9 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Where' => 'Where should it search',
-        'Default' => 'Default Alexandria\'s directory',
-        'Specified' => 'Directory specified below',
+        'Where' => 'Unde ar trebui să caute',
+        'Default' => 'Directorul implicit pentru Alexandria',
+        'Specified' => 'Directorul specificat mai jos',
      );
 }
 
