@@ -31,35 +31,35 @@
 
     our %lang = (
     
-        CollectionDescription => 'Books collection',
-        Items => 'Books',
-        NewItem => 'New book',
+        CollectionDescription => 'Colecţie de cărţi',
+        Items => 'Cărţi',
+        NewItem => 'Carte nouă',
     
         Isbn => 'ISBN',
-        Title => 'Title',
-        Cover => 'Cover',
-        Authors => 'Authors',
-        Publisher => 'Publisher',
-        Publication => 'Publication date',
-        Language => 'Language',
-        Genre => 'Genre',
-        Bookdescription => 'Description',
-        Pages => 'Pages',
-        Read => 'Read',
-        Rating => 'Rating',
-        Acquisition => 'Acquisition date',
-        Edition => 'Edition',
+        Title => 'Tilu',
+        Cover => 'Copertă',
+        Authors => 'Autori',
+        Publisher => 'Editură',
+        Publication => 'Dată editare',
+        Language => 'Limbă',
+        Genre => 'Gen',
+        Serie => 'Colecţie',
+        Bookdescription => 'Descriere',
+        Pages => 'Pagini',
+        Read => 'Citită',
+        Acquisition => 'Dată cumpărare',
+        Edition => 'Ediţie',
         Format => 'Format',
-        Comments => 'Comments',
-        Url => 'Web page',
-        Translator => 'Translator',
+        Comments => 'Comentarii',
+        Url => 'Pagina web',
+        Translator => 'Traducător',
         Artist => 'Artist',
 
         General => 'General',
-        Details => 'Details',
+        Details => 'Detalii',
 
-        ReadNo => 'Not read',
-        ReadYes => 'Read',
+        ReadNo => 'Necitită',
+        ReadYes => 'Citită',
      );
 }
 
