@@ -31,34 +31,34 @@
 
     our %lang = (
     
-        CollectionDescription => 'Music collection',
-        Items => 'Albums',
-        NewItem => 'New album',
+        CollectionDescription => 'Colecţie de muzică',
+        Items => 'Albume',
+        NewItem => 'Album nou',
     
         Unique => 'ISRC/EAN',
-        Title => 'Title',
-        Cover => 'Cover',
+        Title => 'Titlu',
+        Cover => 'Copertă',
         Artist => 'Artist',
         Format => 'Format',
-        Running => 'Running time',
-        Release => 'Release date',
-        Genre => 'Genre',
+        Running => 'Durată',
+        Release => 'Dată lansare',
+        Genre => 'Gen',
 
 #For tracks list
-        Tracks => 'Tracks list',
-        Number => 'Number',
-        Track => 'Title',
-        Time => 'Time',
+        Tracks => 'Listă piese',
+        Number => 'Număr',
+        Track => 'Titlu',
+        Time => 'Durată',
 
-        Composer => 'Composer',
-        Producer => 'Producer',
-        Playlist => 'Playlist',
-        Comments => 'Comments',
-        Label => 'Label',
-        Url => 'Web page',
+        Composer => 'Compozitor',
+        Producer => 'Producător',
+        Playlist => 'Listă de redare',
+        Comments => 'Comentarii',
+        Label => 'Etichetă',
+        Url => 'Pagină web',
 
         General => 'General',
-        Details => 'Details',
+        Details => 'Detalii',
      );
 }
 
