@@ -46,7 +46,7 @@ explicită</b> a sitului web.
 Pentru a determina ce sit web este proprietarul informaţiei,
 puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         
-        'AllItemsFiltered' => 'Nici un film nu se potriveşte criteriilor dumneavoastră de filtrare',
+        'AllItemsFiltered' => 'Nici un element nu se potriveşte criteriilor dumneavoastră de filtrare',
         
 #Installation
         'InstallDirInfo' => 'Instalare în ',
@@ -66,50 +66,51 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'InstallWithClean' => 'Şterge fişierele aflate în directorul de instalare',
         'InstallWithMenu' => 'Adaugă GCstar la meniul Aplicaţii',
         'InstallNoPermission' => 'Eroare: Nu aveţi permisiunile necesare pentru a scrie în directorul selectat',
-        'InstallMissingMandatory' => 'Dependinţe esenţiale lipsesc. Nu veţi putea instala GCFilms până când acestea nu vor fi prezente pe sistemul dumneavoastră.',
+        'InstallMissingMandatory' => 'Dependinţe esenţiale lipsesc. Nu veţi putea instala GCstar până când acestea nu vor fi prezente pe sistemul dumneavoastră.',
         'InstallMissingOptional' => 'Unele dependinţe opţionale lipsesc. Acestea sunt listate mai jos. GCstar poate fi instalat dar unele facilităţi ar putea să nu fie disponibile.',
         'InstallMissingNone' => 'Toate dependinţele sunt satisfăcute. Puteţi continua cu instalarea GCstar.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Lipsă',
         'InstallMissingFor' => 'Lipsă pentru',
-        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
-        'InstallCopyDirectory' => 'Copying files in directory: ',
-        'InstallCopyDesktop' => 'Copying desktop file in: ',
+        'InstallCleanDirectory' => 'Şterg fişierele GCstar din directorul: ',
+        'InstallCopyDirectory' => 'Copiez fişierele în directorul: ',
+        'InstallCopyDesktop' => 'Copiez fişierul desktop ‪în: ',
 
 #Update
-        'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
-        'UpdateNoPermission' => 'Write permission denied in this directory: ',
-        'UpdateNone' => 'No update have been found',
-        'UpdateFileNotFound' => 'File not found',
+        'UpdateUseProxy' => 'Proxy-ul folosit (apăsaţi enter dacă nu e nevoie de unul): ',
+        'UpdateNoPermission' => 'Nu există permsiuni pentru scriere în acest director: ',
+        'UpdateNone' => 'Nici o actualizare nu a fost găsită',
+        'UpdateFileNotFound' => 'Fişierul nu a fost găsit',
 
 #Splash
         'SplashInit' => 'Iniţializare',
         'SplashLoad' => 'Încărcare colecţie',
-        'SplashDisplay' => 'Displaying Collection',
+        'SplashDisplay' => 'Afişare colecţie',
+        'SplashSort' => 'Sortare colecţie',
         'SplashDone' => 'Gata',
 
 #Import from GCfilms
-        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
-        'GCfilmsImportOptions' => 'Settings',
-        'GCfilmsImportData' => 'Movies list',
+        'GCfilmsImportQuestion' => 'Se pare că foloseaţi GCfilms anterior. Ce doriţi să importaţi din GCfilms în GCstar (nu va influeţa GCfilms în cazul în care încă îl mai folosiţi)?',
+        'GCfilmsImportOptions' => 'Setări',
+        'GCfilmsImportData' => 'Listă filme',
 
 #Menus
         'MenuFile' => '_Fişier',
             'MenuNewList' => 'Colecţie _nouă',
             'MenuHistory' => 'Colecţii _recente',
-            'MenuLend' => 'Afişează filmele î_mprumutate',
+            'MenuLend' => 'Afişează elementele î_mprumutate',
             'MenuImport' => '_Importă',	
             'MenuExport' => '_Exportă',
     
         'MenuEdit'  => '_Editare',
-            'MenuDuplicate' => '_Duplică film',
-            'MenuEditDeleteCurrent' => 'Ş_terge film',
-            'MenuEditFields' => '_Change collection fields',
+            'MenuDuplicate' => '_Duplică element',
+            'MenuEditDeleteCurrent' => 'Ş_terge element',
+            'MenuEditFields' => 'S_chimbă câmpurile colecţiei',
             'MenuEditLockItems' => 'B_lochează colecţia',
     
         'MenuDisplay' => 'F_iltrare',
-            'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Afişează to_ate filmele',
+            'MenuAdvancedSearch' => 'Căutare a_vansată',
+            'MenuViewAllItems' => 'Afişează to_ate elementele',
             'MenuNoFilter' => '_Oricare',
 
         'MenuConfiguration' => '_Setări',
@@ -117,63 +118,64 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
             'MenuBorrowers' => '_Persoane care au împrumutat',
             'MenuGenresConversion' => '_Conversie gen',
 
-        'MenuBookmarks' => 'My _Collections',
-            'MenuBookmarksAdd' => '_Add current collection',
-            'MenuBookmarksEdit' => '_Edit bookmarked collections',
+        'MenuBookmarks' => '_Colecţiile mele',
+            'MenuBookmarksAdd' => '_Adaugă colecţia curentă',
+            'MenuBookmarksEdit' => '_Editează colecţiile favorite',
 
         'MenuHelp' => '_Ajutor',
             'MenuHelpContent' => '_Ajutor',
-            'MenuAllPlugins' => 'View _plugins',
-            'MenuBugReport' => 'Report a _bug',
+            'MenuAllPlugins' => 'Arată _modulele',
+            'MenuBugReport' => 'Raportează un _bug',
             'MenuAbout' => '_Despre GCstar',
     
-        'MenuNewWindow' => 'Afişează filmul în fereastră _nouă',
+        'MenuNewWindow' => 'Afişează elementul în fereastră _nouă',
         
-        'ContextExpandAll' => 'Expand all',
-        'ContextCollapseAll' => 'Collapse all',
+        'ContextExpandAll' => 'Desfă tot',
+        'ContextCollapseAll' => 'Strânge tot',
 
-        'DialogEnterNumber' => 'Please enter value',
+        'DialogEnterNumber' => 'Vă rugăm introduceţi o valoare',
 
-        'RemoveConfirm' => 'Sunteţi sigur că doriţi să ştergeţi acest film?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Adaugă un film nou',
-        'NoItemFound' => 'Nici un film nu a fost găsit. Doriţi să căutaţi pe alt sit?',
+        'RemoveConfirm' => 'Sunteţi sigur că doriţi să ştergeţi acest element?',
+        'DefaultNewItem' => 'Element nou',
+        'NewItemTooltip' => 'Adaugă un element nou',
+        'NoItemFound' => 'Nu a fost găsit nimic. Doriţi să căutaţi pe alt sit?',
         'OpenList' => 'Vă rugăm selectaţi colecţia',
         'SaveList' => 'Vă rugăm alegeţi unde să salvaţi colecţia',
         'SaveListTooltip' => 'Salvează colecţia curentă',
         'SaveCurrentList' => 'Mai întâi specificaţi unde să fie salvată colecţia curentă',
-        'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
-        'SaveDontSave' => 'Don\'t save',
+        'SaveUnsavedChanges' => 'Aveţi modificări nesalvate în colecţia dumneavoastră. Doriţi să le salvaţi?',
+        'SaveDontSave' => 'Nu salva',
         'PreferencesTooltip' => 'Setaţi preferinţele dumneavoastră',
         'ViewTooltip' => 'Schimbă afişarea colecţiei',
-        'PlayTooltip' => 'Redă fişierul video asociat acestui film',
+        'PlayTooltip' => 'Redă fişierul video asociat acestui element',
 
-        'StatusSave' => 'Saving...',
-        'StatusLoad' => 'Loading...',
+        'StatusSave' => 'Salvez...',
+        'StatusLoad' => 'Încarc...',
         'StatusSearch' => 'Căutare în curs...',
         'StatusGetInfo' => 'Obţin informaţiile...',
         'StatusGetImage' => 'Obţin imaginea...',
                 
-        'SaveError' => 'Nu am putut salva lista de filme. Vă rugăm verificaţi drepturile de acces şi spaţiul liber pe disc.',
-        'OpenError' => 'Nu am putut deschide lista de filme. Vă rugăm verificaţi drepturile de acces.',
-        'OpenFormatError' => 'Nu am putut deschide lista de filme.',
+        'SaveError' => 'Nu am putut salva lista de elemente. Vă rugăm verificaţi drepturile de acces şi spaţiul liber pe disc.',
+        'OpenError' => 'Nu am putut deschide lista de elemente. Vă rugăm verificaţi drepturile de acces.',
+        'OpenFormatError' => 'Nu am putut deschide lista de elemente.',
         'ImageError' => 'Directorul selectat pentru a salva imaginile nu este corect. Vă rugăm selectaţi alt director.',
         'OptionsCreationError'=> 'Nu pot crea fişierul de opţiuni: ',
         'OptionsOpenError'=> 'Nu pot deschide fişierul de opţiuni: ',
         'OptionsSaveError'=> 'Nu pot salva fişierul de opţiuni: ',
         
         'RandomTooltip' => 'Ce să vedem în acestă seară?',
-        'RandomError'=> 'Nu aveţi nici un film nevizionat',
-        'RandomEnd'=> 'Nu mai sunt alte filme',
+        'RandomError'=> 'Nu aveţi nici un element care să poate fi selectat',
+        'RandomEnd'=> 'Nu mai sunt alte elemente',
         'RandomNextTip'=> 'Următoarea sugestie',
-        'RandomOkTip'=> 'Acceptă acest film',
+        'RandomOkTip'=> 'Acceptă acest element',
         
         'AboutTitle' => 'Despre GCstar',
-        'AboutDesc' => 'Catalog de filme Gtk2',
+        'AboutDesc' => 'Manager de colecţii',
         'AboutVersion' => 'Versiune',
         'AboutTeam' => 'Echipa',
-        'AboutWho' => 'Tian: Manager de proiect, programator
-Adolfo González : Programator',
+        'AboutWho' => 'Christian Jodar (Tian): Manager de proiect, programator
+Adolfo González : Programator
+Nyall Dawson (Zombiepig) : Programator',
         'AboutLicense' => 'Distribuit în termenii licenţei GNU GPL
 Copyright logo le Spektre
 http://le-spektre.org',
@@ -182,89 +184,93 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'În seara asta',
         
-        'ModelsSelect' => 'Select a collection type',
-        'ModelsPersonal' => 'Personal models',
-        'ModelsDefault' => 'Default models',
-        'ModelsList' => 'Collection definition',
-        'ModelSettings' => 'Collection settings',
-        'ModelNewType' => 'New collection type',
-        'ModelName' => 'Name of the collection type:',
-		'ModelFields' => 'Fields',
-		'ModelOptions'	=> 'Options',
-		'ModelFilters'	=> 'Filters',
-        'ModelNewField' => 'New field',
-        'ModelFieldInformation' => 'Information',
-        'ModelFieldName' => 'Label:',
-        'ModelFieldType' => 'Type:',
-        'ModelFieldGroup' => 'Group:',
-        'ModelFieldValues' => 'Values',
-        'ModelFieldInit' => 'Default:',
-        'ModelFieldMin' => 'Minimum:',
-        'ModelFieldMax' => 'Maximum:',
-        'ModelFieldList' => 'Values list:',
-        'ModelFieldListLegend' => '<i>Comma separated</i>',
-        'ModelFieldTypeShortText' => 'Short text',
-        'ModelFieldTypeLongText' => 'Long text',
-        'ModelFieldTypeYesNo' => 'Yes/No',
-        'ModelFieldTypeNumber' => 'Number',
-        'ModelFieldTypeDate' => 'Date',
-        'ModelFieldTypeOptions' => 'Pre-defined values list',
-        'ModelFieldTypeImage' => 'Image',
-        'ModelFieldTypeSingleList' => 'Simple list',
-        'ModelFieldTypeFile' => 'File',
-        'ModelFieldTypeFormatted' => 'Dependant on other fields',
-        'ModelFieldParameters' => 'Parameters',
-        'ModelFieldHasHistory' => 'Use an history',
-        'ModelFieldFlat' => 'Display on one line',
-        'ModelFieldStep' => 'Increment step:',
-        'ModelFieldFileFormat' => 'File format:',
-        'ModelFieldFileFile' => 'Simple file',
-        'ModelFieldFileImage' => 'Image',
+        'ModelsSelect' => 'Selectaţi un tip de colecţie',
+        'ModelsPersonal' => 'Modele personale',
+        'ModelsDefault' => 'Modele implicite',
+        'ModelsList' => 'Definire colecţie',
+        'ModelSettings' => 'Setări colecţie',
+        'ModelNewType' => 'Nou tip de colecţie',
+        'ModelName' => 'Numele tipului de colecţie:',
+		'ModelFields' => 'Câmpuri',
+		'ModelOptions'	=> 'Opţiuni',
+		'ModelFilters'	=> 'Filtre',
+        'ModelNewField' => 'Câmp nou',
+        'ModelFieldInformation' => 'Informaţii',
+        'ModelFieldName' => 'Etichetă:',
+        'ModelFieldType' => 'Tip:',
+        'ModelFieldGroup' => 'Grup:',
+        'ModelFieldValues' => 'Valori',
+        'ModelFieldInit' => 'Implicit:',
+        'ModelFieldMin' => 'Minim:',
+        'ModelFieldMax' => 'Maxim:',
+        'ModelFieldList' => 'Listă valori:',
+        'ModelFieldListLegend' => '<i>Separare prin virgulă</i>',
+        'ModelFieldTypeShortText' => 'Text scurt',
+        'ModelFieldTypeLongText' => 'Text lung',
+        'ModelFieldTypeYesNo' => 'Da/Nu',
+        'ModelFieldTypeNumber' => 'Număr',
+        'ModelFieldTypeDate' => 'Dată',
+        'ModelFieldTypeOptions' => 'Listă predefinită de valori',
+        'ModelFieldTypeImage' => 'Imagine',
+        'ModelFieldTypeSingleList' => 'Listă simplă',
+        'ModelFieldTypeFile' => 'Fişier',
+        'ModelFieldTypeFormatted' => 'Depinde de alte câmpuri',
+        'ModelFieldParameters' => 'Parametri',
+        'ModelFieldHasHistory' => 'Foloseşte un istoric',
+        'ModelFieldFlat' => 'Afişare pe o linie',
+        'ModelFieldStep' => 'Pas de incrementare:',
+        'ModelFieldFileFormat' => 'Format fişier:',
+        'ModelFieldFileFile' => 'Fişier simplu',
+        'ModelFieldFileImage' => 'Imagine',
         'ModelFieldFileVideo' => 'Video',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
-        'ModelOptionsFields' => 'Fields to use',
-        'ModelOptionsFieldsAuto' => 'Automatic',
-        'ModelOptionsFieldsNone' => 'None',
-        'ModelOptionsFieldsTitle' => 'As title',
-        'ModelOptionsFieldsId' => 'As identifier',
-        'ModelOptionsFieldsCover' => 'As cover',
-        'ModelOptionsFieldsPlay' => 'For Play button',
-        'ModelCollectionSettings' => 'Collection settings',
-        'ModelCollectionSettingsLending' => 'Items could be borrowed',
-        'ModelFilterActivated' => 'Should be in search box',
-        'ModelFilterComparison' => 'Comparison',
-        'ModelFilterContain' => 'Contains',
-        'ModelFilterRange' => 'Range',
-        'ModelFilterNumeric' => 'Comparison is numeric',
-        'ModelFilterQuick' => 'Create a quick filter',
-        'ModelTooltipName' => 'Use a name to re-use this model for many collections. If empty, the settings will be directly stored in the collection itself',
-        'ModelTooltipLabel' => 'The field name as it will be displayed',
-        'ModelTooltipGroup' => 'Used to group fields. Items with no value here will be in a default group',
-        'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
-        'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
-        'ModelTooltipLending' => 'This will add some fields to manage lendings',
-        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
-        'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
+        'ModelOptionsFields' => 'Câmpuri folosite',
+        'ModelOptionsFieldsAuto' => 'Automat',
+        'ModelOptionsFieldsNone' => 'Nici unul',
+        'ModelOptionsFieldsTitle' => 'Ca titlu',
+        'ModelOptionsFieldsId' => 'Ca identificator',
+        'ModelOptionsFieldsCover' => 'Ca şi copertă',
+        'ModelOptionsFieldsPlay' => 'Pentru butonul de redare',
+        'ModelCollectionSettings' => 'Setări colecţie',
+        'ModelCollectionSettingsLending' => 'Elementele pot fi împrumutate',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
+        'ModelFilterActivated' => 'Ar trebui să apară în fereastra de căutare',
+        'ModelFilterComparison' => 'Comparaţie',
+        'ModelFilterContain' => 'Conţine',
+        'ModelFilterRange' => 'Domeniu',
+        'ModelFilterNumeric' => 'Comparaţia e numerică',
+        'ModelFilterQuick' => 'Creaţi un filtru rapid',
+        'ModelTooltipName' => 'Folosiţi un nume pentru a reutiliza acest model pentru mai multe colecţii. Dacă este gol, setările vor fi stocate direct în colecţie',
+        'ModelTooltipLabel' => 'Numele câmpului aşa cum va fi afişat',
+        'ModelTooltipGroup' => 'Folosit pentru a grupa câmpurile. Elementele care nu au o valoare aici vor fi într-un grup implicit',
+        'ModelTooltipHistory' => 'Dacă elementele introduse anterior vor fi stocate într-o listă asociată acestui câmp',
+        'ModelTooltipFormat' => 'Acest format este folosit pentru a determina acţiunea de a deschide un fişier cu butonul de Redare',
+        'ModelTooltipLending' => 'Aceasta va adăuga unele câmpuri pentru a gestiona împrumuturile',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
+        'ModelTooltipNumeric' => 'Dacă valorile trebuie considerate ca numere în comparaţii',
+        'ModelTooltipQuick' => 'Aceasta va adăuga un submeniu la Filtre',
 
-        'ResultsTitle' => 'Selectaţi un film',
+        'ResultsTitle' => 'Selectaţi un element',
         'ResultsNextTip' => 'Caută pe următorul sit',
-        'ResultsPreview' => 'Preview',
+        'ResultsPreview' => 'Previzualizare',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Preferinţe',
         'OptionsBrowser' => 'Navigator web',
         'OptionsPlayer' => 'Player video',
-        'OptionsAudio' => 'Audio player',
+        'OptionsAudio' => 'Player audio',
         'OptionsImages' => 'Director de imagini',
         'OptionsUseRelativePaths' => 'Foloseşte căi relative pentru imagini',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Afişează bara de status',
         'OptionsWarning' => 'Atenţie: Modificările din acest tab nu vor avea efect decât după repornirea aplicaţiei.',
-        'OptionsRemoveConfirm' => 'Cere o confirmare înainte de ştergerea filmului',
+        'OptionsRemoveConfirm' => 'Cere o confirmare înainte de ştergerea elementului',
         'OptionsAutoSave' => 'Salvează colecţia automat',
-        'OptionsAutoLoad' => 'Load previous collection on startup',
+        'OptionsAutoLoad' => 'Încarcă colecţia anterioară la pornire',
         'OptionsSplash' => 'Afişează ecranul de pornire',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Selectaţi un director',
         'OptionsProgramTitle' => 'Selectaţi programul ce va fi folosit',
 		'OptionsPlugins' => 'Situl de la care se vor obţine informaţiile',
@@ -274,6 +280,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Setează lista',
         'OptionsAskImport' => 'Selectează câmpurile ce vor fi importate',
 		'OptionsProxy' => 'Foloseşte un proxy',
+		'OptionsCookieJar' => 'Foloseşte acest fişier cookie',
         'OptionsLang' => 'Limbă',
         'OptionsMain' => 'Principal',
         'OptionsPaths' => 'Căi',
@@ -281,9 +288,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Facilităţi',
         'OptionsDisplay' => 'Afişare',
         'OptionsToolbar' => 'Bară de unelte',
-        'OptionsToolbars' => {0 => 'Fără', 1 => 'Mică', 2 => 'Mare'},
+        'OptionsToolbars' => {0 => 'Fără', 1 => 'Mică', 2 => 'Mare', 3 => 'Setări sistem'},
         'OptionsToolbarPosition' => 'Poziţie',
         'OptionsToolbarPositions' => {0 => 'Sus', 1 => 'Jos', 2 => 'Stânga', 3 => 'Dreapta'},
+        'OptionsExpandersMode' => 'Desfăsurători prea lungi',
+        'OptionsExpandersModes' => {'asis' => 'Ignoră', 'cut' => 'Taie', 'wrap' => 'Rupe linia'},
+        'OptionsDateFormat' => 'Format dată',
+        'OptionsDateFormatTooltip' => 'Formatul este cel folosit de strftime(3). Implicit este %d/%m/%Y.',
         'OptionsView' => 'Afişare',
         'OptionsViews' => {0 => 'Text', 1 => 'Imagine', 2 => 'Detalii'},
         'OptionsColumns' => 'Coloane',
@@ -294,34 +305,36 @@ http://le-spektre.org',
         'OptionsArticles' => 'Articole (separate prin virgulă)',
         'OptionsSearchStop' => 'Permite întreruperea căutărilor',
         'OptionsAlwaysOriginal' => 'Foloseşte titlul principal ca titlu original în cazul în care acesta nu este prezent',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Mărime istoric',
         'OptionsClearHistory' => 'Şterge istoricul',
 		'OptionsStyle' => 'Temă',
         'OptionsDontAsk' => 'Nu mai întreba din nou',
-        'OptionsPathProgramsGroup' => 'Applications',
-        'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
-        'OptionsProgramsSet' => 'Set programs',
-        'OptionsPathImagesGroup' => 'Images',
-        'OptionsInternetDataGroup' => 'Data import',
-        'OptionsInternetSettingsGroup' => 'Settings',
-        'OptionsDisplayInformationGroup' => 'Information display',
-        'OptionsDisplayArticlesGroup' => 'Articles',
-        'OptionsImagesDisplayGroup' => 'Display',
-        'OptionsImagesStyleGroup' => 'Style',
-        'OptionsDetailedPreferencesGroup' => 'Preferences',
-        'OptionsFeaturesConveniencesGroup' => 'Conveniences',
-        'OptionsPicturesFormat' => 'Prefix to use for pictures:',
+        'OptionsPathProgramsGroup' => 'Aplicaţii',
+        'OptionsProgramsSystem' => 'Foloseşte programele definite de sistem',
+        'OptionsProgramsUser' => 'Foloseşte programele specificate',
+        'OptionsProgramsSet' => 'Setare programe',
+        'OptionsPathImagesGroup' => 'Imagini',
+        'OptionsInternetDataGroup' => 'Importare date',
+        'OptionsInternetSettingsGroup' => 'Setări',
+        'OptionsDisplayInformationGroup' => 'Afişare informaţii',
+        'OptionsDisplayArticlesGroup' => 'Articole',
+        'OptionsImagesDisplayGroup' => 'Afişare',
+        'OptionsImagesStyleGroup' => 'Stil',
+        'OptionsDetailedPreferencesGroup' => 'Preferinţe',
+        'OptionsFeaturesConveniencesGroup' => 'Convenţii',
+        'OptionsPicturesFormat' => 'Prefix folosit pentru imagini:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
-        'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
-        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
-        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
-        'OptionsConfigureMailers' => 'Configure mailing programs',
+        'OptionsPicturesFormatTitle' => 'Titlul sau numele elementului asociat',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% sau . va fi înlocuit cu directorul colecţiei (folosiţi doar pentru începutul căilor)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% va fi înlocuit de numele fişierului de colecţie fără sufix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% poate fi folosit doar la începutul căii pentru imagini',
+        'OptionsConfigureMailers' => 'Configurează aplicaţiile pentru mail',
 
         'ImagesOptionsButton' => 'Setări',
         'ImagesOptionsTitle' => 'Setări pentru lista de imagini',
         'ImagesOptionsSelectColor' => 'Selectaţi o culoare',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Fundal',
         'ImagesOptionsBgPicture' => 'Foloseşte o imagine de fundal',
         'ImagesOptionsFg'=> 'Selecţie',
@@ -333,27 +346,29 @@ http://le-spektre.org',
 		        
         'DetailedOptionsTitle' => 'Setări pentru lista detaliată',
         'DetailedOptionsImageSize' => 'Mărime imagini',
-        'DetailedOptionsGroupItems' => 'Grupează filmele după',
+        'DetailedOptionsGroupItems' => 'Grupează elementele după',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Selectează câmpurile afişate',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+        'DetailedOptionsGroupedFirst' => 'Păstrează împreună elementele orfane',
+        'DetailedOptionsAddCount' => 'Adaugă numărul elementelor la categorii',
 
         'ExtractButton' => 'Informaţii',
         'ExtractTitle' => 'Informaţii fişier video',
         'ExtractImport' => 'Foloseşte valorile',
 
-        'FieldsListOpen' => 'Load a fields list from a file',
-        'FieldsListSave' => 'Save fields list to a file',
-        'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListOpen' => 'Încarcă o listă de câmpuri dintr-un fişier',
+        'FieldsListSave' => 'Salvează lista de câmpuri într-un fişier',
+        'FieldsListError' => 'Această listă de fişiere nu poate fi folosită cu acest tip de colecţie',
+        'FieldsListIgnore' => '--- Ignore',
 
-        'ExportTitle' => 'Exportă lista de filme',
-        'ExportFilter' => 'Exportă doar filmele afişate',
+        'ExportTitle' => 'Exportă lista de elemente',
+        'ExportFilter' => 'Exportă doar elementele afişate',
         'ExportFieldsTitle' => 'Câmpurile ce vor fi exportate',
         'ExportFieldsTip' => 'Selectaţi câmpurile pe care doriţi să le exportaţi',
         'ExportWithPictures' => 'Copiază imaginile într-un subdirector',
+        'ExportSortBy' => 'Sortare după',
 
-        'ImportListTitle' => 'Importă altă listă de filme',
+        'ImportListTitle' => 'Importă altă listă de elemente',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Fişier',
         'ImportExportSave' => 'Vă rugăm selectaţi fişierul pentru folosire',
@@ -368,7 +383,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Creează o nouă colecţie',
         'ImportCurrentList' => 'Adaugă la colecţia curentă',
         'ImportDropError' => 'A intervenit o eroare la deschiderea a cel puţin unui fişier. Listă precedentă va fi reîncărcată.',
-        'ImportGenerateId' => 'Generate identifier for each item',
+        'ImportGenerateId' => 'Generează identificator pentru fiecare element',
 
         'FileOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',
 
@@ -379,50 +394,55 @@ http://le-spektre.org',
         'PanelSearchButton' => 'Obţine informaţii',
         'PanelSearchTip' => 'Caută pe web informaţii despre acest titlu',
         'PanelImageTipOpen' => 'Clic pe imagine pentru a selecta alta.',
-        'PanelImageTipView' => 'Click on the picture to view it in real size.',
+        'PanelImageTipView' => 'Clic pe image pentru a o vedea la dimensiunea originală.',
         'PanelImageTipMenu' => ' Clic dreapta pentru mai multe opţiuni.',
         'PanelImageTitle' => 'Selectaţi o imagine',
-        'PanelImageNoImage' => 'No image',
+        'PanelImageNoImage' => 'Nici o imagine',
         'PanelSelectFileTitle' => 'Selectaţi un fişier',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'Restaurează valorile implicite',
 
-        'PanelFrom' =>'From',
-        'PanelTo' =>'To',
+        'PanelFrom' =>'De la',
+        'PanelTo' =>'Către',
 
         'PanelWeb' => 'Mai multe informaţii',
-        'PanelWebTip' => 'Afişează informaţii de pe web despre acest film',
-        'PanelRemoveTip' => 'Şterge filmul curent',
+        'PanelWebTip' => 'Afişează informaţii de pe web despre acest element',
+        'PanelRemoveTip' => 'Şterge elementul curent',
 
         'PanelDateSelect' => 'Selectaţi o dată',
         'PanelNobody' => 'Nimeni',
         'PanelUnknown' => 'Necunoscut',
-        'PanelAdded' => 'Add date',
+        'PanelAdded' => 'Adaugă dată',
+        'PanelRating' => 'Evaluare',
         'PanelLocation' => 'Locaţie',
 
         'PanelLending' => 'Împrumuturi',
         'PanelBorrower' => 'Împrumutat',
         'PanelLendDate' => 'Din data',
         'PanelHistory' => 'Istoric împrumuturi',
-        'PanelReturned' => 'Film returnat',
+        'PanelReturned' => 'Element returnat',
         'PanelReturnDate' => 'Data returnării',
         'PanelLendedYes' => 'Împrumutat',
         'PanelLendedNo' => 'Disponibil',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Nu contează',
         'CheckYes' => 'Da',
         'CheckNo' => 'Nu',
 
         'ToolbarAll' => 'Afişează tot',
-        'ToolbarAllTooltip' => 'Afişează toate filmele',
-        'ToolbarGroupBy' => 'Group by',
-        'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarAllTooltip' => 'Afişează toate elementele',
+        'ToolbarGroupBy' => 'Grupează după',
+        'ToolbarGroupByTooltip' => 'Selectaţi câmpul folosit pentru a grupa elementele din listă',
         
-        'PluginsTitle' => 'Cautare filme',
-        'PluginsQuery' => 'Query',
+        'PluginsTitle' => 'Cautare elemente',
+        'PluginsQuery' => 'Interogare',
         'PluginsFrame' => 'Sit pentru căutare',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Nume',
-        'PluginsSearchFields' => 'Search fields',
+        'PluginsSearchFields' => 'Câmpuri căutate',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Limbă',
         'PluginsUseSite' => 'Foloseşte situl selectat pentru viitoarele căutări',
@@ -438,13 +458,13 @@ http://le-spektre.org',
         'BorrowersSubject' => 'Subiect mail',
         'BorrowersNotice1' => '%1 va fi înlocuit cu numele celui care a împrumutat',
         'BorrowersNotice2' => '%2 va fi înlocuit cu numele filmului',
-        'BorrowersNotice3' => '%3 va fi înlocuit cu data împrumutării',
+        'BorrowersNotice3' => '%3 va fi înlocuit cu data împrumutului',
 
-        'BorrowersImportTitle' => 'Import borrowers information',
-        'BorrowersImportType' => 'File format:',
-        'BorrowersImportFile' => 'File:',
+        'BorrowersImportTitle' => 'Importă informaţiile despre cel care a împrumutat',
+        'BorrowersImportType' => 'Format fişier:',
+        'BorrowersImportFile' => 'Fişier:',
 
-        'BorrowedTitle' => 'Filme împrumutate',
+        'BorrowedTitle' => 'Elemente împrumutate',
         'BorrowedDate' => 'Din data de',
 
         'MailTitle' => 'Trimite un email',
@@ -454,13 +474,13 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problemă la conectarea la serverul SMTP',
         'MailSendmailError' => 'Problemă la lansarea sendmail',
 
-        'SearchTooltip' => 'Caută toate filmele',
-        'SearchTitle' => 'Căutare film',
+        'SearchTooltip' => 'Caută toate elementele',
+        'SearchTitle' => 'Căutare element',
 
-        'QueryReplaceField' => 'Field to replace',
+        'QueryReplaceField' => 'Câmp pentru înlocuire',
         'QueryReplaceOld' => 'Numele actual',
         'QueryReplaceNew' => 'Noul nume',
-        'QueryReplaceLaunch' => 'Replace',
+        'QueryReplaceLaunch' => 'Înlocuieşte',
         
         'ImportWindowTitle' => 'Selectaţi câmpurile pentru import',
         'ImportViewPicture' => 'Afişează imaginea',
@@ -485,38 +505,45 @@ http://le-spektre.org',
         'GenresExport' => 'Salvează lista într-un fişier',
         'GenresModify' => 'Editează conversia',
 
-        'PropertiesName' => 'Collection name',
-        'PropertiesOwner' => 'Owner',
+        'PropertiesName' => 'Nume colecţie',
+        'PropertiesOwner' => 'Proprietar',
         'PropertiesEmail' => 'Email',
-        'PropertiesDescription' => 'Description',
-        'PropertiesFile' => 'File Information',
-        'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
-        'PropertiesFileSize' => 'Size',
+        'PropertiesDescription' => 'Descriere',
+        'PropertiesFile' => 'Informaţii fişier',
+        'PropertiesFilePath' => 'Cale completă',
+        'PropertiesItemsNumber' => 'Număr de elemente',
+        'PropertiesFileSize' => 'Mărime',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
-        'PropertiesCollection' => 'Collection properties',
+        'PropertiesCollection' => 'Proprietăţi colecţie',
 
-        'MailProgramsTitle' => 'Programs for mail sending',
-        'MailProgramsName' => 'Name',
-        'MailProgramsCommand' => 'Command line',
-        'MailProgramsRestore' => 'Restore defaults',
-        'MailProgramsAdd' => 'Add a program',
-        'MailProgramsInstructions' => 'In command line, some substitutions are made:
- %f is replaced with user\'s e-mail address.
- %t is replaced with the recipient address.
- %s is replaced with the subject of the message.
- %b is replaced with the body of the message.',
+        'MailProgramsTitle' => 'Programe pentru trimis mailuri',
+        'MailProgramsName' => 'Nume',
+        'MailProgramsCommand' => 'Linie de comandă',
+        'MailProgramsRestore' => 'Restaurează valorile implicite',
+        'MailProgramsAdd' => 'Adaugă un progra,',
+        'MailProgramsInstructions' => 'În linia de comandă, unele înlocuiri sunt făcute:
+ %f este înlocuit cu adresa de mail a utilizatorului.
+ %t este înlocuit cu adresa de mail a destinatarului.
+ %s este înlocuit cu subiectul mesajului.
+ %b este înlocuit cu corpul mesajului.',
 
-        'BookmarksBookmarks' => 'Bookmarks',
-        'BookmarksFolder' => 'Directory',
-        'BookmarksLabel' => 'Label',
-        'BookmarksPath' => 'Path',
-        'BookmarksNewFolder' => 'New folder',
+        'BookmarksBookmarks' => 'Favorite',
+        'BookmarksFolder' => 'Director',
+        'BookmarksLabel' => 'Etichetă',
+        'BookmarksPath' => 'Cale',
+        'BookmarksNewFolder' => 'Dosar nou',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchType' => 'Tipul de căutare',
+        'AdvancedSearchTypeAnd' => 'Elemente se potrivesc la toate criteriile',
+        'AdvancedSearchTypeOr' => 'Elementele se potrivesc la cel puţin un criteriu',
+        'AdvancedSearchCriteria' => 'Criteriu',
+        'AdvancedSearchAnyField' => 'Orice câmp',
+
+        'BugReportSubject' => 'Raportare bug generată de GCstar',
+        'BugReportVersion' => 'Versiune',
+        'BugReportPlatform' => 'Sistem de operare',
+        'BugReportMessage' => 'Mesaj de eroare',
+        'BugReportInformation' => 'Informaţii adiţionale',
     );
 }
 1;
