@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Использовать Javascript',
        	'FileTemplate' => 'Шаблон:',
         'Preview' => 'Предварительный просмотр',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Взял : ',
         'NotBorrowed' => 'Доступен',
         'Top' => 'Наверх',
+        'Bottom' => 'Bottom',
      );
 }
 
