@@ -47,12 +47,14 @@
         Image => 'Картинка',
         Original => 'Оригинальный заголовок',
         Actors => 'Актеры',
+        Actor => 'Actor',
+        Role => 'Role',
         Comment => 'Комментарии',
         Synopsis => 'Описание',
         Seen => 'Просмотрен',
         Number => '# носителей',
-        Rating => 'Рейтинг',
         Format => 'Носитель',
+        Identifier => 'Identifier',
         Url => 'ВЭБ',
         Audio => 'Аудио',
         Video => 'Видео формат',
