@@ -86,6 +86,7 @@
         'SplashInit' => 'Инициализация',
         'SplashLoad' => 'Загружается',
         'SplashDisplay' => 'Отображать коллекцию',
+        'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'Всё готово',
 
 #Import from GCfilms
@@ -172,8 +173,9 @@
         'AboutDesc' => 'Gtk2 Каталог Фиьмов',
         'AboutVersion' => 'Версия',
         'AboutTeam' => 'Команда',
-        'AboutWho' => 'Tian: Руководитель проекта, Программист
-Adolfo González : Программист',
+        'AboutWho' => 'Christian Jodar (Tian): Руководитель проекта, Программист
+Adolfo González: Программист
+Nyall Dawson (Zombiepig): Программист',
         'AboutLicense' => 'Распространяется под лицензией GNU GPL
 Логотипы Copyright le Spektre
 http://le-spektre.org',
@@ -233,6 +235,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'Для кнопки Воспроизведение',
         'ModelCollectionSettings' => 'Настройки коллекции',
         'ModelCollectionSettingsLending' => 'Предмет может быть дан взаймы',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Должно быть в строке поиска',
         'ModelFilterComparison' => 'Сравнение',
         'ModelFilterContain' => 'Содержит',
@@ -245,12 +248,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Должно ли введенное значение сохраняться в списке ассоциированном с полем',
         'ModelTooltipFormat' => 'Формат используется для определения действия которое происходит при нажатии кнопки Воспроизведение',
         'ModelTooltipLending' => 'Тут будут добавлены некоторые поля для управления займами',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Должны ли значения считаться цифрами при сравнении',
         'ModelTooltipQuick' => 'Это добавит подменю в фильтры',
 
         'ResultsTitle' => 'Выберите фильм',
         'ResultsNextTip' => 'искать на следующем сайте',
         'ResultsPreview' => 'Предпросмотр',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Предпочтения',
         'OptionsBrowser' => 'Вэб браузер',
@@ -265,6 +270,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Автоматически сохранять коллекцию',
         'OptionsAutoLoad' => 'Загружать предыдущую коллекцию при старте',
         'OptionsSplash' => 'Показывать стартовый экран',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Выберите директорию',
         'OptionsProgramTitle' => 'Выберите программу',
 		'OptionsPlugins' => 'Сайт с которого нужно получать данные',
@@ -274,6 +280,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Задать список',
         'OptionsAskImport' => 'Выберите поля для импортирования',
 		'OptionsProxy' => 'Использовать прокси',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Язык',
         'OptionsMain' => 'Основные',
         'OptionsPaths' => 'Пути',
@@ -281,9 +288,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Возможности',
         'OptionsDisplay' => 'Отображение',
         'OptionsToolbar' => 'Панель инструментов',
-        'OptionsToolbars' => {0 => 'Нет', 1 => 'Маленькая', 2 => 'Большая'},
+        'OptionsToolbars' => {0 => 'Нет', 1 => 'Маленькая', 2 => 'Большая', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Позиция',
         'OptionsToolbarPositions' => {0 => 'Вверху', 1 => 'Внизу', 2 => 'Слева', 3 => 'Справа'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Вид',
         'OptionsViews' => {0 => 'Текст', 1 => 'Картинка', 2 => 'Детально'},
         'OptionsColumns' => 'Колонки',
@@ -294,6 +305,7 @@ http://le-spektre.org',
         'OptionsArticles' => 'Артикли (разделённые запятой)',
         'OptionsSearchStop' => 'Разрешить прерывать поиск',
         'OptionsAlwaysOriginal' => 'Использовать основной заголовок вместо оригинального, если он отсутствует',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Размер истории',
         'OptionsClearHistory' => 'Очистить историю',
 		'OptionsStyle' => 'Шкура',
@@ -322,6 +334,7 @@ http://le-spektre.org',
         'ImagesOptionsButton' => 'Настройки',
         'ImagesOptionsTitle' => 'Настройки для списка изображений',
         'ImagesOptionsSelectColor' => 'Выберите цвет',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Фон',
         'ImagesOptionsBgPicture' => 'Выберите фоновое изображение',
         'ImagesOptionsFg'=> 'Выделение',
@@ -334,10 +347,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Настройки для детализированного списка',
         'DetailedOptionsImageSize' => 'Размер изображения',
         'DetailedOptionsGroupItems' => 'Группировать элементы по',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Выберите поля для отображения',
-		'DetailedOptionsMasterOption' => 'Основная группировка ',
-		'DetailedOptionsMasterGenerated' => 'Автоматически созданный',
-		'DetailedOptionsMasterOrdered' => 'Определяется ',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'Информация',
         'ExtractTitle' => 'Информация из видеофайла',
@@ -346,12 +359,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Загрузить список полей из файла',
         'FieldsListSave' => 'Сохранить список полей в файл',
         'FieldsListError' => 'Этот список полей не может быть использован с данным типом коллекции',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Экспортировать список фильмов',
         'ExportFilter' => 'Экспортировать только показанные фильмы',
         'ExportFieldsTitle' => 'Поля для экспорта',
         'ExportFieldsTip' => 'Выберите поля которые вы хотите экспортировать',
         'ExportWithPictures' => 'Скопировать изображения в под-директорию',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'Импортировать другой список фильмоа',
         'ImportExportData' => 'Данные',
@@ -397,6 +412,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Никто',
         'PanelUnknown' => 'Неизвестно',
         'PanelAdded' => 'Добавить дату',
+        'PanelRating' => 'Рейтинг',
         'PanelLocation' => 'Размещение',
 
         'PanelLending' => 'На руках',
@@ -408,6 +424,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Взято напрокат',
         'PanelLendedNo' => 'Доступно',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Или',
         'CheckYes' => 'Да',
         'CheckNo' => 'Нет',
@@ -517,6 +537,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Элементы удовлетворяющие всем критериям',
         'AdvancedSearchTypeOr' => 'Элементы удовлетворяющие по крайней мере одному критерию',
         'AdvancedSearchCriteria' => 'Критерий',
+        'AdvancedSearchAnyField' => 'Any field',
+
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
