@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Koristi Javascript',
        	'FileTemplate' => 'Šabloni :',
         'Preview' => 'Vidi kako izgleda',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Pozajmljen: ',
         'NotBorrowed' => 'Ovde',
         'Top' => 'Na vrh',
+        'Bottom' => 'Bottom',
      );
 }
 
