@@ -43,10 +43,10 @@
         Publication => 'Publication date',
         Language => 'Language',
         Genre => 'Genre',
+        Serie => 'Kolekcija',
         Bookdescription => 'Description',
         Pages => 'Pages',
         Read => 'Read',
-        Rating => 'Rating',
         Acquisition => 'Acquisition date',
         Edition => 'Edition',
         Format => 'Format',
