@@ -83,6 +83,7 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
     	'SplashInit' => 'Startovanje',
     	'SplashLoad' => 'Učitavam kolekciju',
         'SplashDisplay' => 'Displaying Collection',
+        'SplashSort' => 'Sorting Collection',
     	'SplashDone' => 'Spremno',
 
 #Import from GCfilms
@@ -169,8 +170,9 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'AboutDesc' => 'Gtk2 Katalog Filmova',
         'AboutVersion' => 'Verzija',
         'AboutTeam' => 'Tim',
-        'AboutWho' => 'Tian: Vođa projekta, Programer
-Adolfo GonzĂˇlez : Programer',
+        'AboutWho' => 'Christian Jodar (Tian): Vođa projekta, Programer
+Adolfo González: Programer
+Nyall Dawson (Zombiepig): Programer',
         'AboutLicense' => 'Distribuirano pod GNU GPL uslovima
 Logo Copyright le Spektre
 http://le-spektre.org',
@@ -230,6 +232,7 @@ http://le-spektre.org',
         'ModelOptionsFieldsPlay' => 'For Play button',
         'ModelCollectionSettings' => 'Collection settings',
         'ModelCollectionSettingsLending' => 'Items could be borrowed',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
@@ -242,12 +245,14 @@ http://le-spektre.org',
         'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
         'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
         'ModelTooltipLending' => 'This will add some fields to manage lendings',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
         'ResultsTitle' => 'Odaberite film',
         'ResultsNextTip' => 'Pretraži sledeći sajt',
         'ResultsPreview' => 'Preview',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Podešavanja',
         'OptionsBrowser' => 'Web brauzer',
@@ -262,6 +267,7 @@ http://le-spektre.org',
         'OptionsAutoSave' => 'Automatski sačuvaj kolekciju',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Prikaži uvodni ekran (splash screen)',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Odaberite direktorijum',
         'OptionsProgramTitle' => 'Odaberite koji program želite da koristite',
 		'OptionsPlugins' => 'Sajt sa kog želite da preuzmete podatke',
@@ -271,6 +277,7 @@ http://le-spektre.org',
 		'OptionsPluginsList' => 'Zadaj listu',
         'OptionsAskImport' => 'Odaberite polja za uvoženje',
 		'OptionsProxy' => 'Koristi proxy',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Jezik',
         'OptionsMain' => 'Glavni',
         'OptionsPaths' => 'Putanje',
@@ -278,9 +285,13 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Funkcije',
         'OptionsDisplay' => 'Prikaz',
         'OptionsToolbar' => 'Alati',
-        'OptionsToolbars' => {0 => 'Bez', 1 => 'Mali', 2 => 'Veliki'},
+        'OptionsToolbars' => {0 => 'Bez', 1 => 'Mali', 2 => 'Veliki', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Pozicija',
         'OptionsToolbarPositions' => {0 => 'Vrh', 1 => 'Dno', 2 => 'Levo', 3 => 'Desno'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Prikaz',
         'OptionsViews' => {0 => 'Tekst', 1 => 'Slika', 2 => 'Detaljno'},
         'OptionsColumns' => 'Kolone',
@@ -291,6 +302,7 @@ http://le-spektre.org',
         'OptionsArticles' => 'Članovi (Odvojeni zarezom)',
         'OptionsSearchStop' => 'Dozvoli da pretraga bude prekinuta',
         'OptionsAlwaysOriginal' => 'Koristi glavni naslov kao originalni ukoliko originalnog nema',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Veličina istorije',
         'OptionsClearHistory' => 'Obriši istoriju',
 		'OptionsStyle' => 'Promena izgleda',
@@ -319,6 +331,7 @@ http://le-spektre.org',
         'ImagesOptionsButton' => 'Podešavanja',
         'ImagesOptionsTitle' => 'Podešavanja za liste slika',
         'ImagesOptionsSelectColor' => 'Odaberi boju',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Pozadina',
         'ImagesOptionsBgPicture' => 'Upotrebi pozadisku sliku',
         'ImagesOptionsFg'=> 'Selekcija',
@@ -331,10 +344,10 @@ http://le-spektre.org',
         'DetailedOptionsTitle' => 'Podešavanja za detaljnu listu',
         'DetailedOptionsImageSize' => 'Veličina slike',
         'DetailedOptionsGroupItems' => 'Grupiši filmove prema kolekciji',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Odaberi polja za prikaz',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'Informacije',
         'ExtractTitle' => 'Informacije o video fajlu',
@@ -343,12 +356,14 @@ http://le-spektre.org',
         'FieldsListOpen' => 'Load a fields list from a file',
         'FieldsListSave' => 'Save fields list to a file',
         'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Izvezi listu filmova',
         'ExportFilter' => 'Izvezi samo prikazane filmove',
         'ExportFieldsTitle' => 'Polja za izvoženje',
         'ExportFieldsTip' => 'Odaberi polja koja želiš da izvezeš',
         'ExportWithPictures' => 'Kopiraj slike u pod-direktorijum',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'Uvezi drugu listu filmova',
         'ImportExportData' => 'Data',
@@ -394,6 +409,7 @@ http://le-spektre.org',
         'PanelNobody' => 'Niko',
         'PanelUnknown' => 'Nepoznat',
         'PanelAdded' => 'Add date',
+        'PanelRating' => 'Ocena',
         'PanelLocation' => 'Lokacija',
 
         'PanelLending' => 'Pozajmljivanje',
@@ -405,6 +421,10 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Pozajmljen',
         'PanelLendedNo' => 'Ovde',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Ili',
         'CheckYes' => 'Da',
         'CheckNo' => 'Ne',
@@ -514,6 +534,13 @@ http://le-spektre.org',
         'AdvancedSearchTypeAnd' => 'Items matching all criteria',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'Any field',
+
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
