@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Javascript kullan',
        	'FileTemplate' => 'Biçem :',
         'Preview' => 'Önizleme',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Ödünç alan: ',
         'NotBorrowed' => 'Arşivde',
         'Top' => 'Başa dön',
+        'Bottom' => 'Bottom',
      );
 }
 
