@@ -47,12 +47,14 @@
         Image => 'Kapak',
         Original => 'Özgün Adı',
         Actors => 'Oyuncular',
+        Actor => 'Actor',
+        Role => 'Role',
         Comment => 'Yorumlar, Ödüller ve Diğer Bilgiler',
         Synopsis => 'Konu',
         Seen => 'İzlendi',
         Number => 'Sayısı',
-        Rating => 'Puan',
         Format => 'Medya',
+        Identifier => 'Identifier',
         Url => 'Web',
         Audio => 'Ses',
         Video => 'Video formatı',
