@@ -90,6 +90,7 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
     	'SplashInit' => 'Program açılıyor...',
     	'SplashLoad' => 'Veritabanı yükleniyor...',
         'SplashDisplay' => 'Displaying Collection',
+        'SplashSort' => 'Sorting Collection',
     	'SplashDone' => 'Hazır.',
 
 #Import from GCfilms
@@ -176,8 +177,9 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'AboutDesc' => 'Veritabanı Yöneticisi',
         'AboutVersion' => 'Sürüm',
         'AboutTeam' => 'Takım',
-        'AboutWho' => 'Tian: Proje Yöneticisi, Programcı
-Adolfo González : Programcı',
+        'AboutWho' => 'Christian Jodar (Tian): Proje Yöneticisi, Programcı
+Adolfo González: Programcı
+Nyall Dawson (Zombiepig): Programcı',
         'AboutLicense' => 'GNU GPL lisansı altında dağıtılmaktadır
 Logoların telif hakları le Spektre
 http://le-spektre.org\'a aittir.',
@@ -237,6 +239,7 @@ http://le-spektre.org\'a aittir.',
         'ModelOptionsFieldsPlay' => 'For Play button',
         'ModelCollectionSettings' => 'Collection settings',
         'ModelCollectionSettingsLending' => 'Items could be borrowed',
+        'ModelCollectionSettingsTagging' => 'Items can be tagged',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
@@ -249,12 +252,14 @@ http://le-spektre.org\'a aittir.',
         'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
         'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
         'ModelTooltipLending' => 'This will add some fields to manage lendings',
+        'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
         'ResultsTitle' => 'Bir başlık seçiniz',
         'ResultsNextTip' => 'Bir sonraki sitede ara',
         'ResultsPreview' => 'Preview',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Ayarlar',
         'OptionsBrowser' => 'Web tarayıcı',
@@ -269,6 +274,7 @@ http://le-spektre.org\'a aittir.',
         'OptionsAutoSave' => 'Veritabanını otomatik olarak kaydet',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Başlangıç ekranını göster',
+        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsImagesTitle' => 'Bir Klasör Seçiniz',
         'OptionsProgramTitle' => 'Bir Program Seçiniz',
 		'OptionsPlugins' => 'Bilginin alınacağı siteyi seçiniz',
@@ -278,6 +284,7 @@ http://le-spektre.org\'a aittir.',
 		'OptionsPluginsList' => 'Listeyi oluşturun',
         'OptionsAskImport' => 'Alınacak bilgi alanları',
 		'OptionsProxy' => 'Proxy Kullan',
+		'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Dil',
         'OptionsMain' => 'Genel',
         'OptionsPaths' => 'Dizin',
@@ -285,9 +292,13 @@ http://le-spektre.org\'a aittir.',
         'OptionsConveniences' => 'Diğer',
         'OptionsDisplay' => 'Görsel',
         'OptionsToolbar' => 'Menü',
-        'OptionsToolbars' => {0 => 'Yok', 1 => 'Küçük', 2 => 'Büyük'},
+        'OptionsToolbars' => {0 => 'Yok', 1 => 'Küçük', 2 => 'Büyük', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Konum',
         'OptionsToolbarPositions' => {0 => 'Üst', 1 => 'Alt', 2 => 'Sol', 3 => 'Sağ'},
+        'OptionsExpandersMode' => 'Expanders too long',
+        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsDateFormat' => 'Date Format',
+        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
         'OptionsView' => 'Film Listesi',
         'OptionsViews' => {0 => 'Başlık Adları', 1 => 'Kapak', 2 => 'Detay'},
         'OptionsColumns' => 'Kolonlar',
@@ -298,6 +309,7 @@ http://le-spektre.org\'a aittir.',
         'OptionsArticles' => 'Öbekler (virgülle ayrılmış)',
         'OptionsSearchStop' => 'Aramanın durdurulmasını sağlar',
         'OptionsAlwaysOriginal' => 'Başlık için özgün ad yoksa kendi adını kullan',
+        'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Geçmiş dosya kısıtlaması',
         'OptionsClearHistory' => 'Geçmişi temizle',
 		'OptionsStyle' => 'Arayüz',
@@ -326,6 +338,7 @@ http://le-spektre.org\'a aittir.',
         'ImagesOptionsButton' => 'Ayarlar',
         'ImagesOptionsTitle' => 'Kağak listesi için ayarlar',
         'ImagesOptionsSelectColor' => 'Renk seçiniz',
+        'ImagesOptionsUseOverlays' => 'Use image overlays',
         'ImagesOptionsBg' => 'Arkaplan',
         'ImagesOptionsBgPicture' => 'Arkaplan resmi kullan',
         'ImagesOptionsFg'=> 'Seçim',
@@ -338,10 +351,10 @@ http://le-spektre.org\'a aittir.',
         'DetailedOptionsTitle' => 'Detaylı liste için ayarlar',
         'DetailedOptionsImageSize' => 'Kapak boyutu',
         'DetailedOptionsGroupItems' => 'Filmleri Koleksiyon türüne göre sınıflandır',
+        'DetailedOptionsSecondarySort' => 'Sort field for children',
 		'DetailedOptionsFields' => 'Gösterilecek alanları seçiniz',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
+        'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
         'ExtractButton' => 'Bilgi',
         'ExtractTitle' => 'Video Bilgisi',
@@ -350,12 +363,14 @@ http://le-spektre.org\'a aittir.',
         'FieldsListOpen' => 'Load a fields list from a file',
         'FieldsListSave' => 'Save fields list to a file',
         'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListIgnore' => '--- Ignore',
 
         'ExportTitle' => 'Film listesini ver',
         'ExportFilter' => 'Sadece seçili filmleri ver',
         'ExportFieldsTitle' => 'Verilecek alanlar',
         'ExportFieldsTip' => 'Aktarılacak alanları seçiniz',
         'ExportWithPictures' => 'Kapak resimlerini bir alt klasöre kopyala',
+        'ExportSortBy' => 'Sort by',
 
         'ImportListTitle' => 'Diğer bir film listesinden aktar',
         'ImportExportData' => 'Data',
@@ -402,6 +417,7 @@ http://le-spektre.org\'a aittir.',
         'PanelNobody' => 'Kimse',
         'PanelUnknown' => 'Bilinmiyor',
         'PanelAdded' => 'Add date',
+        'PanelRating' => 'Puan',
         'PanelLocation' => 'Yer',
 
         'PanelLending' => 'Ödünç',
@@ -413,6 +429,10 @@ http://le-spektre.org\'a aittir.',
         'PanelLendedYes' => 'Ödün verilme',
         'PanelLendedNo' => 'Arşivde',
 
+        'PanelTags' => 'Tags',
+        'PanelFavourite' => 'Favourite',
+        'TagsAssigned' => 'Assigned Tags', 
+
         'CheckUndef' => 'Farketmez',
         'CheckYes' => 'Evet',
         'CheckNo' => 'Hayır',
@@ -522,6 +542,13 @@ http://le-spektre.org\'a aittir.',
         'AdvancedSearchTypeAnd' => 'Items matching all criteria',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'Any field',
+
+        'BugReportSubject' => 'Bug report generated from GCstar',
+        'BugReportVersion' => 'Version',
+        'BugReportPlatform' => 'Operating system',
+        'BugReportMessage' => 'Error message',
+        'BugReportInformation' => 'Additional information',
     );
 }
 1;
