@@ -2,7 +2,7 @@ package GCMail;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -29,7 +29,7 @@ our $muas = 0;
 
 our %defaultMua = (
     'Evolution' => 'evolution "mailto:%t?subject=%s&body=%b"',
-    'Sylpheed-Claws' => 'sylpheed-claws --compose "mailto:%t?subject=%s&body=%b"',
+    'Claws Mail' => 'sylpheed-claws --compose "mailto:%t?subject=%s&body=%b"',
     'Thunderbird' => 'thunderbird -compose "mailto:%t?subject=%s&body=%b"',
 );
 
