@@ -34,32 +34,20 @@ use strict;
 
     sub addHistoryMenu
     {
-        my $self = shift;
+        my ($self, $historyArray) = @_;
         my $parent = $self->{parent};
 
-        $parent->{options}->historysize (5) if $parent->{options}->historysize eq "";
-        $parent->{options}->history ("none|" x ($parent->{options}->historysize - 1) . "none") if $parent->{options}->history eq "";
-
-        my @tmpHistory = split(/\|/, $parent->{options}->history);
-        my $current_size = scalar @tmpHistory;
-        if ($current_size < $parent->{options}->historysize)
+        my @tmpHistory;
+        if (! $historyArray)
         {
-            $parent->{options}->history ($parent->{options}->history . "|none" x ($parent->{options}->historysize - $current_size));
+            my @tmpHistory = split(/\|/, $parent->{options}->history);
+            $historyArray = \@tmpHistory;
         }
-        elsif ($current_size > $parent->{options}->historysize)
+        foreach my $filename(@$historyArray)
         {
-            my $size = $parent->{options}->historysize - 1;
-            (my $history = $parent->{options}->history) =~ s/^((?:[^\|]*\|){$size})?([^\|]*)\|.*$/$1$2/;
-            $parent->{options}->history ($history);
-        }
-
-        my @history_array = split /\|/, $parent->{options}->history;
-        foreach my $filename(@history_array)
-        {
-            next if $filename eq "none";
-            next if $filename eq "";
+            next if !$filename || ($filename eq 'none');
             my $item = Gtk2::MenuItem->new_with_label($filename);
-            $item->signal_connect ("activate" => sub {
+            $item->signal_connect ('activate' => sub {
                         $parent->openFile($filename);
                     });
             $self->{menuHistory}->append($item);
@@ -249,10 +237,12 @@ use strict;
         my $position = 1;
         foreach my $filter(@{$model->{filters}})
         {
-            next if $filter->{quick} ne 'true';
+            next if (!defined $filter->{quick}) || ($filter->{quick} ne 'true');
             my $field = $filter->{field};
             $self->{filtersInfo}->{$field} = $filter;
-            $self->{'menuFilter'.$field} = Gtk2::Menu->new();
+            $self->{'menuFilter'.$field} = Gtk2::Menu->new;
+            $self->{'menuFilter'.$field}->set_accel_path("<main>/Filter/$field");
+            $self->{'menuFilter'.$field}->set_accel_group($self->{accel});
             
             my $all = Gtk2::RadioMenuItem->new_with_mnemonic(undef,$self->{parent}->{lang}->{MenuNoFilter});
             $self->{'group'.$field} = $all->get_group();
@@ -366,6 +356,7 @@ use strict;
             my $label = $fieldsInfo->{$field}->{displayed};
             $label = $model->getDisplayedText($filter->{label}) if $filter->{label};            
             $self->{'item'.$field} = Gtk2::MenuItem->new_with_mnemonic($label);
+            $self->{'item'.$field}->set_accel_path("<main>/Display/$field");
             $self->{'item'.$field}->set_submenu($self->{'menuFilter'.$field});
             $self->{menuDisplay}->insert($self->{'item'.$field}, $position);
             $self->{'item'.$field}->show_all;
@@ -380,7 +371,6 @@ use strict;
     sub refreshFilters
     {
         my $self = shift;
-        
         foreach (keys %{$self->{dynamicFilters}})
         {
             $self->checkFilter($_);
@@ -390,7 +380,6 @@ use strict;
     sub checkFilter
     {
         my ($self, $field) = @_;
-
         return if ! exists $self->{dynamicFilters}->{$field};
         $self->{deactivated} = 1;
         my $values = $self->{parent}->{panel}->getValues($field);
@@ -466,7 +455,7 @@ use strict;
     
     sub new
     {
-        my ($proto, $parent) = @_;
+        my ($proto, $parent, $accelMapFile) = @_;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
         bless ($self, $class);
@@ -478,18 +467,22 @@ use strict;
         # File Menu
         ############################
 
-        $self->{menuFile} = Gtk2::Menu->new();
+        $self->{menuFile} = Gtk2::Menu->new;
+        $self->{menuFile}->set_accel_path('<main>/File');
+        $self->{menuFile}->set_accel_group($self->{accel});
 
         my $fto = Gtk2::TearoffMenuItem->new();
         $self->{menuFile}->append($fto);
 
-        my $newdb = Gtk2::ImageMenuItem->new_from_stock('gtk-new', $self->{accel});
+        my $newdb = Gtk2::ImageMenuItem->new_from_stock('gtk-new');
+        $newdb->set_accel_path('<main>/File/gtk-new');
         $newdb->signal_connect ('activate' => sub {
             $self->{parent}->newList;
         });
         $self->{menuFile}->append($newdb);
 
-        my $opendb = Gtk2::ImageMenuItem->new_from_stock('gtk-open', $self->{accel});
+        my $opendb = Gtk2::ImageMenuItem->new_from_stock('gtk-open');
+        $opendb->set_accel_path('<main>/File/gtk-open');
         $opendb->signal_connect ('activate' => sub {
             $self->{parent}->openList;
         });
@@ -498,13 +491,15 @@ use strict;
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-        $self->{savedb} = Gtk2::ImageMenuItem->new_from_stock('gtk-save', $self->{accel});
+        $self->{savedb} = Gtk2::ImageMenuItem->new_from_stock('gtk-save');
+        $self->{savedb}->set_accel_path('<main>/File/gtk-save');
         $self->{savedb}->signal_connect ('activate' => sub {
             $self->{parent}->saveList;
         });
         $self->{menuFile}->append($self->{savedb});
 
-        my $saveasdb = Gtk2::ImageMenuItem->new_from_stock('gtk-save-as', $self->{accel});
+        my $saveasdb = Gtk2::ImageMenuItem->new_from_stock('gtk-save-as');
+        $saveasdb->set_accel_path('<main>/File/gtk-save-as');
         $saveasdb->signal_connect ('activate' => sub {
             $self->{parent}->saveAs;
         });
@@ -514,19 +509,22 @@ use strict;
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-        my $newitem = Gtk2::ImageMenuItem->new_from_stock('gtk-add', $self->{accel});
+        my $newitem = Gtk2::ImageMenuItem->new_from_stock('gtk-add');
+        $newitem->set_accel_path('<main>/File/gtk-add');
         $newitem->signal_connect ('activate' => sub {
             $self->{parent}->newItem;
         });
         $self->{menuFile}->append($newitem);
 
-        my $properties = Gtk2::ImageMenuItem->new_from_stock('gtk-properties', $self->{accel});
+        my $properties = Gtk2::ImageMenuItem->new_from_stock('gtk-properties');
+        $properties->set_accel_path('<main>/File/gtk-properties');
         $properties->signal_connect ('activate' => sub {
             $self->{parent}->properties;
         });
         $self->{menuFile}->append($properties);
 
         my $lend = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuLend});
+        $lend->set_accel_path('<main>/File/Borrowers');
         $lend->signal_connect ('activate' => sub {
             $self->{parent}->showBorrowed;
         });
@@ -535,17 +533,20 @@ use strict;
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-           $self->{menuHistoryItem} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuHistory});
+        $self->{menuHistoryItem} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuHistory});
+        $self->{menuHistoryItem}->set_accel_path('<main>/File/History');
         $self->{menuHistory} = Gtk2::Menu->new();
-            addHistoryMenu($self);
+        addHistoryMenu($self);
         $self->{menuFile}->append($self->{menuHistoryItem});
 
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
                 
-        my $importItem = Gtk2::ImageMenuItem->new_from_stock('gtk-convert', $self->{accel});
-        $self->{menuImport} = Gtk2::Menu->new();
-       
+        my $importItem = Gtk2::ImageMenuItem->new_from_stock('gtk-convert');
+        $importItem->set_accel_path('<main>/File/gtk-convert');
+        $self->{menuImport} = Gtk2::Menu->new;
+        $self->{menuImport}->set_accel_path('<main>/Import');
+        $self->{menuImport}->set_accel_group($self->{accel});       
         foreach my $importer(@GCImport::importersArray)
         {
             $importer->setLangName($parent->{options}->lang);
@@ -558,8 +559,10 @@ use strict;
         $importItem->set_submenu($self->{menuImport});
         $self->{menuFile}->append($importItem);        
 
-        my $exportItem = Gtk2::ImageMenuItem->new_from_stock('gtk-revert-to-saved', $self->{accel});
-        $self->{menuExport} = Gtk2::Menu->new();
+        my $exportItem = Gtk2::ImageMenuItem->new_from_stock('gtk-revert-to-saved');
+        $self->{menuExport} = Gtk2::Menu->new;
+        $self->{menuExport}->set_accel_path('<main>/Export');
+        $self->{menuExport}->set_accel_group($self->{accel});
         $self->{exporters} = {};
         foreach my $exporter(@GCExport::exportersArray)
         {
@@ -577,7 +580,8 @@ use strict;
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-        my $leave = Gtk2::ImageMenuItem->new_from_stock('gtk-quit', $self->{accel});
+        my $leave = Gtk2::ImageMenuItem->new_from_stock('gtk-quit');
+        $leave->set_accel_path('<main>/File/gtk-quit');
         $self->{menuFile}->append($leave);
         $leave->signal_connect('activate' ,sub {
             $self->{parent}->leave;
@@ -591,17 +595,28 @@ use strict;
         ############################
         # Edit Menu
         ############################
-        $self->{menuEdit} = Gtk2::Menu->new();
+        $self->{menuEdit} = Gtk2::Menu->new;
+        $self->{menuEdit}->set_accel_path('<main>/Edit');
+        $self->{menuEdit}->set_accel_group($self->{accel});
         my $eto = Gtk2::TearoffMenuItem->new();
         $self->{menuEdit}->append($eto);
 
-        my $duplicateItem = Gtk2::ImageMenuItem->new_from_stock('gtk-dnd', $self->{accel});
+        my $duplicateItem = Gtk2::ImageMenuItem->new_from_stock('gtk-dnd');
+        $duplicateItem->set_accel_path('<main>/Edit/gtk-dnd');
         $duplicateItem->signal_connect('activate' , sub {
             $self->{parent}->duplicateItem;
         });
         $self->{menuEdit}->append($duplicateItem);
 
-        my $deleteCurrentItem = Gtk2::ImageMenuItem->new_from_stock('gtk-delete', $self->{accel});
+        my $selectAllItem = Gtk2::ImageMenuItem->new_from_stock('gtk-select-all');
+        $selectAllItem->set_accel_path('<main>/Edit/gtk-select-all');
+        $selectAllItem->signal_connect('activate' , sub {
+            $self->{parent}->selectAll;
+        });
+        $self->{menuEdit}->append($selectAllItem);
+
+        my $deleteCurrentItem = Gtk2::ImageMenuItem->new_from_stock('gtk-delete');
+        $deleteCurrentItem->set_accel_path('<main>/Edit/gtk-delete');
         $deleteCurrentItem->signal_connect('activate' , sub {
             $self->{parent}->deleteCurrentItem;
         });
@@ -611,6 +626,7 @@ use strict;
         ############################
 
         $self->{editFieldsItem} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuEditFields});
+        $self->{editFieldsItem}->set_accel_path('<main>/Edit/Collection');
         $self->{editFieldsItem}->signal_connect('activate' , sub {
             $self->{parent}->editModel;
         });
@@ -619,7 +635,8 @@ use strict;
         $self->{menuEdit}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-        my $queryReplaceItem = Gtk2::ImageMenuItem->new_from_stock('gtk-find-and-replace', $self->{accel});
+        my $queryReplaceItem = Gtk2::ImageMenuItem->new_from_stock('gtk-find-and-replace');
+        $queryReplaceItem->set_accel_path('<main>/Edit/gtk-find-and-replace');
         $queryReplaceItem->signal_connect('activate' , sub {
             $self->{parent}->queryReplace;
         });
@@ -629,6 +646,7 @@ use strict;
         ############################
 
         my $lockItemsItem = Gtk2::CheckMenuItem->new_with_mnemonic($parent->{lang}->{MenuEditLockItems});
+        $lockItemsItem->set_accel_path('<main>/Edit/Lock');
         $self->{menuEdit}->append($lockItemsItem);
          #$lockItemsItem->set_active($parent->{items}->getLock);
         $lockItemsItem->signal_connect('activate' , sub {
@@ -641,28 +659,31 @@ use strict;
         $self->{menuEditLockItemsItem}=$lockItemsItem;
         $lockItemsItem->{parent}=$self->{menuEdit};
 
-        my $edititem = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuEdit});
-        $edititem->set_submenu($self->{menuEdit});
-        $self->append($edititem);
+        my $editItem = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuEdit});
+        $editItem->set_submenu($self->{menuEdit});
+        $self->append($editItem);
 
         ############################
         # Display Menu
         ############################
-        $self->{menuDisplay} = Gtk2::Menu->new();
-
-        my $dto = Gtk2::TearoffMenuItem->new();
+        $self->{menuDisplay} = Gtk2::Menu->new;
+        $self->{menuDisplay}->set_accel_path('<main>/Display');
+        $self->{menuDisplay}->set_accel_group($self->{accel});
+        my $dto = Gtk2::TearoffMenuItem->new;
         $self->{menuDisplay}->append($dto);
 
         $self->{menuDisplay}->append(new Gtk2::SeparatorMenuItem);
         ############################
 
-        my $search = Gtk2::ImageMenuItem->new_from_stock('gtk-find', $self->{accel});
+        my $search = Gtk2::ImageMenuItem->new_from_stock('gtk-find');
+        $search->set_accel_path('<main>/Display/gtk-find');
         $search->signal_connect('activate' , sub {
                 $self->{parent}->search('all');
         }); 
         $self->{menuDisplay}->append($search);
 
         my $advancedSearch = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuAdvancedSearch});
+        $advancedSearch->set_accel_path('<main>/Display/Advanced');
         my $advancedImage = Gtk2::Image->new_from_stock('gtk-find', 'menu');
         $advancedSearch->set_image($advancedImage);
         $advancedSearch->signal_connect('activate' , sub {
@@ -670,7 +691,8 @@ use strict;
         }); 
         $self->{menuDisplay}->append($advancedSearch);
 
-        my $random = Gtk2::ImageMenuItem->new_from_stock('gtk-execute', $self->{accel});
+        my $random = Gtk2::ImageMenuItem->new_from_stock('gtk-execute');
+        $random->set_accel_path('<main>/Display/gtk-execute');
         $random->signal_connect('activate' , sub {
                 $self->{parent}->randomItem;
         }); 
@@ -680,6 +702,7 @@ use strict;
         ############################
 
         my $allItems = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuViewAllItems});
+        $allItems->set_accel_path('<main>/Display/All');
         my $refreshImage = Gtk2::Image->new_from_stock('gtk-refresh', 'menu');
         $allItems->set_image($refreshImage);
         $allItems->signal_connect('activate' , sub {
@@ -695,10 +718,13 @@ use strict;
         ############################
         # Configuration Menu
         ############################
-        $self->{menuConfig} = Gtk2::Menu->new();
-        my $cto = Gtk2::TearoffMenuItem->new();
+        $self->{menuConfig} = Gtk2::Menu->new;
+        $self->{menuConfig}->set_accel_path('<main>/Config');
+        $self->{menuConfig}->set_accel_group($self->{accel});
+        my $cto = Gtk2::TearoffMenuItem->new;
         $self->{menuConfig}->append($cto);
-        my $options = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences',$self->{accel});
+        my $options = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences');
+        $options->set_accel_path('<main>/Config/gtk-preferences');
         $options->signal_connect('activate' , sub {
             my ($widget, $window) = @_;
             $window->options;
@@ -706,12 +732,14 @@ use strict;
         $self->{menuConfig}->append($options);
 
         my $displayOptions = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuDisplayOptions});
+        $displayOptions->set_accel_path('<main>/Config/Display');
         $displayOptions->signal_connect ('activate' => sub {
             $self->{parent}->displayOptions;
         });
         $self->{menuConfig}->append($displayOptions);
 
         my $borrowers = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBorrowers});
+        $borrowers->set_accel_path('<main>/Config/Borrowers');
         $borrowers->signal_connect ('activate' => sub {
             $self->{parent}->borrowers;
         });
@@ -724,16 +752,20 @@ use strict;
         ############################
         # Bookmarks Menu
         ############################
-        $self->{menuBookmarks} = Gtk2::Menu->new();
-        my $bto = Gtk2::TearoffMenuItem->new();
+        $self->{menuBookmarks} = Gtk2::Menu->new;
+        $self->{menuBookmarks}->set_accel_path('<main>/Bookmarks');
+        $self->{menuBookmarks}->set_accel_group($self->{accel});
+        my $bto = Gtk2::TearoffMenuItem->new;
         $self->{menuBookmarks}->append($bto);
         $self->{addBookmark} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksAdd});
+        $self->{addBookmark}->set_accel_path('<main>/Bookmarks/Add');
         $self->{addBookmark}->signal_connect('activate' , sub {
             $self->{parent}->addBookmark;
         });
         $self->{menuBookmarks}->append($self->{addBookmark});
 
         my $editBookmark = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksEdit});
+        $editBookmark->set_accel_path('<main>/Bookmarks/Edit');
         $editBookmark->signal_connect('activate' , sub {
             $self->{parent}->editBookmark;
         });
@@ -748,32 +780,39 @@ use strict;
         ############################
         # Help Menu
         ############################
-        $self->{menuHelp} = Gtk2::Menu->new();
-        my $hto = Gtk2::TearoffMenuItem->new();
+        $self->{menuHelp} = Gtk2::Menu->new;
+        $self->{menuHelp}->set_accel_path('<main>/Help');
+        $self->{menuHelp}->set_accel_group($self->{accel});
+        my $hto = Gtk2::TearoffMenuItem->new;
         $self->{menuHelp}->append($hto);
-        my $help = Gtk2::ImageMenuItem->new_from_stock('gtk-help',$self->{accel});
+        my $help = Gtk2::ImageMenuItem->new_from_stock('gtk-help');
+        $help->set_accel_path('<main>/Help/Content');
         $help->signal_connect('activate' , sub {
             my ($widget, $window) = @_;
             $window->help;
         }, $self->{parent});
         $self->{menuHelp}->append($help);
         my $plugins = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuAllPlugins});
+        $plugins->set_accel_path('<main>/Help/Plugins');
         $plugins->signal_connect ('activate' => sub {
             $self->{parent}->showAllPlugins;
         });
         $self->{menuHelp}->append($plugins);
         my $depend = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{InstallDependencies});
+        $depend->set_accel_path('<main>/Help/Dependencies');
         $depend->signal_connect ('activate' => sub {
             $self->{parent}->showDependencies;
         });
         $self->{menuHelp}->append($depend);
         my $bug = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuBugReport});
+        $bug->set_accel_path('<main>/Help/Bug');
         $bug->signal_connect('activate' , sub {
             my ($widget, $window) = @_;
             $window->reportBug;
         }, $self->{parent});
         $self->{menuHelp}->append($bug);
-        my $about = Gtk2::ImageMenuItem->new_from_stock('gtk-about',$self->{accel});
+        my $about = Gtk2::ImageMenuItem->new_from_stock('gtk-about');
+        $about->set_accel_path('<main>/Help/gtk-about');
         $about->signal_connect('activate' , sub {
             my ($widget, $window) = @_;
             $window->about;
@@ -790,6 +829,57 @@ use strict;
         $self->{contextUpdating} = 0;
 
         $self->setSaveActive(0);
+
+        $self->{AccelMapFile} = $accelMapFile;
+        if (-f $accelMapFile)
+        {
+            Gtk2::AccelMap->load($accelMapFile);
+        }
+        else
+        {
+            $self->restoreDefaultAccels;
+        }
+        $self->get_settings->set(gtk_can_change_accels => 1);
+
+        return $self;
+        
+    }
+
+    sub save
+    {
+        my $self = shift;
+        Gtk2::AccelMap->save($self->{AccelMapFile});
+    }
+
+    sub restoreDefaultAccels
+    {
+        my $self = shift;
+
+        Gtk2::AccelMap->foreach(undef, sub {
+            my ($path, $key, $modifier, $changed) = @_;
+            if ($path =~ m|(gtk-.*?)$|)
+            {
+                my $stockItem = Gtk2::Stock->lookup($1);
+                Gtk2::AccelMap->change_entry($path,
+                                             $stockItem->{keyval},
+                                             $stockItem->{modifier},
+                                             1);
+            }
+            else
+            {
+                Gtk2::AccelMap->change_entry($path,
+                                             undef,
+                                             [],
+                                             1);
+            }
+        });
+
+        Gtk2::AccelMap->change_entry('<main>/Bookmarks/Add',
+                                     ord('d'),
+                                     'control-mask',
+                                     1);
+        
+
         return $self;
     }
 
@@ -883,32 +973,6 @@ use strict;
         return $self;
     }
     
-#    sub setShowFieldsSelection
-#    {
-#        my ($self, $value) = @_;
-#        if ($value != $self->{showFieldsSelection})
-#        {
-#            if ($value)
-#            {
-#                print "HEre\n";
-#                $self->append_widget($self->{groupLabel}, undef, undef);
-#                $self->append_widget($self->{groupBox}, undef, undef);
-#                $self->{groupOption}->setValues($self->{groupOption}->getValues);
-#                $self->{groupOption}->hide_all;
-#                $self->{groupOption}->show_all;
-#                $self->{groupBox}->show_all;
-#                $self->{groupOption}->popup;
-#                $self->hide_all;
-#            }
-#            else
-#            {
-#                $self->remove($self->{groupLabel});
-#                $self->remove($self->{groupBox});
-#            }
-#        }
-#        $self->{showFieldsSelection} = $value;
-#    }
-    
     sub setShowFieldsSelection
     {
         my ($self, $value) = @_;
@@ -944,11 +1008,11 @@ use strict;
         $self->setGroupField($model->{preferences}->groupBy, 1);
         
         # Hide tonight button if needed
-        $self->{tonight}->show_all;
+        $self->{tonight}->show;
         $self->{tonight}->hide if !$model->hasRandom;
         
         # Hide play button if needed
-        $self->{play}->show_all;
+        $self->{play}->show;
         $self->{play}->hide if !$model->hasPlay;
 
         $self->{blocked} = 0;
@@ -958,10 +1022,24 @@ use strict;
     {
         my ($self, $field, $force) = @_;
         my $i = 0;
-        return if ($self->{currentGroupField} eq $field) && !$force;
+        return if (defined $self->{currentGroupField}) && ($self->{currentGroupField} eq $field) && !$force;
         $self->{currentGroupField} = $field;
         $self->{groupOption}->setValue($field);
     }
+    
+    sub setSize
+    {
+        my ($self, $size) = @_;
+        
+        if ($size == 3)
+        {
+            $self->unset_icon_size;
+        }
+        else
+        {
+            $self->set_icon_size($size == 1 ? 'small-toolbar' : 'large-toolbar');
+        }
+    }
 }
 
-1;
\ No newline at end of file
+1;
