@@ -38,6 +38,7 @@ our $initDefault = 'DefaultNewItem';
 
     use XML::Simple;
     $XML::Simple::PREFERRED_PARSER='XML::Parser';
+    #$XML::Simple::PREFERRED_PARSER='XML::SAX::Expat';
 
     sub load
     {
@@ -54,10 +55,9 @@ our $initDefault = 'DefaultNewItem';
         my $self = shift;
         my $xs = XML::Simple->new;
         return if ! $self->{xmlString};
-        
         $self->{collection} = $xs->XMLin($self->{xmlString},
                                          ForceArray => ['item', 'values', 'filter', 'panel', 'group', 'field'],
-                                         KeyAttr => {'group' => '',
+                                         KeyAttr => {
                                                      'values' => 'id'
                                                     }
                                         );
@@ -76,6 +76,7 @@ our $initDefault = 'DefaultNewItem';
         $self->{resultsFields} = $self->{collection}->{options}->{fields}->{results}->{field};
         $self->{defaultImage} = $ENV{GCS_SHARE_DIR}.'/logos/'.$self->{options}->{defaults}->{image};
         $self->{random} = $self->{collection}->{random}->{filter};
+
         if (exists $self->{collection}->{lang})
         {
             my $lang = $self->{collection}->{lang};
@@ -84,11 +85,13 @@ our $initDefault = 'DefaultNewItem';
             eval "%tmpLang = %GCLang::".$self->{parent}->{options}->lang."::GCModels::".$lang."::lang";
             $self->{lang} = \%tmpLang;
         }
+        
         $self->loadPreferences;
         #$self->checkMaster;
         $self->addDefaultFields;
         $self->{searchFields} = 0;
         $self->checkLending;
+        $self->checkTags;
         $self->initFields;
         $self->setDefaults;
         $self->initPanels;
@@ -155,11 +158,12 @@ our $initDefault = 'DefaultNewItem';
     
     sub setFields
     {
-        my ($self, $fields, $hasLending) = @_;
+        my ($self, $fields, $hasLending, $hasTags) = @_;
         #Force panel generation
         delete $self->{collection}->{panels}->{panel};
         $self->{collection}->{fields}->{field} = $fields;
         $self->{collection}->{fields}->{lending} = ($hasLending ? 'true' : 'false');
+        $self->{collection}->{fields}->{tags} = ($hasTags ? 'true' : 'false');
         $self->doInitialization;
     }
     
@@ -204,6 +208,16 @@ our $initDefault = 'DefaultNewItem';
             }
             delete $collection->{groups}->{group}->[(scalar @{$collection->{groups}->{group}}) - 1];
         }
+        if ($self->{hasTags})
+        {
+            my @fields = @{$collection->{fields}->{field}};
+            for (my $i = 0; $i <= $#fields; $i++)
+            {
+                delete $collection->{fields}->{field}->[$i]
+                    if $fields[$i]->{group} eq 'tagpanel';
+            }
+            delete $collection->{groups}->{group}->[(scalar @{$collection->{groups}->{group}}) - 1];
+        }
         return $collection;
     }
     
@@ -237,33 +251,28 @@ our $initDefault = 'DefaultNewItem';
         $self->{fieldsInfo}->{$self->{commonFields}->{title}}->{init} = $GCModel::initDefault
             if ! $self->{fieldsInfo}->{$self->{commonFields}->{title}}->{init};
         
-        $self->{model}->{options}->{defaults}->{mastertype} = 'generated'
-            if ! exists $self->{model}->{options}->{defaults}->{mastertype};
-        $self->{model}->{options}->{defaults}->{orderby} = $self->{commonFields}->{title}
-            if ! exists $self->{model}->{options}->{defaults}->{orderby};
-
         $self->{preferences}->groupBy($self->{options}->{defaults}->{groupby})
             if ! $self->{preferences}->exists('groupBy');
-        $self->{preferences}->masterType($self->{options}->{defaults}->{mastertype})
-            if ! $self->{preferences}->exists('masterType');
-        $self->{preferences}->orderBy($self->{options}->{defaults}->{orderby})
-            if ! $self->{preferences}->exists('orderBy');
     }
 
     sub isEmpty
     {
         my $self = shift;
-        
         return (!$self->{fields} || ((scalar @{$self->{fields}}) == 0));
     }
 
     sub isPersonal
     {
         my $self = shift;
-        
         return ($self->{isInline} || $self->{isPersonal});
     }
 
+    sub isInline
+    {
+        my $self = shift;
+        return $self->{isInline};
+    }
+
     sub initFields
     {
         my $self = shift;
@@ -283,7 +292,10 @@ our $initDefault = 'DefaultNewItem';
             $fieldsInfo{$name} = $_;
             $fieldsInfo{$name}->{displayed} = $self->getDisplayedText($fieldsInfo{$name}->{label});
             if (($_->{type} =~ /history/)
-            || (($_->{type} =~ /list/) && ($_->{history} ne 'false')))
+            || (
+                 ($_->{type} =~ /list/)
+              && ((!exists $_->{history}) || ($_->{history} ne 'false'))
+               ))
             {
                 push @fieldsHistory, $name;
                 $fieldsInfo{$name}->{hasHistory} = 1;
@@ -291,12 +303,12 @@ our $initDefault = 'DefaultNewItem';
             elsif ($_->{type} eq 'image')
             {
                 push @fieldsImage, $name;
-                push @managedImages, $name if $_->{imported} eq 'true';
+                push @managedImages, $name if (exists $_->{imported}) && ($_->{imported} eq 'true');
             }
             push @fieldsNotNull, $name
-                if $_->{notnull} eq 'true';
+                if (exists $_->{notnull}) && ($_->{notnull} eq 'true');
             push @fieldsNotFormatted, $name
-                if $_->{type} ne 'formatted';
+                if (!exists $_->{type}) || ($_->{type} ne 'formatted');
         }
         $self->{fieldsNames} = \@fieldsNames;
         $self->{fieldsInfo} = \%fieldsInfo;
@@ -424,6 +436,57 @@ our $initDefault = 'DefaultNewItem';
                                             };
     }
 
+    sub checkTags
+    {
+        my $self = shift;
+        $self->{hasTags} = 0;
+        return if ! ($self->{collection}->{fields}->{tags} eq 'true');
+        $self->{hasTags} = 1;        
+
+        # Add group
+        push @{$self->{groups}}, {
+                                id => 'tagpanel',
+                                label => 'PanelTags'
+                              };
+        # Add tag fields
+        push @{$self->{fields}}, (
+            {
+                value => 'favourite',
+                type => 'yesno',
+                label => 'PanelFavourite',
+                init => '0',
+                group => 'tagpanel',
+                imported => 'false'
+            },
+            {
+                value => 'tags',
+                type => 'single list',
+                label => 'TagsAssigned',
+                init => '',
+                group => 'tagpanel',
+                imported => 'false'
+            },
+        );
+
+        # Add filter
+        push @{$self->{filters}}, (
+            {
+                field => 'tags',
+                comparison => 'contain',
+                quick => 'true',
+                numeric => 'false'
+            },
+            {
+                field => 'favourite',
+                comparison => 'contain',
+                quick => 'true',
+                numeric => 'false'
+            },
+        );
+
+    }
+
+
     sub initPanels
     {
         my $self = shift;
@@ -475,7 +538,7 @@ our $initDefault = 'DefaultNewItem';
         my $infoFrame;
         foreach (@{$fields})
         {
-            next if $_->{id} eq 'lending';
+            next if (($_->{id} eq 'lending') || ($_->{id} eq 'tagpanel'));
             my $tab;
             if ($hasTabs)
             {
@@ -619,6 +682,22 @@ our $initDefault = 'DefaultNewItem';
                       };
             push @{$notebook->{item}}, $tab
         }
+
+        if ($self->{hasTags})
+        {
+            my $tab = {type => 'tab', value => 'tagpanel',
+                       title => 'PanelTags',
+                       item => [
+                         {type => 'line', 
+                          item => [
+                            {type => 'value', for => 'favourite'}
+                          ]
+                         },
+                         {type => 'value', for => 'tags', expand => 'true'}
+                       ]
+                      };
+            push @{$notebook->{item}}, $tab
+        }
         
         push @items, $notebook;
         
@@ -672,7 +751,7 @@ our $initDefault = 'DefaultNewItem';
         foreach (@{$fields})
         {
             $infoTable = 0;
-            next if $_->{id} eq 'lending';
+            next if (($_->{id} eq 'lending') || ($_->{id} eq 'tagpanel'));
             my $container;
             my $inExpander = 0;
             if ($i == 0)
@@ -771,6 +850,17 @@ our $initDefault = 'DefaultNewItem';
             };
             push @items, $lendingExpander;
         }
+        if ($self->{hasTags})
+        {
+            my $tagsExpander = {
+                       type => 'expander',
+                       title => 'PanelTags',
+                       item => [
+                         {type => 'value', for => 'tags', expand => 'true'}
+                       ]
+            };
+            push @items, $tagsExpander;
+        }
         
         $panel->{item} = \@items;
         $self->{collection}->{panels}->{panel}->[1] = $panel;        
@@ -847,6 +937,34 @@ our $initDefault = 'DefaultNewItem';
         }
     }
 
+    sub getDisplayedItems
+    {
+        my ($self, $number) = @_;
+        $number = 'X' if !defined $number;
+        return 'Items' if !exists $self->{lang}->{Items};
+        my $items = $self->{lang}->{Items};
+        if (ref($items) eq 'HASH')
+        {
+            return $items->{$number} if exists $items->{$number};
+            return $items->{X};
+        }
+        elsif (ref($items) eq 'CODE')
+        {
+            # Example of Items definition:
+            #Items => sub {
+            #    my $number = shift;
+            #    return 'Movie' if $number < 2;
+            #    return 'Movies';
+            #},
+
+            return $items->($number);
+        }
+        else
+        {
+            return $items;
+        }
+    }
+
     sub getValues
     {
         my ($self, $id) = @_;
@@ -1002,12 +1120,13 @@ our $initDefault = 'DefaultNewItem';
 
     sub new
     {
-        my ($proto, $parent, $file) = @_;
+        my ($proto, $parent, $file, $isPersonal) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = {parent => $parent};
+        my $self  = {parent => $parent, isPersonal => $isPersonal};
         bless $self, $class;
         $self->{isInline} = 0;
         $self->load($file);
+        GCPlugins::loadPlugins($self->getName) if !$isPersonal && !$ENV{GCS_PROFILING};
         return $self;
     }
 
@@ -1031,7 +1150,7 @@ our $initDefault = 'DefaultNewItem';
         my $self  = {parent => $parent};
         bless $self, $class;
         $self->{isInline} = 1;
-        $self->{xmlString} = '<collection><options/><groups/><fields lending="false"/></collection>';
+        $self->{xmlString} = '<collection><options/><groups/><fields lending="false" tags="false"/></collection>';
         $self->{preferences} = GCOptionLoader->newFromXmlString('');
         $self->loadFromString;
         return $self;
@@ -1050,7 +1169,7 @@ our $initDefault = 'DefaultNewItem';
 
     use File::Basename;
     use GCUtils 'glob';
-    
+
     sub new
     {
         my ($proto, $parent) = @_;
@@ -1059,17 +1178,18 @@ our $initDefault = 'DefaultNewItem';
         my $self  = {
             parent => $parent,
             cache => {},
+            lang => $parent->{lang},
             persoDirectory => $ENV{GCS_DATA_HOME}.'/GCModels/',
             defaultDirectory => $ENV{GCS_LIB_DIR}.'/GCModels/',
             modelsSuffix => $GCModel::modelsSuffix
         };
-        
+
         $self->{modelsDirectories} = [$self->{persoDirectory}, $self->{defaultDirectory}],
-        
+
         bless $self, $class;
         return $self;
     }
-    
+
     sub getModel
     {
         my ($self, $name) = @_;
@@ -1085,8 +1205,10 @@ our $initDefault = 'DefaultNewItem';
                 $file .= $self->{modelsSuffix}
                     if $file !~ /$self->{modelsSuffix}$/;
                 next if ! -e $file;
-                $self->{cache}->{$cacheId} = GCModelLoader->new($self->{parent}, $file);
-                $self->{cache}->{$cacheId}->{isPersonal} = 1 if $dir eq $self->{persoDirectory};
+                $self->{cache}->{$cacheId} = GCModelLoader->new($self->{parent},
+                                                                $file,
+                                                                ($dir eq $self->{persoDirectory}));
+                #$self->{cache}->{$cacheId}->{isPersonal} = 1 if $dir eq $self->{persoDirectory};
             }
         }
         return $self->{cache}->{$cacheId};
@@ -1160,13 +1282,49 @@ our $initDefault = 'DefaultNewItem';
 
         foreach (glob $self->{defaultDirectory}.'*'.$self->{modelsSuffix})
         {
-            my $model = $self->getModel(basename($_));
-            push @results, {name => $model->getName,
-                            description => $model->getDescription};
+            #my $model = $self->getModel(basename($_));
+            #push @results, {name => $model->getName,
+            #                description => $model->getDescription};
+            push @results, $self->extractInfos($_);
         }
         @results = sort {$a->{description} cmp $b->{description}} @results;
         return \@results;
     }
+    
+    sub extractInfos
+    {
+        my ($self, $file) = @_;
+        my $result;
+        
+        open FILE, $file;
+        my $lang;
+        while (<FILE>)
+        {
+            $result->{name} = $1
+                if /name="(.*?)"/;
+            if (m|<lang>(.*?)</lang>|)
+            {
+                $lang = $1;
+                last;
+            }
+        }
+        close FILE;
+
+        open LANG, $ENV{GCS_LIB_DIR}.'/GCLang/'.$self->{parent}->{options}->lang."/GCModels/$lang.pm";
+        binmode(LANG, ':utf8');
+        while (<LANG>)
+        {
+            if (/CollectionDescription\s*=>\s*'(.*?)'/)
+            {
+                $result->{description} = $1;
+                last;
+            }
+            
+        }
+        close LANG;
+
+        return $result;
+    }
 }
 
 use Gtk2;
@@ -1174,6 +1332,7 @@ use Gtk2;
 {
     package GCModelsDialog;
 
+    use GCImport;
     use base "GCModalDialog";
 
     sub show
@@ -1220,9 +1379,20 @@ use Gtk2;
                         $self->{modelsList}->grab_focus;
                         next;
                     }
-                    my $name = ((($indices[0] == 1) && (scalar @{$self->{persoList}})) ? 
-                        $self->{persoList}->[$indices[1]]->{name} : $self->{defaultList}->[$indices[1]]->{name});
-                    $self->{model} = $self->{factory}->getModel($name);
+                    my $hasPerso = scalar @{$self->{persoList}};
+                    if ((($indices[0] == 2) && !$hasPerso)
+                      || ($indices[0] == 3))
+                    {
+                        # Here we are importing
+                        $self->{model} = 0;
+                        $self->{importer} = $self->{importers}->[$indices[1]];
+                    }
+                    else
+                    {
+                        my $name = ((($indices[0] == 1) && ($hasPerso)) ? 
+                           $self->{persoList}->[$indices[1]]->{name} : $self->{defaultList}->[$indices[1]]->{name});
+                        $self->{model} = $self->{factory}->getModel($name);
+                    }
                 }
             }
             last;
@@ -1233,7 +1403,7 @@ use Gtk2;
 
     sub new
     {
-        my ($proto, $parent, $factory) = @_;
+        my ($proto, $parent, $factory, $init) = @_;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new($parent, $parent->{lang}->{ModelsSelect});
         
@@ -1260,18 +1430,30 @@ use Gtk2;
         $self->vbox->pack_start($scrollPanelList, 1, 1, 10);
         
         $self->{factory} = $factory;
+        $self->{initVersion} = $init;
         $self->set_default_size(300,350);
         
         return $self;
     }
 
+    sub isImporting
+    {
+        my $self = shift;
+        return $self->{model} == 0;
+    }
+
     sub getModel
     {
         my $self = shift;
-
         return $self->{model};
     }
 
+    sub getImporter
+    {
+        my $self = shift;
+        return $self->{importer};
+    }
+
     sub setModelsList
     {
         my $self = shift;
@@ -1301,8 +1483,28 @@ use Gtk2;
         }
         $self->{modelsList}->expand_row($self->{modelsModel}->get_path($defaultIter), 0);
         $self->{modelsList}->get_selection->select_iter($self->{modelsModel}->get_iter_first);
+
+        $self->addImport if $self->{initVersion};
+
         $self->{modelsList}->grab_focus;
     }
+
+    sub addImport
+    {
+        my $self = shift;
+        my $importIter = $self->{modelsModel}->append(undef);
+        (my $label = $self->{parent}->{lang}->{MenuImport}) =~ s/_//g;
+        $self->{modelsModel}->set($importIter, (0 => $label));
+        $self->{importers} = [];
+        my $iter;
+        foreach my $importer(@GCImport::importersArray)
+        {
+            next if scalar @{$importer->getModels} == 0;
+            push @{$self->{importers}}, $importer;
+            $iter = $self->{modelsModel}->append($importIter);
+            $self->{modelsModel}->set($iter, (0 => $importer->getName));
+        }        
+    }
 }
 
 
@@ -1331,8 +1533,8 @@ use Gtk2;
 
     sub initFields
     {
-        my ($self, $fields, $groups, $commonFields, $withLending) = @_;
-        
+        my ($self, $fields, $groups, $commonFields, $withLending, $withTags) = @_;
+
         # A clone was already made by caller
         #$self->{fields} = Storable::dclone($fields) if $fields;
         $self->{fields} = $fields;
@@ -1378,6 +1580,7 @@ use Gtk2;
         }
         $self->initCommonFields($commonFields);
         $self->{hasLending}->setValue($withLending);
+        $self->{hasTags}->setValue($withTags);
     }
 
     sub convertFormat
@@ -1780,10 +1983,17 @@ use Gtk2;
     sub hasLending
     {
         my $self = shift;
-        
+
         return $self->{hasLending}->getValue;
     }
 
+    sub hasTags
+    {
+        my $self = shift;
+
+        return $self->{hasTags}->getValue;
+    }
+
     sub checkFieldType
     {
         my $self = shift;
@@ -2034,13 +2244,17 @@ use Gtk2;
         
         my $hboxFields = new Gtk2::HBox(0,0);
         $hboxFields->set_border_width($GCUtils::margin);
-        $hboxFields->pack_start($vboxFieldsList, 0, 0, 0);
+        $self->{fieldsPane} = new Gtk2::HPaned;
+        $self->{fieldsPane}->signal_connect('size-allocate' => sub {
+            $self->{scrollPanelFilters}->set_size_request($self->{scrollPanelFields}->allocation->width, -1);
+        });
+        $hboxFields->pack_start($vboxFieldsList, 1, 1, 0);
         $hboxFields->pack_start($vboxMove, 0, 0, $GCUtils::halfMargin);
-        $hboxFields->pack_start($self->{fieldsOptionsTable}, 1, 1, $GCUtils::halfMargin);
-        $vboxFields->pack_start($hboxFields, 1, 1, 0);
+        $self->{fieldsPane}->pack1($hboxFields,1,0);
+        $self->{fieldsPane}->pack2($self->{fieldsOptionsTable},1,0);
+        $vboxFields->pack_start($self->{fieldsPane}, 1, 1, 0);
 
-
-        my $optionsTable = new Gtk2::Table(8, 4);
+        my $optionsTable = new Gtk2::Table(9, 4);
         $optionsTable->set_row_spacings($GCUtils::halfMargin);
         $optionsTable->set_col_spacings($GCUtils::margin);
         $optionsTable->set_border_width($GCUtils::margin);
@@ -2056,6 +2270,9 @@ use Gtk2;
         $self->{hasLending} = new GCCheckBox($parent->{lang}->{ModelCollectionSettingsLending});
         $self->{tooltips}->set_tip($self->{hasLending},
                                    $parent->{lang}->{ModelTooltipLending});
+        $self->{hasTags} = new GCCheckBox($parent->{lang}->{ModelCollectionSettingsTagging});
+        $self->{tooltips}->set_tip($self->{hasTags},
+                                   $parent->{lang}->{ModelTooltipTagging});
 
         my $commonFieldsLabel = new GCHeaderLabel($parent->{lang}->{ModelOptionsFields});
         $optionsTable->attach($commonFieldsLabel, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
@@ -2070,6 +2287,7 @@ use Gtk2;
         my $collectionSettingsLabel = new GCHeaderLabel($parent->{lang}->{ModelCollectionSettings});
         $optionsTable->attach($collectionSettingsLabel, 0, 4, 6, 7, 'fill', 'fill', 0, 0);
         $optionsTable->attach($self->{hasLending}, 2, 4, 7, 8, ['expand', 'fill'], 'fill', 0, 0);
+        $optionsTable->attach($self->{hasTags}, 2, 4, 8, 9, ['expand', 'fill'], 'fill', 0, 0);
 
         $vboxOptions->pack_start($optionsTable, 1, 1, 0);
 
@@ -2096,10 +2314,6 @@ use Gtk2;
         $self->{scrollPanelFilters}->set_shadow_type('etched-in');
         $self->{scrollPanelFilters}->add($self->{filtersList});
 
-        $self->signal_connect('size-allocate' => sub {
-            $self->{scrollPanelFilters}->set_size_request($self->{scrollPanelFields}->allocation->width, -1);
-        });
-
         $self->{filter}->{activated} = GCCheckBox->new($parent->{lang}->{ModelFilterActivated});
         $self->{filter}->{activated}->signal_connect('toggled' => sub {
             $self->checkFilterActivated;
@@ -2129,8 +2343,6 @@ use Gtk2;
         $hboxFilters->pack_start($self->{scrollPanelFilters}, 0, 0, 0);
         $hboxFilters->pack_start($self->{filtersOptionsTable}, 1, 1, $GCUtils::halfMargin);
         $vboxFilters->pack_start($hboxFilters,1,1,0);
-        
-
 
         $notebook->append_page($vboxFields, $parent->{lang}->{ModelFields});
         $notebook->append_page($vboxOptions, $parent->{lang}->{ModelOptions});
@@ -2138,6 +2350,7 @@ use Gtk2;
 
         $self->vbox->pack_start($hboxCollectionName, 0, 0, $GCUtils::margin);
         $self->vbox->pack_start($notebook, 1, 1, 0);
+        $self->vbox->show_all;
 
         $self->setSensitive(0);
 
