@@ -45,6 +45,8 @@ use strict;
         $self->{previouslyHidden} = 0;
 
         $self->{expanders} = [];
+        $self->{dateFields} = [];
+        $self->{longTextFields} = [];
         $self->{formatted} = [];
         #Stores for each fields the widgets which depends on it
         # (used for formatted and launcher)
@@ -82,7 +84,34 @@ use strict;
     {
         my ($self, $style) = @_;
     }    
-    
+
+
+    sub setExpandersMode
+    {
+        my ($self, $mode) = @_;
+        $_->setMode($mode)
+            foreach (@{$self->{expanders}});
+    }
+
+    sub setDateFormat
+    {
+        my ($self, $format) = @_;
+        foreach (@{$self->{dateFields}})
+        {
+            $_->setFormat($format);
+            $_->resetChanged;
+        }
+    }
+
+    sub setSpellChecking
+    {
+        my ($self, $activate) = @_;
+        foreach (@{$self->{longTextFields}})
+        {
+            $_->setSpellChecking($activate);
+        }
+    }
+
     sub createContent
     {
         my ($self, $model) = @_;
@@ -159,7 +188,13 @@ use strict;
             {
                 if ($show->{$_})
                 {
-                    $parentsToHide{$widget->{realParent}} = 0;
+                    #$parentsToHide{$widget->{realParent}} = 0;
+                    my $parent = $widget->{realParent};
+                    while ($parent)
+                    {
+                        $parentsToHide{$parent} = 0;
+                        $parent = $parent->{realParent};
+                    }
                     foreach my $dependency(@{$self->{dependencies}->{$_}})
                     {
                         $parentsToHide{$dependency->{realParent}} = 0;
@@ -184,7 +219,7 @@ use strict;
                 $parentsToHide{$_}->hide;
                 $parentsToHide{$_}->{realParent}->hide
                     if ($parentsToHide{$_}->{realParent})
-                    && ($parentsToHide{$_}->{realParent}->isa('Gtk2::Expander'));
+                    && ($parentsToHide{$_}->{realParent}->isa('GCExpander'));
             }
         }
         
@@ -199,7 +234,6 @@ use strict;
     sub hide
     {
         my ($self, $filtering) = @_;
-        
         $self->{infoBox}->show_all;
         if ($filtering)
         {
@@ -281,6 +315,13 @@ use strict;
         $widget->set_alignment(0, 0.5);
         return $widget;
     }
+
+    sub createExpander
+    {
+        my ($self, $label) = @_;
+
+        return new GCExpander($label);
+    }
     
     sub formatLabel
     {
@@ -298,12 +339,14 @@ use strict;
         if ($expander->{collapsedTemplate}
         && ($expander->get_expanded xor $init))
         {
-            $expander->set_label($expander->{originalLabel}.$self->{parent}->{lang}->{Separator}.
-                                 $self->formatLabel($expander->{collapsedTemplate}));
+            #$expander->setValue($expander->{originalLabel}.$self->{parent}->{lang}->{Separator}.
+            #                    $self->formatLabel($expander->{collapsedTemplate}));
+            $expander->setValue($expander->{originalLabel}.$self->{parent}->{lang}->{Separator},
+                                $self->formatLabel($expander->{collapsedTemplate}));
         }
         else
         {
-            $expander->set_label($expander->{originalLabel});
+            $expander->setValue($expander->{originalLabel});
         }
     }
     
@@ -333,6 +376,7 @@ use strict;
     sub addToContainer
     {
         my ($self, $container, $widget, $info) = @_;
+        $info->{expand} = 'default' if !exists $info->{expand};
         if ($container->isa('Gtk2::Notebook'))
         {
             $container->append_page($widget,
@@ -345,7 +389,7 @@ use strict;
             my $top = $info->{row};
             my $bottom = $top + ($info->{rowspan} ? $info->{rowspan} : 1);
             my $fill = [];
-            push @$fill, 'fill' if ! ($info->{expand} eq 'false');
+            push @$fill, 'fill' if $info->{expand} ne 'false';
             push @$fill, 'expand' if $info->{expand} eq 'true';
             if ($info->{expand} eq 'shrink')
             {
@@ -375,8 +419,8 @@ use strict;
             if ($container->isa('Gtk2::VBox'))
             {
                 my $margin = $self->{halfMargin};
-                $margin = 0 if $info->{nomargin} eq 'true';
-                if ($info->{place} eq 'end')
+                $margin = 0 if (exists $info->{nomargin}) && ($info->{nomargin} eq 'true');
+                if ((exists $info->{place}) && ($info->{place} eq 'end'))
                 {
                     $container->pack_end($widget, $expand, $expand, $margin);
                 }
@@ -418,6 +462,9 @@ use strict;
             my $box;
             my $isContainer = 0;
 
+            # TODO We should return an error here
+            $_->{type} = 'default' if ! exists $_->{type};
+
             if ($_->{type} eq 'formatted')
             {
                 my $info = {};
@@ -433,7 +480,7 @@ use strict;
                 $widget = $self->getWidget($_->{for}, $_);
                 $widget->setWidth($_->{width}) if $_->{width};
                 $widget->setHeight($_->{height}) if $_->{height};
-                $widget->expand if $_->{expand} eq 'true';
+                $widget->expand if (exists $_->{expand}) && ($_->{expand} eq 'true');
                 if ($_->{values} || $self->{model}->{fieldsInfo}->{$_->{for}}->{values})
                 {
                     $self->{displayedValues}->{$_->{for}} = 
@@ -451,7 +498,7 @@ use strict;
                 {
                     $widget = $self->createLabel($_, $self->{withSeparator});
                 }
-                if ($_->{align} eq 'center')
+                if ((exists $_->{align}) && ($_->{align} eq 'center'))
                 {
                     $widget->set_alignment(0.5, 0.5);
                     if ($self->{withSeparator})
@@ -462,7 +509,7 @@ use strict;
                         $widget->set_label($label);
                     }
                 }
-                $widget->set_alignment(0, 0) if $_->{align} eq 'top';
+                $widget->set_alignment(0, 0) if (exists $_->{align}) && ($_->{align} eq 'top');
             }
             elsif ($_->{type} eq 'special')
             {
@@ -567,18 +614,22 @@ use strict;
             }
             elsif ($_->{type} eq 'expander')
             {
-                $widget = new Gtk2::Expander($self->{model}->getDisplayedText($_->{title}));
+                #$widget = new GCExpander($self->{model}->getDisplayedText($_->{title}));
+                $widget = $self->createExpander($self->{model}->getDisplayedText($_->{title}));
+                $widget->setMode($self->{parent}->{options}->expandersMode);
                 $widget->{originalLabel} = $self->{model}->getDisplayedText($_->{title});
                 $widget->{collapsedTemplate} = $_->{collapsed};
                 $self->setExpanderLabel($widget, 1);
                 $widget->signal_connect('activate' => sub {
                     $self->setExpanderLabel($widget, 0);
                 });
+                $widget->set_expanded(1) if (defined $_->{expanded}) && ($_->{expanded} eq 'true');
                 push @{$self->{expanders}}, $widget;
                 $box = new Gtk2::VBox(0,0);
                 $box->set_border_width($self->{halfMargin});
                 $widget->add($box);
                 $isContainer = 1;
+                $_->{style} = 'expander' if !exists $_->{style};
             }
             
             if (exists $_->{border})
@@ -670,7 +721,7 @@ use strict;
             m/^(.*?)\s*=\s*(.*)$/;
             my $item = $1;
             (my $value = $2) =~ s/^"(.*?)"$/$1/;
-            $item =~ /(.*?)(Bg|Color|Style|Justify)/;
+            $item =~ /(.*?)(Bg|Color|Style|Justify|Arrow|Prelight)/;
             my $comp = $1;
             my $style = lc $2;
             $self->{styles}->{$comp}->{$style} = $value;
@@ -686,9 +737,9 @@ use strict;
     }
     
     sub deactivate
-	{
+    {
         my $self = shift;
-	}
+    }
 
     sub getValues
     {
@@ -740,6 +791,15 @@ use strict;
         return $widget;
     }
     
+    sub createExpander
+    {
+        my ($self, $label) = @_;
+
+        return new GCColorExpander($label,
+                                   $self->{styles}->{expander}->{bgColor},
+                                   $self->{styles}->{expander}->{style});
+    }
+
     sub setWidgetStyle
     {
         my ($self, $widget, $name, $style) = @_;
@@ -754,6 +814,25 @@ use strict;
             my $justify = $self->{styles}->{$style}->{justify};
             $widget->set_justify($justify) if $justify;
         }
+        
+        if ($widget->isa('GCColorExpander'))
+        {
+            my $arrowColor = Gtk2::Gdk::Color->parse($self->{styles}->{expander}->{arrow});
+            my $prelightColor;
+            if (exists $self->{styles}->{expander}->{prelight})
+            {
+                $prelightColor = Gtk2::Gdk::Color->parse($self->{styles}->{expander}->{prelight});
+            }
+            else
+            {
+                $prelightColor = $self->{styles}->{expander}->{bgColor};
+            }
+            
+            $widget->modify_bg('prelight', $prelightColor);
+            $widget->get_label_widget->modify_bg('prelight', $prelightColor);
+            $widget->modify_fg('normal', $arrowColor);
+            $widget->modify_fg('prelight', $arrowColor);
+        }
     }
     
     sub createItem
@@ -819,7 +898,7 @@ use strict;
         my ($self, $field, $info) = @_;
 
         my $widget = $self->{$field};
-        if ($widget->isa('GCColorLabel') && $info->{height})
+        if ($info->{height} && $widget->isa('GCColorLabel'))
         {
             my $style = $info->{style};
             $style = 'field' if !$style;
@@ -828,17 +907,24 @@ use strict;
             $widget->{name} = $self->{$field}->{name};
             $self->{$field} = $widget;
         }
-        if ($widget->isa('GCColorTable') && ($info->{flat} eq 'true'))
+        elsif ($widget->isa('GCColorTable') && ($info->{flat} eq 'true'))
         {
             my $columns = $widget->{number};
             $widget->destroy;
             $self->{prepare}->{$field}->{func} = 'prepareMultipleList';
             $self->{prepare}->{$field}->{extra} = $columns;
-            $widget = new GCColorLabel($self->{styles}->{field}->{bgColor}, $columns);
+            if ($info->{height})
+            {
+                $widget = new GCColorText($self->{styles}->{field}->{bgColor}, 0, $columns);
+            }
+            else
+            {
+                $widget = new GCColorLabel($self->{styles}->{field}->{bgColor}, $columns);
+                $widget->set_selectable(0);
+                $widget->set_padding(5,5);
+                $widget->set_justify('fill');
+            }
             $self->{style}->{$field} = 'field';
-            $widget->set_selectable(0);
-            $widget->set_padding(5,5);
-            $widget->set_justify('fill');
             $self->{$field} = $widget;
         }
 
@@ -887,12 +973,13 @@ use strict;
                 {
                     $self->{$name}->setMarkup("<span ".
                                               $self->{styles}->{$self->{style}->{$name}}->{style}.
-                                              ">".$text.'</span>');
+                                              ">".$self->{$name}->cleanMarkup($text).'</span>');
                 }
                 else
                 {
                     $self->{$name}->setValue($text);
                 }
+                #$self->{$name}->resetChanged;
             }
         };
         goto &{$AUTOLOAD};
@@ -947,6 +1034,7 @@ use strict;
         bless ($self, $class);
 
         $self->{withSeparator} = 1;
+        $self->{locked} = 0;
         $self->{colSpacing} = $self->{margin};
         $self->{rowSpacing} = $self->{halfMargin};
 
@@ -1020,7 +1108,7 @@ use strict;
             $self->{$borrowerField}->setValue('none');
             $self->{$lendDateField}->clear;
             my $new = $self->getAsHash;
-            $self->{parent}->{itemsList}->changeCurrent($previous, $new)
+            $self->{parent}->{itemsView}->changeCurrent($previous, $new, $self->{parent}->{items}->getCurrent, 1)
                 if $self->$coverField;
         }
         $self->showMe;
@@ -1033,18 +1121,17 @@ use strict;
     }
     
     sub deactivate
-	{
+    {
         my $self = shift;
-		$self->changeState($self,1);
-	}
+        $self->changeState($self,1);
+    }
 
-	sub changeState
+    sub changeState
     {
         my ($caller, $self, $locked)  = @_;
         $locked = 1 if $self->{parent}->{items}->getLock;
         return if $self->{locked} == $locked;
         $self->{locked} = $locked;
-
         foreach (@{$self->{parent}->{model}->{fieldsNames}})
         {
             $self->{$_}->lock($locked) if ($self->{$_});
@@ -1128,6 +1215,8 @@ use strict;
         elsif ($info->{type} eq 'long text')
         {
             $widget = new GCLongText;
+            $widget->setSpellChecking($self->{parent}->{options}->spellCheck);
+            push @{$self->{longTextFields}}, $widget;
         }
         elsif ($info->{type} eq 'history text')
         {
@@ -1159,7 +1248,7 @@ use strict;
             my $withHistory = 1;
             my @labels;
             $withHistory = 0
-                if $info->{history} eq 'false';
+                if (exists $info->{history}) && ($info->{history} eq 'false');
             $readonly = 1
                 if $info->{value} eq $self->{model}->{commonFields}->{borrower}->{history};
             $number = GCUtils::listNameToNumber($info->{type});
@@ -1195,6 +1284,8 @@ use strict;
             else
             {
                 $widget = new GCCheckedText('0-9.');
+                $widget->setReadOnly
+                    if ($info->{value} eq $self->{model}->{commonFields}->{id});
             }
             $widget->signal_connect('activate', sub {
                 $self->searchItem;
@@ -1206,6 +1297,7 @@ use strict;
                                       $self->{model}->{defaultImage});
             my $isCover = 0;
             $isCover = 1 if $info->{value} eq $self->{model}->{commonFields}->{cover};
+            #$img->setImmediate if $isCover;
             $widget = new GCImageButton($self, $img, $isCover, $info->{default});
         }
         elsif ($info->{type} eq 'button')
@@ -1235,6 +1327,9 @@ use strict;
         elsif ($info->{type} eq 'date')
         {
             $widget = new GCDate($self, $self->{lang});
+            $widget->setFormat($self->{parent}->{options}->dateFormat)
+                if $self->{parent}->{options}->dateFormat;
+            push @{$self->{dateFields}}, $widget;
         }
         elsif ($info->{type} eq 'formatted')
         {
@@ -1250,7 +1345,7 @@ use strict;
         
          $self->{tooltips}->set_tip($widget, $self->{model}->getDisplayedText($info->{tip}), '')
             if $info->{tip};
-        
+        $widget->activateStateTracking;
         return $widget;
     }
     
@@ -1271,7 +1366,8 @@ use strict;
             return 0 if !$self->{$name};
             return $self->{$name}->getValue
                 if !(scalar @_);
-            ($self->{$name}->setValue(shift), return);
+            $self->{$name}->setValue(shift);
+            #$self->{$name}->resetChanged;
         };
         goto &{$AUTOLOAD};
     }
