@@ -35,25 +35,34 @@ our %pluginsMap;
 our %pluginsNameArrays;
 
 sub loadPlugins
+{
+    my $model = shift;
+    return if $pluginsNameArrays{$model};
+    my $dir = $ENV{GCS_LIB_DIR}.'/GCPlugins/'.$model;
+    foreach (glob "$dir/*.pm")
+    {
+        my $plugin = basename($_, '.pm')."\n";
+        next if $plugin =~ /Common/;
+        eval "use GCPlugins::".$model."::$plugin";
+        (my $class = $plugin) =~ s/^GC/GCPlugin/;
+        my $obj;
+        eval "\$obj = new GCPlugins::".$model."::$class";
+        die "Fatal error with plugin $plugin : $@" if $@;
+        $pluginsMap{$model}->{$obj->getName} = $obj;
+    }
+    my @names = sort keys %{$pluginsMap{$model}};
+    $pluginsNameArrays{$model} = \@names;
+    
+}
+
+sub loadAllPlugins
 {
     foreach my $dir(glob $ENV{GCS_LIB_DIR}.'/GCPlugins/*')
     {
         next if $dir =~ /PluginsBase/;
         my $model = basename($dir);
         next if ($model !~ /^GC/) || ($model eq 'GCstar');
-        foreach (glob "$dir/*.pm")
-        {
-            my $plugin = basename($_, '.pm')."\n";
-            next if $plugin =~ /Common/;
-            eval "use GCPlugins::".$model."::$plugin";
-            (my $class = $plugin) =~ s/^GC/GCPlugin/;
-            my $obj;
-            eval "\$obj = new GCPlugins::".$model."::$class";
-            die "Fatal error with plugin $plugin : $@" if $@;
-            $pluginsMap{$model}->{$obj->getName} = $obj;
-        }
-        my @names = sort keys %{$pluginsMap{$model}};
-        $pluginsNameArrays{$model} = \@names;
+        loadPlugins($model);
     }
 }
     
@@ -72,8 +81,8 @@ sub loadPlugins
             my $self  = {command => $command, data => $data};
             $command->autoflush(1);
             $data->autoflush(1);
-            GCPlugins::loadPlugins;
-                        
+            #GCPlugins::loadPlugins if ! $ENV{GCS_PROFILING};
+
             bless ($self, $class);
             return $self;
         }
@@ -81,7 +90,6 @@ sub loadPlugins
         sub run
         {
             my $self = shift;
-            
             my $command = $self->{command};
             while (1)
             {
@@ -90,11 +98,20 @@ sub loadPlugins
             }
         }
         
+        sub quit
+        {
+            my $self = shift;
+            close $self->{command};
+            close $self->{data};
+            wait;
+            exit;
+        }
+        
         sub beginSearch
         {
             my ($self, $info) = @_;
-            
             my $pid;
+            GCPlugins::loadPlugins($info->{model}) if $info->{model};
             if ($pid = fork)
             {
                 my $command = $self->{command};
@@ -102,6 +119,7 @@ sub loadPlugins
                 my $cmd = readline($command);
                 chomp $cmd;
                 kill 9,$pid if ($cmd eq 'STOP');
+                $self->quit if $cmd eq 'EXIT';
                 wait;
             }
             else
@@ -111,7 +129,8 @@ sub loadPlugins
                 {
                     # Here we create the plugin
                     my $plugin = $pluginsMap{$info->{model}}->{$info->{name}};
-                    $plugin->setProxy($info->{proxy});        
+                    $plugin->setProxy($info->{proxy});
+                    $plugin->setCookieJar($info->{cookieJar});
                     $plugin->{type} = $info->{type};
                     $plugin->{urlField} = $info->{urlField};
 
@@ -122,7 +141,7 @@ sub loadPlugins
                     $plugin->load;
                     store_fd $plugin, $self->{data};
                 }
-                else
+                elsif ($info->{type} ne 'exit')
                 {
                     # Here we re-use it
                     my $plugin = $info;
@@ -156,7 +175,7 @@ sub loadPlugins
             {
                 my $pluginName = '';
                 my $idx = ($self->{pluginsList}->get_selected_indices)[0];
-                $pluginName = $self->{pluginsList}->{data}->[$idx]->[0 + $self->{withPics}];
+                $pluginName = $self->{pluginsList}->{data}->[$idx]->[0];
 
                 $self->{plugin} = $self->{model}->getPlugin($pluginName);
 
@@ -181,7 +200,6 @@ sub loadPlugins
                 bless ($self, $class);
     
             $self->{parent} = $parent;
-            $self->{withPics} = $parent->{hasPluginsPictures};
 
             $self->{titleGroup} = new GCGroup($parent->{lang}->{PluginsQuery});
             my $queryHbox = new Gtk2::HBox(0,0);
@@ -200,21 +218,10 @@ sub loadPlugins
             my $pluginGroup = undef;
             my $pluginsFrame = new GCGroup($parent->{lang}->{PluginsFrame});
              
-            if ($self->{withPics})
-            {
-                $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsLogo} => "pixbuf",
-                                                            $parent->{lang}->{PluginsName} => "text",
-                                                            $parent->{lang}->{PluginsLang} => "text",
-                                                            $parent->{lang}->{PluginsSearchFields} => "text",
-                                                            $parent->{lang}->{PluginsAuthor} => "text",);
-            }
-            else
-            {
-                $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsName} => "text",
-                                                            $parent->{lang}->{PluginsLang} => "text",
-                                                            $parent->{lang}->{PluginsSearchFields} => "text",
-                                                            $parent->{lang}->{PluginsAuthor} => "text",);
-            }
+            $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsName} => "text",
+                                                        $parent->{lang}->{PluginsLang} => "text",
+                                                        $parent->{lang}->{PluginsSearchFields} => "text",
+                                                        $parent->{lang}->{PluginsAuthor} => "text",);
             $self->{pluginsList}->set_border_width(5);
             $self->{pluginsList}->set_rules_hint(1);
             $self->{pluginsList}->get_column(0)->set_min_width(150);
@@ -256,8 +263,18 @@ sub loadPlugins
             my $self = shift;
             if (@_)
             {
-               $self->{query}->setValue(shift);
-               $self->{fieldsList}->setValue(shift);
+               my ($query, $field, $queries) = @_;
+               $self->{fieldsList}->setValue($field);
+               $self->{query}->setValue($query);
+               $self->{queries} = $queries;
+               $self->{fieldsList}->signal_connect('changed' => sub {
+                   $self->{query}->setValue(
+                       $self->{queries}->{
+                           $self->{fieldsList}->getValue
+                       }
+                   );
+               });
+               #$self->{fieldsList}->setDefaultValues(shift);
                #$self->{searchField} = shift;
             }
             return ($self->{query}->getValue, $self->{fieldsList}->getValue);
@@ -317,19 +334,8 @@ sub loadPlugins
                     my $plugin = $model->getPlugin($_);
                     if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                     {
-                        if ($self->{withPics})
-                        {
-                            my $picFile = $self->{parent}->{pluginsPicturesDir}.$plugin->getImageFile;
-                            $picFile = $ENV{GCS_SHARE_DIR}.'/icons/gcstar_32x32.png' if ! -f $picFile;
-                               my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
-                               push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
-                        }
-                        else
-                        {
-                               push @newData, [$plugin->getName, "\n".$plugin->getLang."\n",
-                                               $plugin->getSearchFields($model), $plugin->getAuthor];
-                        }
-                           
+                        push @newData, [$plugin->getName, "\n".$plugin->getLang."\n",
+                                        $plugin->getSearchFields($model), $plugin->getAuthor];
                         $i++;
                     }
                 }
@@ -472,18 +478,7 @@ sub loadPlugins
                     my $plugin = $model->getPlugin($_);
                     if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                     {
-                        if ($self->{withPics})
-                        {
-                            my $picFile = $self->{parent}->{pluginsPicturesDir}.$plugin->getImageFile;
-                            $picFile = $ENV{GCS_SHARE_DIR}.'/icons/gcstar_32x32.png' if ! -f $picFile;
-                               my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
-                               push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
-                        }
-                        else
-                        {
-                               push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
-                        }
-                           
+                        push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
                         $i++;
                     }
                 }
@@ -634,8 +629,12 @@ sub loadPlugins
             if ($code eq 'ok')
             {
                 $self->{validated} = 1;
-                my @idx = $self->{results}->get_selected_indices;
-                $self->{itemIndex} = $self->{items}->[$idx[0]]->{'#'};
+                $self->{itemsIndexes} = [];
+                my @idxs = $self->{results}->get_selected_indices;
+                foreach my $idx(@idxs)
+                {
+                    push @{$self->{itemsIndexes}}, $self->{items}->[$idx]->{'#'};
+                }
             }
             elsif ($code eq 'yes')
             {
@@ -650,10 +649,17 @@ sub loadPlugins
         return ($code eq 'no');
     }
 
-    sub getItemIndex
+    sub getItemsIndexes
     {
         my $self = shift;
-        return $self->{itemIndex};
+        return $self->{itemsIndexes};
+    }
+
+    sub setMultipleSelection
+    {
+        my ($self, $activate) = @_;
+        return if !$self->{results};
+        $self->{results}->get_selection->set_mode ($activate ? 'multiple' : 'single');
     }
 
     sub setWithNext
@@ -699,6 +705,7 @@ sub loadPlugins
                                       );
         bless ($self, $class);
 
+        $self->{results} = 0;
         $self->{withExtra} = 0;
         $self->{withNext} = 0;
         $self->{nextButton} = Gtk2::Button->new_from_stock('gtk-go-forward');
@@ -715,18 +722,55 @@ sub loadPlugins
         $self->{scrollPanelList}->set_policy ('never', 'automatic');
         $self->{scrollPanelList}->set_shadow_type('etched-in');
                                             
-        $self->vbox->add($self->{scrollPanelList});
-        
+        $self->vbox->pack_start($self->{scrollPanelList}, 1, 1, 0);
+        $self->vbox->pack_start(Gtk2::HSeparator->new, 0, 0, 0);
+        my $fillBox = new Gtk2::HBox(0,0);
+        my $label = GCLabel->new('<i>'.$parent->{lang}->{ResultsInfo}.'</i>');
+        $label->set_line_wrap(1);
+        $label->set_justify('center');
+        $label->set_padding($GCUtils::margin, 0);
+        $fillBox->pack_start(Gtk2::HBox->new(0,0),1,1,0);
+        $fillBox->pack_start($label, 0, 0, $GCUtils::margin);
+        $fillBox->pack_start(Gtk2::HBox->new(0,0),1,1,0);
+        $self->vbox->pack_start($fillBox, 0 , 0, $GCUtils::margin);
+         
         # To create a tooltip as it is not implemented directly in Gtk2
         $self->{tooltipLabel} = Gtk2::Label->new;
         $self->{tooltipLabel}->set_line_wrap(1);
         $self->{tooltipLabel}->set_padding($GCUtils::margin, $GCUtils::margin);
         $self->{tooltip} = Gtk2::Window->new('popup');
         $self->{tooltip}->set_decorated(0);
+        $self->{tooltip}->set_sensitive(1);
         $self->{tooltip}->modify_fg('normal', Gtk2::Gdk::Color->parse('#000000'));
         $self->{tooltip}->modify_bg('normal', Gtk2::Gdk::Color->parse('#ffffbf'));
         $self->{tooltip}->set_position('mouse');
         $self->{tooltip}->add($self->{tooltipLabel});
+        $self->{tooltip}->signal_connect('button_press_event' => sub {
+            $self->hideTooltip;
+            if ($self->{results})
+            {
+                shift;
+                $self->{results}->signal_emit('button_press_event', @_);
+            }
+        });
+        $self->{tooltip}->signal_connect('motion-notify-event' => sub {
+            my ($widget, $event) = @_;
+            my ($x, $y) = ($event->x_root, $event->y_root);
+            my ($xoffset, $yoffset) = $widget->window->get_root_origin;
+            my $allocation = $widget->allocation();
+            my $x1 = $xoffset + 2 * $allocation->x;
+            my $y1 = $yoffset + 2 * $allocation->y;
+            my $x2 = $x1 + $allocation->width;
+            my $y2 = $y1 + $allocation->height;
+            my $isInWidget = ($x > $x1 && $x < $x2 && $y > $y1 && $y < $y2);
+            
+            return if $isInWidget;
+            if ($self->{results})
+            {
+                shift;
+                $self->{results}->signal_emit('motion-notify-event', @_);
+            }            
+        });
         $self->{tooltipDisplayed} = 0;        
  
         return $self;
@@ -760,7 +804,6 @@ sub loadPlugins
         
         $self->{results} = Gtk2::SimpleList->new(@cols);
         
-        
         $self->{results}->set_rules_hint(1);
         $self->{results}->set_headers_clickable(1);
 
@@ -849,11 +892,13 @@ sub loadPlugins
             $col = 0;
             foreach my $field(@{$self->{fields}})
             {
-                (my $shortField = $item->{$field}) =~ s/(.{40}).*/$1.../;
+                my $value = '';
+                $value = $item->{$field} if exists $item->{$field};
+                (my $shortField = $value) =~ s/(.{40}).*/$1.../;
                 push @$infos, $shortField."\n";
                 # We store a tooltip is the text has been truncated
-                $self->{tooltipsStrings}->{$idx}->{$col} = $item->{$field}
-                    if $item->{$field} ne $shortField;
+                $self->{tooltipsStrings}->{$idx}->{$col} = $value
+                    if $value ne $shortField;
                 $col++;
             }
             $item->{'#'} = $idx if ! exists $item->{'#'};
@@ -863,8 +908,7 @@ sub loadPlugins
         }
         $self->{results}->select(0);
         $self->{results}->columns_autosize;
-        #$self->resize(1,1);
-        $self->set_default_size(200,400);
+        $self->set_default_size(-1,400);
     }
  
  
@@ -875,29 +919,39 @@ sub loadPlugins
         if ($path)
         {
             my $model = $self->{results}->get_model;
-            use Data::Dumper;
-            my $i = $column->{column_number};
+            my $col = $column->{column_number};
             my $row = $path->to_string();
             
             # If a new cell is selected, then hide the tooltip
             # It'll be re-shown as required by the code down under
-            if ($self->{selectedRow} ne $row or $self->{selectedCol} != $i)
+            if ($self->{selectedRow} ne $row or $self->{selectedCol} != $col)
             {
                 $self->hideTooltip;
                 $self->{selectedRow} = $row;
-                $self->{selectedCol} = $i;
+                $self->{selectedCol} = $col;
+            }
+            else
+            {
+                return;
             }
             if ($row ne '')
             {
                 # Pick that popup string from our hash
                 #my $str = $popup_hash->{$row}->{$i};
-                my $str = $self->{tooltipsStrings}->{$row}->{$i};
+                my $str = $self->{tooltipsStrings}->{$row}->{$col};
                 if ($str)
                 {
                     $self->{tooltipLabel}->set_label($str);
                     if (!$self->{tooltipDisplayed})
                     {
                         $self->{tooltip}->show_all;
+                        Gtk2->grab_add($self->{tooltip});
+                        Gtk2::Gdk->pointer_grab(
+                            $self->{tooltip}->window, 1,
+                            [qw/button-press-mask button-release-mask pointer-motion-mask/],
+                            undef, undef, 0);
+                        Gtk2::Gdk->keyboard_grab ($self->{tooltip}->window, 0, 0);
+                        $self->{tooltip}->grab_focus;
                         my ($thisx, $thisy) = $self->{tooltip}->window->get_origin;
                         # The window to be a bit away from the mouse pointer.
                         $self->{tooltip}->move($thisx, $thisy-20);
@@ -914,6 +968,7 @@ sub loadPlugins
         my $self = shift;
         if ($self->{tooltipDisplayed})
         {
+            Gtk2->grab_remove($self->{tooltip});
             $self->{tooltip}->hide;
             $self->{tooltipDisplayed} = 0;
         }
@@ -932,7 +987,8 @@ sub loadPlugins
         my @children = $self->{table}->get_children;
         foreach (@children)
         {
-            $_->set_sensitive(!$value) if $_->get_name eq 'GtkCheckButton';
+            $_->set_sensitive(!$value) if ($_->get_name eq 'GtkCheckButton')
+                                       && (!$_->{mandatory});
         }
         $self->set_title($value ? $self->{parent}->{lang}->{ResultsPreview}
                                 : $self->{parent}->{lang}->{ImportWindowTitle});
@@ -959,7 +1015,6 @@ sub loadPlugins
             my $fieldsInfo = $self->{parent}->{model}->{fieldsInfo};        
             foreach (keys %{$info})
             {
-                next if $_ eq $self->{parent}->{model}->{commonFields}->{url};
                 my $tmp = $info->{$_};
                 if ($fieldsInfo->{$_}->{type} =~ /list/)
                 {
@@ -970,8 +1025,11 @@ sub loadPlugins
                     $tmp = $self->{parent}->{model}->getDisplayedValue($fieldsInfo->{$_}->{values},
                                                                        $tmp);
                 }
-                $tmp =~ s/\n/ /g;
-                $tmp =~ s/(.{50}).*/$1.../m;
+                if ($_ ne $self->{urlField})
+                {
+                    $tmp =~ s/\n/ /g;
+                    $tmp =~ s/(.{50}).*/$1.../m;
+                }
                 $self->{$_}->set_text($tmp)
                     if $self->{$_};
             }
@@ -1010,10 +1068,7 @@ sub loadPlugins
             $self->window->set_cursor(Gtk2::Gdk::Cursor->new('watch'));
             Gtk2->main_iteration while (Gtk2->events_pending);
             (my $tmpFile = tmpnam) .= $suffix;
-            my $browser = LWP::UserAgent->new;
-            $browser->proxy(['http'], $self->{parent}->{options}->proxy);
-            $browser->agent($self->{parent}->{agent});
-            $browser->get($location, ':content_file' => $tmpFile);
+            GCUtils::downloadFile($location, $tmpFile, $self->{parent});
             $self->window->set_cursor(Gtk2::Gdk::Cursor->new('left_ptr'));
             $self->{parent}->launch($tmpFile, 'image');
             $self->{info}->{$field} = $tmpFile;
@@ -1049,9 +1104,15 @@ sub loadPlugins
 
     sub createItem
     {
-        my ($self, $field, $row) = @_;
+        my ($self, $field, $row, $mandatory) = @_;
         my $fieldsInfo = $self->{parent}->{model}->{fieldsInfo};
         $self->{$field.'Cb'} = new Gtk2::CheckButton($self->{parent}->{model}->getDisplayedText($fieldsInfo->{$field}->{label}));
+        if ($mandatory)
+        {
+            $self->{$field.'Cb'}->set_sensitive(0);
+            $self->{$field.'Cb'}->set_active(1);
+            $self->{$field.'Cb'}->{mandatory} = 1;
+        }
         $self->{$field} = new Gtk2::Entry;
         $self->{$field}->set_editable(0);
         $self->{table}->attach($self->{$field.'Cb'}, 0, 1, $row, $row + 1, 'fill', ['fill', 'expand'], 0, 0);
@@ -1099,6 +1160,7 @@ sub loadPlugins
         
         $self->{model} = $model;
         my $fieldsInfo = $model->{fieldsInfo};
+        $self->{urlField} = $self->{parent}->{model}->{commonFields}->{url};
 
         foreach ($self->{table}->get_children)
         {
@@ -1113,7 +1175,7 @@ sub loadPlugins
         foreach $field(@{$model->{fieldsNames}})
         {
             next if $fieldsInfo->{$field}->{imported} ne 'true';
-            next if ($fieldsInfo->{$field}->{type} eq 'url');
+            next if ($field eq $self->{urlField});
             if ($fieldsInfo->{$field}->{type} eq 'image')
             {
                 push @picFields, $field;
@@ -1134,6 +1196,12 @@ sub loadPlugins
             $row++;
         }
 
+        if ($self->{urlField})
+        {
+            $self->createItem($self->{urlField}, $row, 1);
+            $row++;
+        }
+
         $row++;
 
         $self->{selectAll} = new Gtk2::Button($parent->{lang}->{ImportSelectAll});
@@ -1149,6 +1217,8 @@ sub loadPlugins
         $self->{selectNone} = new Gtk2::Button($parent->{lang}->{ImportSelectNone});
         $self->{selectNone}->signal_connect('clicked' => sub {
                 my @children = $self->{table}->get_children;
+                # Remove 2 items corresponding to website to keep it checked
+                splice @children, 2, 2;
                 foreach (@children)
                 {
                     $_->set_active(0) if $_->get_name eq 'GtkCheckButton';
