@@ -233,11 +233,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Alapage.com";
     }
     
-    sub getImageFile
-    {
-        return "alapage.png";
-    }
-    
     sub getAuthor
     {
         return 'MeV';
@@ -254,6 +249,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     
         return "ISO-8859-1";
     }
+
+    sub getDefaultPictureSuffix
+    {
+        return '.jpg';
+    }
 }
 
 1;
