@@ -34,9 +34,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
  
     sub start
     {
-		my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
-		$self->{inside}->{$tagname}++;
+        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;        
+        $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
         {
@@ -77,28 +76,26 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                    {
                        $self->{curInfo}->{image} = $src;
                    }
-                   elsif ($src =~ /AffichetteAllocine\.gif/)
+                   elsif ($src =~ /AffichetteAllocine\.gif/i)
                    {
                        $self->{curInfo}->{image} = "empty";
                    }
                }
            }
-		   elsif ($tagname eq "br")
-		   {
-		       if ($self->{insideSynopsis})
-		       {
-			   $self->{curInfo}->{synopsis} .= '<br>';
-		       }
-		   }
-
+           elsif ($tagname eq "br")
+           {
+               if ($self->{insideSynopsis})
+               {
+                   $self->{curInfo}->{synopsis} .= "\n";
+               }
+           }
         }
     }
 
     sub end
     {
-		my ($self, $tagname) = @_;
-		
-		$self->{inside}->{$tagname}--;
+        my ($self, $tagname) = @_;
+        $self->{inside}->{$tagname}--;
 
         if ($tagname eq "h4")
         {
@@ -114,39 +111,30 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
+                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
                 $self->{isMovie} = 0;
                 $self->{isInfo} = 1;
                 return;
             }
-
-            if ($self->{inside}->{h4})
+            if ($self->{isInfo})
             {
-                my $element = undef;
-                if ( $origtext =~ /^ de/ )
+                if ($self->{inside}->{h4})
                 {
-                    $origtext =~ s/^ de //;
-                    $element = "director";
+                    if ( $origtext =~ /([0-9]{4})/ )
+                    {
+                        $self->{itemsList}[$self->{itemIdx}]->{date} = $1;
+                    }
                 }
-                elsif (( $origtext =~ m/^ avec/ ) && (!$self->{itemsList}[$self->{itemIdx}]->{actors}))
+                elsif ($self->{inside}->{h5})
                 {
-                    $origtext =~ s/ avec //;
-                    $element = "actors";
-                }
-                elsif ( $origtext =~ /^ \([0-9]{4}\)/ )
-                {
-                    $origtext =~ s/ \(([0-9]{4})\)/$1/;
-                    $element = "date";
-                    $self->{isInfo} = 0;
-                }
-                $self->{itemsList}[$self->{itemIdx}]->{$element} = $origtext if $element;
-            }
-            if ($self->{inside}->{h5})
-            {
-                if ( ( $origtext =~ /^ \(.*?\)/ ) && ($self->{isInfo}) )
-                {
-                    $origtext =~ s/^ \((.*?)\)/$1/;
-                    $self->{itemsList}[$self->{itemIdx}]->{"orig"} = $origtext;
+                    if ( $origtext =~ /^de (.*)/ )
+                    {
+                        $self->{itemsList}[$self->{itemIdx}]->{director} = $1;
+                    }
+                    elsif (( $origtext =~ m/^avec (.*)/ ) && (!$self->{itemsList}[$self->{itemIdx}]->{actors}))
+                    {
+                        $self->{itemsList}[$self->{itemIdx}]->{actors} = $1;
+                    }
                 }
             }
         }
@@ -197,7 +185,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $origtext =~ s/^Durée : (.*)?/$1/;
                     $self->{curInfo}->{time} = $origtext;
                 }
-                elsif ( $origtext =~ /Date de sortie/ )
+                elsif (( $origtext =~ /Date de sortie/ )
+                    && ( !$self->{curInfo}->{date} ) )
                 {
                     $origtext =~ s/Date de sortie : (.*)/$1/;
                     $origtext =~ s/^[\s\n]*//;
@@ -252,22 +241,28 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         #Remove links for genre
         $html =~ s|<a href="/film/alaffiche_genre_gen_genre.*?>(.*?)</a>|$1|gi;
         #"
+
+        if (!$self->{parsingList})
+        {
+            # Remove link "Plus" in list of actors
+            $html =~ s|<a href="/film/casting_gen_cfilm=.*?>.*?</a>||gi;
+        }
         
         return $html;
     }
     
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
+        my ($self, $word) = @_;
 	
-		return "http://www.allocine.fr/recherche/?motcle=$word&f=3&rub=1";
+        return "http://www.allocine.fr/recherche/?motcle=$word&f=3&rub=1";
     }
     
     sub getItemUrl
     {
-		my ($self, $url) = @_;
+        my ($self, $url) = @_;
 		
-		return "http://www.allocine.fr".$url;
+        return "http://www.allocine.fr".$url;
     }
 
     sub getName
@@ -275,11 +270,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Allocine.fr";
     }
     
-    sub getImageFile
-    {
-        return "allocine.png";
-    }
-
     sub getAuthor
     {
         return 'Tian';
