@@ -24,12 +24,12 @@ package GCPlugins::GCfilms::GCAmazonDE;
 
 use strict;
 
-use GCPlugins::GCfilms::GCfilmsCommon;
+use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
 {
     package GCPlugins::GCfilms::GCPluginAmazonDE;
 
-    use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
+    use base qw(GCPlugins::GCfilms::GCfilmsAmazonPluginsBase);
 
     sub start
     {
@@ -57,12 +57,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             return if ! $self->{beginParsing};
             if ($tagname eq "a")
             {
-                if ($attr->{href} =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
+                my $urlId;
+                if ($urlId = $self->isItemUrl($attr->{href}))
                 {
-                    return if $self->{alreadyRetrieved}->{$1};
-                    $self->{alreadyRetrieved}->{$1} = 1;
+                    return if $self->{alreadyRetrieved}->{$urlId};
+                    $self->{alreadyRetrieved}->{$urlId} = 1;
                     my $url = $attr->{href}; 
-                    $self->{isMovie} = 1;
                     $self->{itemIdx}++;
                     $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
@@ -72,10 +72,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "img")
             {
-                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
-                 && (!$self->{curInfo}->{image}))
+                if (!$self->{curInfo}->{image})
                 {
-                    $self->{curInfo}->{image} = 'http://images.amazon.com/images/P/'.$1.$2.'MZZZZZZZ.jpg';
+                    $self->{curInfo}->{image} = $self->extractImage($attr);
                 }
             }
             elsif ($tagname eq "b")
@@ -116,10 +115,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 return;
             }
             return if ! $self->{beginParsing};
-            if ($self->{isMovie})
+            if ($self->{inside}->{srtitle})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
-                $self->{isMovie} = 0;
+                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
                 return;
             }
             elsif ($self->{inside}->{actors})
@@ -177,11 +175,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             elsif ($self->{inside}->{b})
             {
                 $self->{insideActors} = 1 if $origtext =~ /Darsteller:/;
-				$self->{insideDirector} = 1 if $origtext =~ /Regisseur\(e\):/;
-				$self->{insideAge} = 1 if $origtext =~ /FSK:/;
-				$self->{insideTime} = 1 if $origtext =~ /Spieldauer:/;
-    			$self->{insideSynopsis} = 1 if $origtext =~ /(VideoWoche|Amazon\.de|Movieman\.de|VideoWoche|VideoMarkt|Kurzbeschreibung)/;
-			}        
+                $self->{insideDirector} = 1 if $origtext =~ /Regisseur\(e\):/;
+                $self->{insideAge} = 1 if $origtext =~ /FSK:/;
+                $self->{insideTime} = 1 if $origtext =~ /Spieldauer:/;
+                $self->{insideSynopsis} = 1 if $origtext =~ /(VideoWoche|Amazon\.de|Movieman\.de|VideoWoche|VideoMarkt|Kurzbeschreibung)/;
+            }        
         }
     } 
 
@@ -199,7 +197,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             actors => 1,
         };
 
-        $self->{isMovie} = 0;
+        $self->{suffix} = 'de';
+
         $self->{curName} = undef;
         $self->{curUrl} = undef;
 
@@ -210,6 +209,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
 
+        $html = $self->SUPER::preProcess($html);
         if ($self->{parsingList})
         {
             $html =~ s|^\s+von\s+([^<]*)|<actors>$1</actors>|gm;
@@ -232,37 +232,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         return $html;
     }
-    
-    sub getSearchUrl
-    {
-		my ($self, $word) = @_;
-	
-        return "http://www.amazon.de/gp/search/?redirect=true&search-alias=dvd&keywords=$word";
-    }
-    
-    sub getItemUrl
-    {
-		my ($self, $url) = @_;
-		
-        return 'http://www.amazon.de' if !$url;
-        return $url;
-    }
-
+   
     sub getName
     {
         return "Amazon (DE)";
     }
     
-    sub getImageFile
-    {
-        return "amazon.png";
-    }
-
-    sub getAuthor
-    {
-        return 'Tian';
-    }
-    
     sub getLang
     {
         return 'DE';
