@@ -235,11 +235,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "AnimeNfo Anime";
     }
     
-    sub getImageFile
-    {
-        return "animenfo.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
