@@ -276,11 +276,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Animeka.com";
     }
     
-    sub getImageFile
-    {
-        return "animeka.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
