@@ -236,11 +236,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "CinemaClock.com";
     }
     
-    sub getImageFile
-    {
-        return "cinemaclock.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
