@@ -39,7 +39,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         if ($self->{parsingList})
         {
-            if ($tagname eq "a")
+            if ($tagname eq 'a')
             {
                 if (($attr->{href} =~ /^\/modules\/Films\/fiche\//)
 								 && ($attr->{class} eq "link4"))
@@ -51,15 +51,15 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
-            elsif (($tagname eq "img") && (($attr->{src} =~ /^\/data\/films\//)
+            elsif (($tagname eq 'img') && (($attr->{src} =~ /^\/data\/films\//)
                     || ($attr->{src} =~ /^\/modules\/Films\/img\/webpasdaffiche\.jpg/)))
             {
                 $self->{isMovie} = 0;
                 $self->{itemIdx}--;
             }
-            elsif ($tagname eq "font")
+            elsif ($tagname eq 'font')
             {
-                if ($attr->{class} eq "link4dtext")
+                if ($attr->{class} eq 'link4dtext')
                 {
                     $self->{isInfo}=1;
                 }
@@ -67,26 +67,23 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         }
         else
         {
-            if ($tagname eq "img")
+            if ($tagname eq 'img')
             {
-                if (($attr->{src} =~ /^\/data\/films\//) && 
-                    ($attr->{src} !~ /\/data\/films\/[^_]*_[0-9]{4}_[0-9]*\.jpg/))
+                if (($attr->{src} =~ m|/data/films/|)
+                 && ($attr->{src} !~ m|/data/films/[^_]*_[0-9]{4}_[0-9]*\.jpg|)
+                 && ($attr->{width} == 150))
                 {
-                    $self->{curInfo}->{image} = "http://cinemotions.com" . $attr->{src};
+                    $self->{curInfo}->{image} = $attr->{src};
                 }
             }
-            elsif ($tagname eq "a")
+            elsif ($tagname eq 'font')
             {
-                $self->{insideName} = 1 if $attr->{class} eq "titre_film";
-            }
-            elsif ($tagname eq "font")
-            {
-                $self->{insideOrig} = 1 if $attr->{class} eq "titrevo_film";
-                $self->{insideInfos} = 1 if ($attr->{face} eq "arial")
-                    && ($attr->{size} eq "2");
-                $self->{insideArtists} = 1 if ($attr->{face} eq "verdana,geneva,arial")
-                    && ($attr->{size} eq "2");
-                $self->{insideSynopsis} = 1 if $attr->{class} eq "link6";
+                $self->{insideOrig} = 1 if $attr->{class} eq 'titrevo_film';
+                $self->{insideInfos} = 1 if ($attr->{face} eq 'arial')
+                    && ($attr->{size} eq '2');
+                $self->{insideArtists} = 1 if ($attr->{face} eq 'verdana,geneva,arial')
+                    && ($attr->{size} eq '2');
+                $self->{insideSynopsis} = 1 if $attr->{class} eq 'link6';
             }
         }
     }
@@ -111,32 +108,37 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
-                $self->{isMovie} = 0;
-                $self->{isInfo} = 1;
-                return;
+                if (($self->{inside}->{h1}) || ($self->{inside}->{h2}))
+                {
+                    $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                    $self->{isMovie} = 0;
+                    $self->{isInfo} = 1;
+                    return;
+                }
             }
             elsif ($self->{isInfo})
             {
                 if (($origtext =~ /([0-9]{4}) - [0-9]*h[0-9]*/)
-                    || ($origtext =~ /([0-9]{4}) - [0-9]* mn/))
+                 || ($origtext =~ /([0-9]{4}) - [0-9]* mn/))
                 {
-                    $self->{itemsList}[$self->{itemIdx}]->{"year"} = $1;
+                    $self->{itemsList}[$self->{itemIdx}]->{date} = $1;
                 }
-                elsif ($origtext =~ /R.alisation : ([^\.]*)(\.\.\..*)?Avec (.*)/)
+                elsif ($origtext =~ /^\s*R.alisation : (.*)/)
                 {
-                    $self->{itemsList}[$self->{itemIdx}]->{"director"} =$1;
-                    $self->{itemsList}[$self->{itemIdx}]->{"actors"} = $3;
+                    $self->{itemsList}[$self->{itemIdx}]->{director} =$1;
+                }
+                elsif ($origtext =~ /^\s*avec (.*)/)
+                {
+                    $self->{itemsList}[$self->{itemIdx}]->{actors} = $1;
+                    $self->{isInfo} = 0;
                 }
-                $self->{isInfo} = 0;
             }
         }
         else
         {
-            if ($self->{insideName})
+            if ($self->{inside}->{h1})
             {
                 $self->{curInfo}->{title} = $origtext;
-                $self->{insideName} = 0;
             }
             elsif ($self->{insideOrig})
             {
@@ -164,7 +166,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     $self->{curInfo}->{director} = $1 if !$self->{curInfo}->{director};
                 }
-                elsif ($origtext =~ /Avec (.*)/)
+                elsif ($origtext =~ /avec\s*:?\s*(.*)/i)
                 {
                     $self->{curInfo}->{actors} = $1 if !$self->{curInfo}->{actors};
                 }
@@ -207,8 +209,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s/<b>|<\/b>//g;
         $html =~ s/&nbsp;/ /g;
         $html =~ s/\\'//g;
-        $html =~ s/<A HREF="\/modules\/Artistes\/fiche\/[0-9]*\/[^\.]*\.html"(?:  target=_parent)? class=link5(?:b)? onMouseOver="window\.status='[^']*'; return true;" onMouseOut="window.status=''">([^<]*)<\/A>/$1/gi;
-        $html =~ s/<font class=link_news_2>([^<]*)<\/font>/$1/g;
+        $html =~ s|<A HREF="/modules/Artistes/fiche/[0-9]*[^>]*>(.*?)</A>|$1|gi;
+        $html =~ s/<font class=link_news_2>([^<]*)<\/font>/$1/gi;
         $html =~ s/<font class=link4dtext>([^<]*)<br>([^<]*)<\/TD>/<font class=link4dtext>$1 $2<\/font><\/TD>/gi;
 
         return $html;
@@ -218,26 +220,21 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
 		my ($self, $word) = @_;
 	
-			return "http://www.cinemotions.com/modules/Films/resultats.php?new_keyword=$word";
+		return "http://www.cinemotions.com/cinema-tv-dvd/film-serie-acteur-actrice-realisateur/$word.html"
     }
     
     sub getItemUrl
     {
 		my ($self, $url) = @_;
 		
-			return "http://www.cinemotions.com" . $url;
+			return 'http://www.cinemotions.com' . $url;
     }
 
     sub getName
     {
-        return "Cinemotions.com";
+        return 'Cinemotions.com';
     }
     
-    sub getImageFile
-    {
-        return "cinemotions.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
