@@ -211,11 +211,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "CulturaliaNet";
     }
     
-    sub getImageFile
-    {
-        return "culturalia.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
