@@ -223,6 +223,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 			elsif ($self->{insideSynopsis})
 			{
 				$self->{curInfo}->{synopsis} = $origtext;
+				$self->{curInfo}->{synopsis} =~ s/\n/ /g;
 				$self->{insideSynopsis} = 0;
 			}
 			elsif ($self->{insideTime})
@@ -329,11 +330,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "DVDFr.com";
     }
     
-    sub getImageFile
-    {
-        return "dvdfr.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
