@@ -251,11 +251,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "DVDPost.be";
     }
     
-    sub getImageFile
-    {
-        return "dvdpost.png";
-    }
-    
     sub getAuthor
     {
         return 'MeV';
