@@ -232,10 +232,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
            # $html =~ s/<A.*?ds_kategori.*?>(.*?)<\/A>/$1/g;
            # $html =~ s/<A.*?ds_person.*?>(.*?)<\/A>/$1/g;
             $html =~ s|<a CLASS="blackNUL"[^>]*>([^<]*)</a>|$1|gi;
-            $html =~ s|<FONT COLOR="white">i</FONT>||gi;
+            $html =~ s|<FONT COLOR="white">i</FONT>| |gi;
             $html =~ s/<IMG SRC="img\/design\/pix.gif" WIDTH=2 HEIGHT=5>//g;
-            
-            print "Parsing $html\n";
         }
 
         return $html;
@@ -267,11 +265,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Dicshop.se";
     }
     
-    sub getImageFile
-    {
-        return "dicshop.se.png";
-    }
-
     sub getCharset
     {
         my $self = shift;
@@ -286,7 +279,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     
     sub getLang
     {
-        return 'SE';
+        return 'SV';
     }
     
 }
