@@ -288,11 +288,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Film affinity (EN)";
     }
     
-    sub getImageFile
-    {
-        return "filmaffinity.png";
-    }
-
     sub getCharset
     {
         my $self = shift;
