@@ -307,11 +307,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "Film affinity (ES)";
     }
     
-    sub getImageFile
-    {
-        return "filmaffinity.png";
-    }
-
     sub getCharset
     {
         my $self = shift;
