@@ -55,11 +55,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "FilmUP";
     }
     
-    sub getImageFile
-    {
-        return "filmup.png";
-    }
-
     sub getAuthor
     {
         return 'Tian';
@@ -127,7 +122,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
             }
             if ($self->{inside}->{small} 
-             && ($self->{inside}->{table} == 2)
+             && ($self->{inside}->{table} == 4)
              && $self->{insideInfos})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{date} = $1
@@ -164,8 +159,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
                 elsif ($self->{insideGenre})
                 {
-                    $origtext =~ s|/|,|;
-                    $self->{curInfo}->{genre} = $origtext;
+                    if (!$self->{curInfo}->{genre})
+                    {
+                        $origtext =~ s|/|,|;
+                        $self->{curInfo}->{genre} = $origtext;
+                    }
                     $self->{insideGenre} = 0;
                 }
                 elsif ($self->{insideTime})
@@ -227,7 +225,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s/<font face="arial, helvetica" size="2">Trama:(.*?)<\/font>/<synopsis>$1<\/synopsis>/;
         $html =~ s/Trama:<br>//;
         $html =~ s/<span .*?>|<\/span>//g;
-        $html =~ s/<a href="\/?personaggi.*?>(.+?)<\/a>/$1/g;
+        $html =~ s/<a .*?href="\/?personaggi.*?>(.+?)<\/a>/$1/g;
         #"
         $html =~ s/<font .*?>|<\/font>//g;
         $html =~ s/<b>|<\/b>//g;
