@@ -174,7 +174,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             elsif ($self->{isOrig})
             {
                 $self->{curInfo}->{original} = $origtext if (($origtext !~ /\(/) && ($origtext !~ /rednia ocena:/) );
-                $self->{curInfo}->{original} =~ s/(.*), (.*)/\2 \1/;
+                $self->{curInfo}->{original} =~ s/(.*), (.*)/$2 $1/;
                 $self->{isOrig} = 0;   
             }
             elsif ($self->{isCountry})
@@ -289,11 +289,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "FilmWeb";
     }
     
-    sub getImageFile
-    {
-        return "filmaffinity.png";
-    }
-
     sub getCharset
     {
         my $self = shift;
@@ -311,6 +306,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return 'PL';
     }
+
+    sub getDefaultPictureSuffix
+    {
+        return '.jpg';
+    }
 }
 
 1;
