@@ -24,7 +24,6 @@ package GCPlugins::GCfilms::GCImdb;
 
 use strict;
 
-use GCPlugins::GCfilms::GCfilmsCommon;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
@@ -40,6 +39,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         if ($self->{parsingEnded})
         {
+            return;
             if ($tagname eq "a")
             {
                 if ($attr->{href} =~ m/mymovies\/list\?pending\&add=([0-9]*)/)
@@ -72,12 +72,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 if ((
                      ($self->{inside}->{a}) && 
                      (($self->{currentHref} =~ m/photogallery/) || ($self->{currentHref} =~ m/posters/)) &&
-                     ($attr->{src} !~ /f\d{2}\.gif/)
+                     ($attr->{src} !~ /f\d{2}\.gif/) && ($attr->{src} !~ /icon_photos_faded\.gif/)
                    ) ||
                    (
                       (
                         ($self->{curInfo}->{title}) &&
-                        ($attr->{alt} eq $self->{curInfo}->{title})
+                        (($attr->{alt} eq $self->{curInfo}->{title}) || ($attr->{title} eq $self->{curInfo}->{title}))
                       ) ||
                       (
                         ($self->{curInfo}->{original}) &&
@@ -94,6 +94,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 if ($attr->{href} =~ m/fullcredits/)
                 {
                     $self->{insideActors} = 0;
+                    $self->{insideRoles} = 0;
                     $self->{curInfo}->{actors} =~ s/, $//;
                 }
                 elsif ($attr->{href} =~ m/certificates=USA:(.+?)&/)
@@ -105,8 +106,25 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{curInfo}->{age} = 17 if $1 eq 'R';
                     $self->{curInfo}->{age} = 18  if ($1 eq 'NC-17') || ($1 eq 'X');
                 }
-                $self->{insideSynopsis} = 0 if ($attr->{href} =~ m/plotsummary/);
-                $self->{insideGenre} = 0 if ($attr->{href} =~ m/keywords/);
+                else
+                {
+                    $self->{insideSynopsis} = 0 if ($attr->{href} =~ m/plotsummary/);
+                    $self->{insideGenre} = 1 if ($attr->{href} =~ m|/Sections/Genres/|)
+                        && !($self->{curInfo}->{synopsis} || $self->{curInfo}->{country}
+                          || $self->{curInfo}->{time});
+                }
+            }
+            elsif ($tagname eq 'td')
+            {
+                if ($attr->{class} eq 'nm')
+                {
+                    $self->{insideActors} = 1;
+                    $self->{insideSynopsis} = 0;
+                }
+                elsif ($attr->{class} eq 'char')
+                {
+                    $self->{insideRoles} = 1;
+                }
             }
         }
     }
@@ -137,6 +155,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             if (($self->{inside}->{h1}) && ($origtext !~ m/IMDb\s*Title\s*Search/i))
             {
                 $self->{parsingEnded} = 1;
+                $self->{itemIdx} = 0;
+                $self->{itemsList}[0]->{url} = $self->{loadedUrl};
             }
             if ($self->{isMovie})
             {
@@ -147,7 +167,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             if ($self->{isInfo})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{date} = $1 if $origtext =~ m/\(([0-9]*)\)/;
+                $self->{itemsList}[$self->{itemIdx}]->{date} = $1 if $origtext =~ m|\(([0-9]*)(/I+)?\)|;
                 $self->{isInfo} = 0;
             }
         }
@@ -155,12 +175,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             $self->{insideNat} = 0 if $origtext =~ m/Language:|Color:/;
             $self->{insideOtherTitles} = 0 if $origtext =~ m/Runtime:|MPAA:/;
-            $self->{insideSynopsis} = 0 if $origtext =~ m/(User Comments:)|(User Rating:)/;
-            $self->{insideGenre} = 0 if $origtext =~ m/(User Rating:)|(Plot Outline:)|(Plot Summary:)|(Tagline:)|(User Comments:)/;
+            $self->{insideSynopsis} = 0 if $origtext =~ m/(User Comments:)|(User Rating:)|(Plot Keywords:)/;
 
             if ($self->{insideGenre})
             {
-                $self->{curInfo}->{genre} .= $self->capWord($origtext).',' if $origtext !~ m/\//;
+                $origtext =~ s/\s*$//;
+                $self->{curInfo}->{genre} .= $self->capWord($origtext).',';
+                $self->{curInfo}->{genre} =~ s|\s*/\s*|,|g;
+                $self->{insideGenre} = 0;
             }
             elsif ($self->{insideDirector})
             {
@@ -181,11 +203,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{curInfo}->{time} =~ s/.*?://;
                 $self->{insideTime} = 0;
             }
-            elsif (($self->{insideActors}) && ($self->{inside}->{a}))
+            elsif ($self->{insideActors})
             {
-                $self->{curInfo}->{actors} .= $origtext.', '
+                $self->{curInfo}->{actors} .= $origtext.'; '
                     if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
                 $self->{actorsCounter}++;
+                $self->{insideActors} = 0;
+            }
+            elsif ($self->{insideRoles})
+            {
+                # As we incremented it above, we have one more chance here to add a role
+                # Without <= we would skip the role for last actor
+                $self->{curInfo}->{actors} .= $origtext.', '
+                    if ($self->{actorsCounter} <= $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
+                $self->{insideRoles} = 0;
             }
             elsif ($self->{insideOtherTitles})
             {
@@ -195,28 +226,37 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{insideOtherTitles} = 0;
                 }
             }
+            else {
+                if ( $origtext =~ m{User\s+Rating:\s+(\d+\.\d+)/10\s+} ) {
+                    $self->{ curInfo }->{ rating } = int( $1 + 0.5 );
+                }; # if
+            }; # if
             
-            if ($self->{inside}->{h1})
+            if (($self->{inside}->{title}) || ($self->{inside}->{h1}))
             {
-                $self->{curInfo}->{date} = $origtext if $origtext =~ m/[0-9]+/;
+                $self->{curInfo}->{date} = $1 if $origtext =~ m/([0-9]+)/;
                 $self->{curInfo}->{date} = $1 if $origtext =~ m/\[(TV-Series.*)\]/;
-                if (!$self->{curInfo}->{original})
+                if (!$self->{curInfo}->{title})
                 {
-                    $self->{curInfo}->{original} = $origtext;
-                    $self->{curInfo}->{original} =~ s/\s*$//;
+                    if ($origtext =~ m%^(.*)\s*\([0-9]+(/I+)?\)\s*(\((T?V|mini)\))?$%)
+                    {
+                        $self->{curInfo}->{title} = $1;
+                    }
+                    else
+                    {
+                        $self->{curInfo}->{title} = $origtext;
+                    }
+                    $self->{curInfo}->{title} =~ s/\s*$//;
                 }
             }
-            elsif ($self->{inside}->{b})
+            elsif ($self->{inside}->{h5})
             {
-                $self->{insideDirector} = 1 if $origtext =~ m/Directed by/;
-                $self->{insideGenre} = 1 if $origtext =~ m/Genre:/;
+                $self->{insideDirector} = 1 if $origtext =~ m/(Directed by|Director)/;
                 $self->{insideSynopsis} = 1 if ($origtext =~ m/Synopsis:|Plot Summary:|Plot Outline:/);
                 $self->{insideOtherTitles} = 1 if ($origtext =~ m/Also Known As:/);
                 $self->{insideTime} = 1 if $origtext =~ m/Runtime:/;
                 $self->{insideNat} = 1 if $origtext =~ m/Country:/;
-                $self->{insideActors} = 1 if $origtext =~ m/Cast overview|credited cast:/i;
             }
-            
         }
     }
 
@@ -251,6 +291,16 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s/"&#34;/'"/g;
         $html =~ s/&#34;"/"'/g;
         $html =~ s|</a></b><br>|</a><br>|;
+        $html =~ s{</?(?:b|small)>}{}gi;
+        
+        if (!$self->{parsingList})
+        {
+            $html =~ s|<a href="synopsis">[^<]*</a>||gi;
+            $html =~ s|<a href="/name/.*?">([^<]*)</a>|$1|gi;
+            $html =~ s|<a href="/character/ch[0-9]*/">([^<]*)</a>|$1|gi;
+            #$html =~ s|<a href="/Sections/.*?">([^<]*)</a>|$1|gi;
+        }
+        
         
         return $html;
     }
@@ -266,6 +316,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
 		my ($self, $url) = @_;
 		
+		return $url if $url =~ /^http:/;
 		return "http://www.imdb.com".$url;
     }
 
@@ -274,11 +325,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "IMDb";
     }
     
-    sub getImageFile
-    {
-        return "imdb.png";
-    }
-
     sub getAuthor
     {
         return 'Tian';
@@ -288,8 +334,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return 'EN';
     }
-    
-    
+
 }
 
 1;
