@@ -225,11 +225,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "MovieClub FR";
     }
     
-    sub getImageFile
-    {
-        return "movieclub.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
