@@ -224,11 +224,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "MovieClub NL";
     }
     
-    sub getImageFile
-    {
-        return "movieclub.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
