@@ -245,11 +245,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "OFDb.de";
     }
     
-    sub getImageFile
-    {
-        return "ofdb.png";
-    }
-
     sub getAuthor
     {
         return 'MeV';
