@@ -43,7 +43,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             if ($tagname eq 'div')
             {
                 $self->{isGame} = 1
-                    if $attr->{class} eq 'f18';
+                    if $attr->{class} =~ /f18$/;
                 $self->{isDate} = 1
                     if $attr->{class} eq 'f11 fwb';
             }
@@ -80,13 +80,12 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         else
         {
-            return if $self->{infoEnded};
             if ($tagname eq 'img')
             {
                 $self->{curInfo}->{boxpic} = ' '
                     if $attr->{src} =~ /no_preview/;
                 $self->{curInfo}->{boxpic} = $attr->{src}
-                    if (! $self->{curInfo}->{boxpic}) && ($attr->{src} =~ /[^xo]box/);
+                    if (! $self->{curInfo}->{boxpic}) && ($attr->{src} =~ /[^xo]boxs[^c]/);
                 if ($attr->{src} =~ /thumb/)
                 {
                     my $pic = $attr->{src};
@@ -102,6 +101,10 @@ use GCPlugins::GCgames::GCgamesCommon;
             {
                 $self->{isName} = 1 if ! $self->{curInfo}->{name};
             }
+            elsif ($tagname eq 'p')
+            {
+                $self->{isDesc} = 1 if $attr->{class} eq 'review deck';
+            }
             elsif ($tagname eq 'div')
             {
                 $self->{isDesc} = 1 if $attr->{class} eq 'f12 dots pb5 mb5';
@@ -159,8 +162,8 @@ use GCPlugins::GCgames::GCgamesCommon;
                 $self->{section} = 'Codes' if $origtext =~ /Cheat Codes$/;    
                 $self->{section} = 'Secrets' if $origtext =~ /Secrets$/;    
                 $self->{section} = 'Unlockables' if $origtext =~ /Unlockables$/;    
-                $self->{curInfo}->{code} = {line => []} if $self->{section} eq 'Codes';
-                $self->{curInfo}->{unlockable} = {line => []} if $self->{section} eq 'Unlockables';
+                $self->{curInfo}->{code} = [] if $self->{section} eq 'Codes';
+                $self->{curInfo}->{unlockable} = [] if $self->{section} eq 'Unlockables';
                 $self->{isSection} = 0;
             }
             elsif (($self->{section} eq 'Codes') || ($self->{section} eq 'Unlockables'))
@@ -172,20 +175,20 @@ use GCPlugins::GCgames::GCgamesCommon;
                 
                 if ($self->{isCheat})
                 {
-                    $self->{tmpCheatLine} = {col => []};
-                    push @{$self->{tmpCheatLine}->{col}}, $origtext;
+                    $self->{tmpCheatLine} = [];
+                    push @{$self->{tmpCheatLine}}, $origtext;
                     $self->{isCheat} = 0;
                 }
                 elsif ($self->{isDesc})
                 {
-                    push @{$self->{tmpCheatLine}->{col}}, $origtext;
+                    push @{$self->{tmpCheatLine}}, $origtext;
                     if ($self->{section} eq 'Codes')
                     {
-                        push @{$self->{curInfo}->{code}->{line}}, $self->{tmpCheatLine};
+                        push @{$self->{curInfo}->{code}}, $self->{tmpCheatLine};
                     }
                     else
                     {
-                        push @{$self->{curInfo}->{unlockable}->{line}}, $self->{tmpCheatLine};
+                        push @{$self->{curInfo}->{unlockable}}, $self->{tmpCheatLine};
                     }
                     $self->{isDesc} = 0;
                 }
@@ -201,12 +204,6 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         else
         {
-            if ($self->{inside}->{h2})
-            {
-                $self->{infoEnded} = 1
-                    if $origtext eq 'Similar Games';
-            }
-            return if $self->{infoEnded};
             if ($self->{isName})
             {
                 $origtext =~ s/\n//g;
@@ -296,8 +293,6 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{section} = '';
         $self->{isSection} = 0;
 
-        $self->{infoEnded} = 0;
-
         return $self;
     }
 
@@ -309,7 +304,18 @@ use GCPlugins::GCgames::GCgamesCommon;
         {
             $html =~ s|<b>(.*?)</b>|$1|g;
         }
-            
+        elsif ($self->{parsingList})
+        {
+        }
+        else
+        {
+            my $found = index($html,"Similar Games");
+            if ( $found >= 0 )
+            {
+               $html = substr($html, 0, $found);
+            }
+        }
+
         return $html;
     }
     
@@ -317,14 +323,17 @@ use GCPlugins::GCgames::GCgamesCommon;
     {
 		my ($self, $word) = @_;
 	
-        return 'http://www.gamespot.com/search.html?qs='.$word.'&sub=g&stype=11&type=11';
+        #return 'http://www.gamespot.com/search.html?qs='.$word.'&sub=g&stype=11&type=11';
+        return 'http://www.gamespot.com/pages/search/solr_search_ajax.php?q='.$word.'&type=game&offset=0&tags_only=false&sort=false';
     }
     
     sub getItemUrl
     {
 		my ($self, $url) = @_;
-
-        return 'http://www.gamespot.com' . $url;
+        return 'http://www.gamespot.com' . $url
+            if $url !~ /gamespot\.com/;
+        return $url if $url;
+        return 'http://www.gamespot.com';
     }
 
     sub getName
