@@ -107,7 +107,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                     $self->{is} = 'editor';
                     $self->{isEditor} = 0;
             }
-            elsif ( ($tagname eq 'a') && ($self->{isDeveloper}) )
+            elsif ($self->{isDeveloper})
             {
                     $self->{is} = 'developer';
                     $self->{isDeveloper} = 0;
@@ -131,6 +131,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                     if (( $attr->{src} ne "http://image.jeuxvideo.com/pics/pasdimage2.gif" ) && ($attr->{src} ne "http://image.jeuxvideo.com/pics/pasdimage.gif"))
                     {
                         $self->{curInfo}->{boxpic} = $attr->{src};
+                        $self->{curInfo}->{boxpic} =~ s/20ft.jpg/20f.jpg/;
                     }
                     $self->{isBox} = 0;
             }
@@ -168,6 +169,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                     {
                        my $html_Desc = substr($html, $found +length('<p id="chapo">'),length($html)- $found -length('<p id="chapo">'));
                        $html_Desc = substr($html_Desc,index($html_Desc,"<strong>") + length("<strong>"),index($html_Desc,"</strong>")-index($html_Desc,"<strong>")-length("<strong>") );
+                       $html_Desc =~ s|\x{92}|'|gi;
                        $self->{curInfo}->{description} = $html_Desc;
                     }
                     $found = index($html,"<dt>Multijoueurs :</dt>");
@@ -256,6 +258,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             elsif ($self->{isStrong})
             {
                 $self->{isDate} = 1 if $origtext =~ /Sortie :/;
+                $self->{isDate} = 1 if $origtext =~ /Sortie France :/;
                 $self->{isGenre} = 1 if $origtext =~ /Type :/;
                 $self->{isEditor} = 1 if $origtext =~ /Editeur :/;
                 $self->{isDeveloper} = 1 if $origtext =~ /D.veloppeur :/;
@@ -338,14 +341,14 @@ use GCPlugins::GCgames::GCgamesCommon;
 
         if ($self->{parsingTips})
         {
-            $html =~ s|<br />|<p>|g;
-            $html =~ s|</kbd>||g;
-            $html =~ s|</b>||g;
-            $html =~ s|<img src="../pics/psx/cercle.gif" />|cercle|g;
-            $html =~ s|<img src="../pics/psx/croix.gif" />|croix|g;
-            $html =~ s|<img src="../pics/psx/carre.gif" />|carre|g;
-            $html =~ s|<img src="../pics/psx/triangle.gif" />|triangle|g;
-            $html =~ s|\x{92}|'|g;
+            $html =~ s|<br />|<p>|gi;
+            $html =~ s|</kbd>||gi;
+            $html =~ s|</b>||gi;
+            $html =~ s|<img src="../pics/psx/cercle.gif" />|cercle|gi;
+            $html =~ s|<img src="../pics/psx/croix.gif" />|croix|gi;
+            $html =~ s|<img src="../pics/psx/carre.gif" />|carre|gi;
+            $html =~ s|<img src="../pics/psx/triangle.gif" />|triangle|gi;
+            $html =~ s|\x{92}|'|gi;
         }
         return $html;
     }
@@ -361,7 +364,7 @@ use GCPlugins::GCgames::GCgamesCommon;
     {
 		my ($self, $url) = @_;
 		
-        return $url unless $url eq '';
+        return $url if $url;
         return 'http://www.jeuxvideo.com/';
     }
 
