@@ -56,14 +56,12 @@ use GCPlugins::GCgames::GCgamesCommon;
                 }
                 elsif ($tagname eq 'a')
                 {
-                    if ($attr->{href} =~ m|/fiche|)
-                    {
-                        $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
-                        $self->{isName} = 1;
-                    }
+                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href}
+                        if $self->{isName};
                 }
                 elsif ($tagname eq 'td')
                 {
+                    $self->{isName} = 1 if $attr->{class} eq 'titre';
                     $self->{isDate} = 1 if $attr->{class} eq 'datesortie';
                     $self->{isGenre} = 1 if $attr->{class} eq 'genre';
                 }
@@ -274,8 +272,11 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         elsif ($self->{parsingTips})
         {
-            $html =~ s|<b>(.*?)</b>|$1|g;
+            $html =~ s|<b>(.*?)</b>|$1|gi;
             $html =~ s|<img src='http://www\.jeuxvideo\.fr/style/img/man/bt_([a-z_]*)\.gif' align='absmiddle'>|$self->toKey($1)|ge;
+            $html =~ s|\x{92}|'|gi;
+            $html =~ s|\x{8C}|OE|gi;
+            $html =~ s|\x{9C}|oe|gi;
         }
 
         return $html;
