@@ -39,10 +39,10 @@ use GCPlugins::GCgames::GCgamesCommon;
         my $answer = "";
         my @tmpAnswer = ();
         my $html = $self->loadPage($html_ini);
-        $html =~ s|<pre>||g;
-        $html =~ s|</pre>||g;
-        $html =~ s|<b>||g;
-        $html =~ s|</b>||g;
+        $html =~ s|<pre>||gi;
+        $html =~ s|</pre>||gi;
+        $html =~ s|<b>||gi;
+        $html =~ s|</b>||gi;
         my $found = index($html,"class=\"sbL sbB sbT\">");
         if ( $found >= 0 )
         {
@@ -56,7 +56,9 @@ use GCPlugins::GCgames::GCgamesCommon;
            {
               my $html2 = substr($html, $found + length("class=\"sbR sbL sbB\"><p>"),length($html)- $found -length("class=\"sbR sbL sbB\"><p>") );
               $html2 = substr($html2, 0, index($html2,"</p>"));
-              $html2 =~ s/<br>/\n/g;
+              $html2 =~ s/<br>/\n/gi;
+              $html2 =~ s|<p>|\n|gi;
+              $html2 =~ s|</p>||gi;
 
               $tmpAnswer[1] = decode_entities($html2);
            }
@@ -143,9 +145,9 @@ use GCPlugins::GCgames::GCgamesCommon;
                 {
                    $Text::Wrap::columns = 80;
                    $tips[1] = Text::Wrap::wrap('', '', $tips[1]);
-                   $self->{tmpCheatLine} = {col => []};
-                   push @{$self->{tmpCheatLine}->{col}}, @tips;
-                   push @{$self->{curInfo}->{unlockable}->{line}}, $self->{tmpCheatLine};
+                   #$self->{tmpCheatLine} = [];
+                   #push @{$self->{tmpCheatLine}}, @tips;
+                   push @{$self->{curInfo}->{unlockable}}, \@tips;
                 }
                 else
                 {
@@ -166,9 +168,9 @@ use GCPlugins::GCgames::GCgamesCommon;
                 @tips = reverse(@tips);
                 $Text::Wrap::columns = 80;
                 $tips[1] = Text::Wrap::wrap('', '', $tips[1]);
-                $self->{tmpCheatLine} = {col => []};
-                push @{$self->{tmpCheatLine}->{col}}, @tips;
-                push @{$self->{curInfo}->{code}->{line}}, $self->{tmpCheatLine};
+                #$self->{tmpCheatLine} = [];
+                #push @{$self->{tmpCheatLine}}, @tips;
+                push @{$self->{curInfo}->{code}}, \@tips;
 
                 $self->{isCode} = 2;
 
@@ -286,7 +288,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                        }
                     }
 
-                    my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots');
+                    $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots');
                     my $found = index($html,"\"><img alt=\"[");
                     if ( $found >= 0 )
                     {
@@ -502,7 +504,7 @@ use GCPlugins::GCgames::GCgamesCommon;
     {
         my ($self, $url) = @_;
 		
-        return $url unless $url eq '';
+        return $url if $url;
         return 'http://www.mobygames.com/';
     }
 
