@@ -80,7 +80,8 @@ use GCPlugins::GCmusics::GCmusicsCommon;
             }
             $self->{curInfo}->{tracks} = $self->getTracks;
             $self->{curInfo}->{running} = $self->getTotalTime;
-            $self->{curInfo}->{cover} = 'http://images.amazon.com/images/P/'.$xml->{release}->{asin}.'.01.MZZZZZZZ.jpg';
+            $self->{curInfo}->{cover} = 'http://images.amazon.com/images/P/'.$xml->{release}->{asin}.'.01.MZZZZZZZ.jpg'
+                if $xml->{release}->{asin};
         }
     }
 
@@ -132,7 +133,7 @@ use GCPlugins::GCmusics::GCmusicsCommon;
     sub getItemUrl
     {
 		my ($self, $url) = @_;
-        return $url unless $url eq '';
+        return $url if $url;
         return "http://musicbrainz.org/";
     }
 
@@ -166,6 +167,12 @@ use GCPlugins::GCmusics::GCmusicsCommon;
         return "UTF-8";
     }
 
+    sub convertCharset
+    {
+        my ($self, $value) = @_;
+        return $value;
+    }
+
     sub getNotConverted
     {
         my $self = shift;
