@@ -31,9 +31,17 @@ use GCPlugins::GCPluginsBase;
 
     sub extractImage
     {
-        my ($self, $url) = @_;
-        return 'http://images.amazon.com/images/P/'.$1.$2.'MZZZZZZZ.jpg'
-            if ($url =~ m%^http://.*?images[.-]amazon\.com/images/P/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%);
+        my ($self, $attr) = @_;
+        my $url = $attr->{src};
+        return 'http://images.amazon.com/images/'.$1.'/'.$2.$3.'MZZZZZZZ.'.$5
+            if ($url =~ m%^http://.*?images[.-]amazon\.com/images/(P)/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%);
+        return 'http://images.amazon.com/images/'.$1.'/'.$2.'.'.$3
+            if ($url =~ m%^http://.*?images[.-]amazon\.com/images/(I|G)/([-A-Z0-9a-z+]*)\._.*?_\.(jpg|gif)%);
+        if ($attr->{id} eq 'prodImage')
+        {
+            $url =~ s/\._AA[0-9]*_//;
+            return $url;
+        }
         return '';
     }
 
@@ -50,6 +58,15 @@ use GCPlugins::GCPluginsBase;
         return 0;
     }
 
+    sub isItemUrl
+    {
+        my ($self, $url) = @_;
+        return $1
+            if (($url =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
+             || ($url =~ m|/dp/[A-Z0-9]*/ref=(?:sr\|pd)_([a-z0-9_]*)/[0-9]*|));
+        return undef;
+    }
+
     sub getSearchUrl
     {
         my ($self, $word) = @_;
@@ -65,20 +82,30 @@ use GCPlugins::GCPluginsBase;
     
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-        return 'http://www.amazon.'.$self->{suffix} if !$url;
-        return $url;
-    }
-
-    sub getImageFile
-    {
-        return "amazon.png";
+        my ($self, $url) = @_;
+        return $url if $url;
+        return 'http://www.amazon.'.$self->{suffix};
     }
 
     sub getAuthor
     {
         return 'Tian';
     }
+
+    sub preProcess
+    {
+        my ($self, $html) = @_;
+        if ($self->{parsingList})
+        {
+            $html =~ s|<span\s+class="srTitle">([^<]*)</span>|<srTitle>$1</srTitle>|gim;
+            $html =~ s|<td class="otherEditions">.*?</td>||gim;
+        }
+        else
+        {
+            $html =~ s|<a\s*href="/exec/obidos/ASIN/[0-9/\${}]*">([^<]*)</a>|$1|gim;
+        }
+        return $html;
+    }
 }
 
 1;
