@@ -33,7 +33,7 @@ use Gtk2;
     {
         my $proto = shift;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new('popup');
+        my $self  = $class->SUPER::new();
         bless ($self, $class);
 
         $self->{parent} = shift;
@@ -43,8 +43,10 @@ use Gtk2;
 
         $self->set_decorated(0);
         $self->set_resizable(0);
+        $self->set_transient_for($self->{parent});
         $self->set_destroy_with_parent(1);
-        $self->set_position('center-always');
+        $self->set_modal(1);
+        #$self->set_position('center-always');
         
         $self->{title} = new Gtk2::Label;
         $self->{title}->set_markup('<span size="xx-large" weight="bold" color="#1c86ee">GCstar</span>');
@@ -52,8 +54,8 @@ use Gtk2;
 
         $self->{vbox} = new Gtk2::VBox(0,0);        
 		
-		$self->{progress} = new Gtk2::ProgressBar;
-		$self->{progress}->set_size_request(240,-1);
+        $self->{progress} = new Gtk2::ProgressBar;
+        $self->{progress}->set_size_request(240,-1);
 
         my $color_fg = Gtk2::Gdk::Color->parse('#1c86ee');
         my $color_progress_bg = Gtk2::Gdk::Color->parse('#ffffff');
@@ -73,24 +75,24 @@ use Gtk2;
         $inbox->put($self->{title},0,110);
         $inbox->put($self->{label},0,145);
         $inbox->put($self->{progress},30,170);
-	    $self->{vbox}->pack_start($eventbox,0,0,0);
+        $self->{vbox}->pack_start($eventbox,0,0,0);
 	    
         $self->add($self->{vbox});
-	    my $drawing_area = Gtk2::DrawingArea->new;
+        my $drawing_area = Gtk2::DrawingArea->new;
         $self->{vbox}->pack_start($drawing_area,0,0,0);
-	    $drawing_area->realize;
+        $drawing_area->realize;
 		
-	    my ($pango_w, $pango_h) = (300,200);
+        my ($pango_w, $pango_h) = (300,200);
         my $pixmap = Gtk2::Gdk::Pixmap->new ($drawing_area->window,
                 $pango_w,
                 $pango_h,
                 -1);
 
         my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{splashImage});
-		my ($pm, $m) = $pixbuf->render_pixmap_and_mask(255);
+        my ($pm, $m) = $pixbuf->render_pixmap_and_mask(255);
     	$img->set_from_pixmap($pm, $m);
     	$self->shape_combine_mask ($m, 0, 0) if $m;
-        $self->set_position('center-always');
+        $self->set_position('center');
         $self->{vbox}->show_all;
         $self->show;
         $self->{title}->set_size_request(300,-1);
@@ -119,16 +121,23 @@ use Gtk2;
         elsif ($self->{phase} == 2)
         {
             $self->{parent}->loadPrevious($self);
-            $self->setProgress(1.0);
-            $self->{parent}->{initializing} = 0;
-            $self->{parent}->setSensitive(1);
+            $self->setProgress(0.7);
+#            $self->{parent}->setSensitive(1);
             $self->{phase} = 3;
+            $self->setLabel($self->{parent}->{lang}->{SplashSort});
+        }
+        elsif ($self->{phase} == 3)
+        {
+            $self->{parent}->initEnd;
+            $self->setProgress(1.0);
+            $self->{parent}->setSensitive(1);
+            $self->{phase} = 4;
             $self->setLabel($self->{parent}->{lang}->{SplashDone});
         }
         else
         {
             $self->hide;
-            $self->{parent}->initEnd;
+            $self->{parent}->{initializing} = 0;
             Glib::Timeout->add(700 ,\&destroyMe, $self);
             return 0;
         }
@@ -179,7 +188,23 @@ use Gtk2;
         {
             return if ($current % $self->{step});
             $self->setLabel($self->{parent}->{lang}->{SplashDisplay}." <span color='#cdad00'>($current/".$self->{total}.')</span>');
-            $self->{progress}->set_fraction(0.4 + (($current / $self->{total}) * 0.5));
+            $self->{progress}->set_fraction(0.4 + (($current / $self->{total}) * 0.3));
+        }
+        Gtk2->main_iteration while (Gtk2->events_pending);
+    }
+
+    sub setProgressForItemsSort
+    {
+        my ($self, $current) = @_;
+        if (! $self->{total})
+        {
+            $self->{progress}->set_fraction(0.8);
+        }
+        else
+        {
+            return if ($current % $self->{step});
+            $self->setLabel($self->{parent}->{lang}->{SplashSort}." <span color='#cdad00'>($current/".$self->{total}.')</span>');
+            $self->{progress}->set_fraction(0.7 + (($current / $self->{total}) * 0.2));
         }
         Gtk2->main_iteration while (Gtk2->events_pending);
     }
