@@ -1,6 +1,12 @@
+#
+# More information here: http://wiki.gcstar.org/en/websites_plugins
+#
+# GCcollection should be replaced with the kind of collection your
+# plugin deals with. e.g. GCfilms, GCgames, GCbooks,...
+
 # Replace SiteTemplate with your plugin name.
 # The package name must exactly match the file name (.pm)
-package GCPlugins::GCSiteTemplate;
+package GCPlugins::GCcollection::GCSiteTemplate;
 
 ###################################################
 #
@@ -25,15 +31,16 @@ package GCPlugins::GCSiteTemplate;
 ###################################################
 
 use strict;
+use utf8;
 
-use GCPlugins::GCPluginsBase;
+use GCPlugins::GCcollection::GCcollectionCommon;
 
 {
     # Replace SiteTemplate with your exporter name
     # It must be the same name as the one used for file and main package name
-    package GCPlugins::GCPluginSiteTemplate;
+    package GCPlugins::GCcollection::GCPluginSiteTemplate;
 
-    use base qw(GCPluginParser);
+    use base 'GCPlugins::GCcollection::GCcollectionPluginsBase';
  
     # getSearchUrl
     # Used to get the URL that to be used to perform searches.
@@ -50,7 +57,7 @@ use GCPlugins::GCPluginsBase;
     }
     
     # getItemUrl
-    # Used to get the full URL of a movie page.
+    # Used to get the full URL of an item page.
     # Useful when url on results pages are relative.
     # $url is the URL as found with a search.
     # Returns the absolute URL.
@@ -81,15 +88,6 @@ use GCPlugins::GCPluginsBase;
     {
         return "SiteTemplate";
     }
-    
-    # getImageFile
-    # Used to display a plugin picture in GUI.
-    # The picture should be in share/gcstar.
-    # Returns the plugin picture file name.
-    sub getImageFile
-    {
-        return "sitetemplate.png";
-    }
 
     # getAuthor
     # Used to display the plugin author in GUI.
@@ -106,31 +104,6 @@ use GCPlugins::GCPluginsBase;
     {
         return 'EN';
     }
-
-    # hasSearchYear
-    # Used to hide year column in search results
-    # Return 0 to hide column, 1 to show it.
-    sub hasSearchYear
-    {
-        return 1;
-    }
-
-    # hasSearchDirector
-    # Used to hide director column in search results
-    # Return 0 to hide column, 1 to show it.
-    sub hasSearchDirector
-    {
-        return 1;
-    }
-
-    # hasSearchActors
-    # Used to hide actors column in search results
-    # Return 0 to hide column, 1 to show it.
-    sub hasSearchActors
-    {
-        return 1;
-    }
-
     # getExtra
     # Used if the plugin wants an extra column to be displayed in search results
     # Return the column title or empty string to hide the column.
@@ -140,7 +113,7 @@ use GCPlugins::GCPluginsBase;
     }
 
     # changeUrl
-    # Can be used to change URL if movie URL and the one used to
+    # Can be used to change URL if item URL and the one used to
     # extract information are different.
     # Return the modified URL.
     sub changeUrl
@@ -152,42 +125,22 @@ use GCPlugins::GCPluginsBase;
 
     # In processing functions below, self->{parsingList} can be used.
     # If true, we are processing a search results page
-    # If false, we are processing a movie information page.
+    # If false, we are processing a item information page.
     
     # $self->{inside}->{tagname} (with correct value for tagname) can be used to test
     # if we are in the corresponding tag.
     
-    # You have a counter $self->{movieIdx} that have to be used when processing search results.
+    # You have a counter $self->{itemIdx} that have to be used when processing search results.
     # It is your responsability to increment it!
     
-    # When processing search results, you have to fill (if available) following fields:
+    # When processing search results, you have to fill the available fields for results
     #
-    #  $self->{movieList}[$self->{movieIdx}]->{title}
-    #  $self->{movieList}[$self->{movieIdx}]->{url}
-    #  $self->{movieList}[$self->{movieIdx}]->{actors}
-    #  $self->{movieList}[$self->{movieIdx}]->{director}
-    #  $self->{movieList}[$self->{movieIdx}]->{date}
-    #  $self->{movieList}[$self->{movieIdx}]->{extra}
-    
-    # When processing a movie page, you need to fill the fields (if available) in $self->{curInfo}. They are:
+    #  $self->{itemsList}[$self->{movieIdx}]->{field_name}
     #
-    #  $self->{curInfo}->{title}
-    #  $self->{curInfo}->{director}
-    #  $self->{curInfo}->{original}        (Original title)
-    #  $self->{curInfo}->{actors}
-    #  $self->{curInfo}->{genre}        (Comma separated list of movie type)
-    #  $self->{curInfo}->{country}        (Movie Nationality or country)
-    #  $self->{curInfo}->{date}
-    #  $self->{curInfo}->{time}
-    #  $self->{curInfo}->{synopsis}
-    #  $self->{curInfo}->{image}
-    #  $self->{curInfo}->{audio}
-    #  $self->{curInfo}->{subt}
-    #  $self->{curInfo}->{age}          0     : No information
-    #                                   1     : Unrated
-    #                                   2     : All audience
-    #                                   5     : Parental Guidance
-    #                                   >= 10 : Minimum age value
+    # When processing a movie page, you need to fill the fields (if available)
+    # in $self->{curInfo}.
+    #
+    #  $self->{curInfo}->{field_name}
     
     # start
     # Called each time a new HTML tag begins.
@@ -255,6 +208,17 @@ use GCPlugins::GCPluginsBase;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
 
+        # This member should be initialized as a reference
+        # to a hash. Each keys is a field that could be
+        # in results with value 1 or 0 if it is returned
+        # or not. For the list of keys, check the model file
+        # (.gcm) and search for tags <field> in
+        # /collection/options/fields/results
+        $self->{hasField} = {
+            key1 => 1,
+            key2 => 0,
+        };
+
         # Do your init stuff here
         
         bless ($self, $class);
